// PAC (Proxy Auto Configuration) Filter from EasyList rules
// 
// Copyright (C) 2017 by Steven T. Smith <steve dot t dot smith at gmail dot com>, GPL
// https://github.com/essandess/easylist-pac-privoxy/
//
// PAC file created on Sun, 19 Jan 2020 06:32:10 GMT
// Created with command: easylist_pac.py
//
// http://www.gnu.org/licenses/lgpl.txt
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

// If you normally use a proxy, replace "DIRECT" below with
// "PROXY MACHINE:PORT"
// where MACHINE is the IP address or host name of your proxy
// server and PORT is the port number of your proxy server.
//
// Influenced in part by code from King of the PAC from http://securemecca.com/pac.html

// Define the blackhole proxy for blocked adware and trackware

var normal = "DIRECT";
var proxy = "DIRECT";                  // e.g. 127.0.0.1:3128
// var blackhole_ip_port = "127.0.0.1:8119";  // ngnix-hosted blackhole
// var blackhole_ip_port = "8.8.8.8:53";      // GOOG DNS blackhole; do not use: no longer works with iOS 11—causes long waits on some sites
var blackhole_ip_port = "127.0.0.1:8118";    // on iOS a working blackhole requires return code 200;
// e.g. use the adblock2privoxy nginx server as a blackhole
var blackhole = "PROXY " + blackhole_ip_port;

// The hostnames must be consistent with EasyList format.
// These special RegExp characters will be escaped below: [.?+@]
// This EasyList wildcard will be transformed to an efficient RegExp: *
// 
// EasyList format references:
// https://adblockplus.org/filters
// https://adblockplus.org/filter-cheatsheet

// Create object hashes or compile efficient NFA's from all filters
// Various alternate filtering and regex approaches were timed using node and at jsperf.com

// Too many rules (>~ 10k) bog down the browser; make reasonable exclusions here:

// EasyList rules:
// https://adblockplus.org/filters
// https://adblockplus.org/filter-cheatsheet
// https://opnsrce.github.io/javascript-performance-tip-precompile-your-regular-expressions
// https://adblockplus.org/blog/investigating-filter-matching-algorithms
// 
// Strategies to convert EasyList rules to Javascript tests:
// 
// In general:
// 1. Preference for performance over 1:1 EasyList functionality
// 2. Limit number of rules to ~O(10k) to avoid computational burden on mobile devices
// 3. Exact matches: use Object hashing (very fast); use efficient NFA RegExp's for all else
// 4. Divide and conquer specific cases to avoid large RegExp's
// 5. Based on testing code performance on an iPhone: mobile Safari, Chrome with System Activity Monitor.app
// 6. Backstop these proxy.pac rules with Privoxy rules and a browser plugin
// 
// scheme://host/path?query ; FindProxyForURL(url, host) has full url and host strings
// 
// EasyList rules:
// 
// || domain anchor
// 
// ||host is exact e.g. ||a.b^ ? then hasOwnProperty(hash,host)
// ||host is wildcard e.g. ||a.* ? then RegExp.test(host)
// 
// ||host/path is exact e.g. ||a.b/c? ? then hasOwnProperty(hash,url_path_noquery) [strip ?'s]
// ||host/path is wildcard e.g. ||a.*/c? ? then RegExp.test(url_path_noquery) [strip ?'s]
// 
// ||host/path?query is exact e.g. ||a.b/c?d= ? assume none [handle small number within RegExp's]
// ||host/path?query is wildcard e.g. ||a.*/c?d= ? then RegExp.test(url)
// 
// url parts e.g. a.b^c&d|
// 
// All cases RegExp.test(url)
// Except: |http://a.b. Treat these as domain anchors after stripping the scheme
// 
// regex e.g. /r/
// 
// All cases RegExp.test(url)
// 
// @@ exceptions
// 
// Flag as "good" versus "bad" default
// 
// Variable name conventions (example that defines the rule):
// 
// bad_da_host_exact == bad domain anchor with host/path type, exact matching with Object hash
// bad_da_host_regex == bad domain anchor with host/path type, RegExp matching
// 
// 71 rules:
var good_da_host_JSON = { "apple.com": null,
"icloud.com": null,
"apple-dns.net": null,
"swcdn.apple.com": null,
"init.itunes.apple.com": null,
"init-cdn.itunes-apple.com.akadns.net": null,
"itunes.apple.com.edgekey.net": null,
"setup.icloud.com": null,
"p32-escrowproxy.icloud.com": null,
"p32-escrowproxy.fe.apple-dns.net": null,
"keyvalueservice.icloud.com": null,
"keyvalueservice.fe.apple-dns.net": null,
"p32-bookmarks.icloud.com": null,
"p32-bookmarks.fe.apple-dns.net": null,
"p32-ckdatabase.icloud.com": null,
"p32-ckdatabase.fe.apple-dns.net": null,
"configuration.apple.com": null,
"configuration.apple.com.edgekey.net": null,
"mesu.apple.com": null,
"mesu-cdn.apple.com.akadns.net": null,
"mesu.g.aaplimg.com": null,
"gspe1-ssl.ls.apple.com": null,
"gspe1-ssl.ls.apple.com.edgekey.net": null,
"api-glb-bos.smoot.apple.com": null,
"query.ess.apple.com": null,
"query-geo.ess-apple.com.akadns.net": null,
"query.ess-apple.com.akadns.net": null,
"setup.fe.apple-dns.net": null,
"gsa.apple.com": null,
"gsa.apple.com.akadns.net": null,
"icloud-content.com": null,
"usbos-edge.icloud-content.com": null,
"usbos.ce.apple-dns.net": null,
"lcdn-locator.apple.com": null,
"lcdn-locator.apple.com.akadns.net": null,
"lcdn-locator-usuqo.apple.com.akadns.net": null,
"cl1.apple.com": null,
"cl2.apple.com": null,
"cl3.apple.com": null,
"cl4.apple.com": null,
"cl5.apple.com": null,
"cl1-cdn.origin-apple.com.akadns.net": null,
"cl2-cdn.origin-apple.com.akadns.net": null,
"cl3-cdn.origin-apple.com.akadns.net": null,
"cl4-cdn.origin-apple.com.akadns.net": null,
"cl5-cdn.origin-apple.com.akadns.net": null,
"cl1.apple.com.edgekey.net": null,
"cl2.apple.com.edgekey.net": null,
"cl3.apple.com.edgekey.net": null,
"cl4.apple.com.edgekey.net": null,
"cl5.apple.com.edgekey.net": null,
"xp.apple.com": null,
"xp.itunes-apple.com.akadns.net": null,
"mt-ingestion-service-pv.itunes.apple.com": null,
"p32-sharedstreams.icloud.com": null,
"p32-sharedstreams.fe.apple-dns.net": null,
"p32-fmip.icloud.com": null,
"p32-fmip.fe.apple-dns.net": null,
"gsp-ssl.ls.apple.com": null,
"gsp-ssl.ls-apple.com.akadns.net": null,
"gsp-ssl.ls2-apple.com.akadns.net": null,
"gspe35-ssl.ls.apple.com": null,
"gspe35-ssl.ls-apple.com.akadns.net": null,
"gspe35-ssl.ls.apple.com.edgekey.net": null,
"gsp64-ssl.ls.apple.com": null,
"gsp64-ssl.ls-apple.com.akadns.net": null,
"mt-ingestion-service-st11.itunes.apple.com": null,
"mt-ingestion-service-st11.itunes-apple.com.akadns.net": null,
"microsoft.com": null,
"mozilla.com": null,
"mozilla.org": null };
var good_da_host_exact_flag = 71 > 0 ? true : false;  // test for non-zero number of rules
    
// 0 rules as an efficient NFA RegExp:
var good_da_host_RegExp = /^$/;
var good_da_host_regex_flag = 0 > 0 ? true : false;  // test for non-zero number of rules

// 0 rules:
var good_da_hostpath_JSON = {  };
var good_da_hostpath_exact_flag = 0 > 0 ? true : false;  // test for non-zero number of rules
    
// 0 rules as an efficient NFA RegExp:
var good_da_hostpath_RegExp = /^$/;
var good_da_hostpath_regex_flag = 0 > 0 ? true : false;  // test for non-zero number of rules
    
// 0 rules as an efficient NFA RegExp:
var good_da_RegExp = /^$/;
var good_da_regex_flag = 0 > 0 ? true : false;  // test for non-zero number of rules

// 39 rules:
var good_da_host_exceptions_JSON = { "iad.apple.com": null,
"iadsdk.apple.com": null,
"iadsdk.apple.com.edgekey.net": null,
"bingads.microsoft.com": null,
"azure.bingads.trafficmanager.net": null,
"choice.microsoft.com": null,
"choice.microsoft.com.nsatc.net": null,
"corpext.msitadfs.glbdns2.microsoft.com": null,
"corp.sts.microsoft.com": null,
"df.telemetry.microsoft.com": null,
"diagnostics.support.microsoft.com": null,
"feedback.search.microsoft.com": null,
"i1.services.social.microsoft.com": null,
"i1.services.social.microsoft.com.nsatc.net": null,
"redir.metaservices.microsoft.com": null,
"reports.wes.df.telemetry.microsoft.com": null,
"services.wes.df.telemetry.microsoft.com": null,
"settings-sandbox.data.microsoft.com": null,
"settings-win.data.microsoft.com": null,
"sqm.df.telemetry.microsoft.com": null,
"sqm.telemetry.microsoft.com": null,
"sqm.telemetry.microsoft.com.nsatc.net": null,
"statsfe1.ws.microsoft.com": null,
"statsfe2.update.microsoft.com.akadns.net": null,
"statsfe2.ws.microsoft.com": null,
"survey.watson.microsoft.com": null,
"telecommand.telemetry.microsoft.com": null,
"telecommand.telemetry.microsoft.com.nsatc.net": null,
"telemetry.urs.microsoft.com": null,
"vortex.data.microsoft.com": null,
"vortex-sandbox.data.microsoft.com": null,
"vortex-win.data.microsoft.com": null,
"cy2.vortex.data.microsoft.com.akadns.net": null,
"watson.microsoft.com": null,
"watson.ppe.telemetry.microsoft.comwatson.telemetry.microsoft.com": null,
"watson.telemetry.microsoft.com.nsatc.net": null,
"wes.df.telemetry.microsoft.com": null,
"win10.ipv6.microsoft.com": null,
"www.bingads.microsoft.com": null };
var good_da_host_exceptions_exact_flag = 39 > 0 ? true : false;  // test for non-zero number of rules

// 3394 rules:
var bad_da_host_JSON = { "api.facebook.com": null,
"badge.facebook.com": null,
"addinto.com": null,
"advantagemedia.com": null,
"affiliates.eblastengine.com": null,
"assets.simplifydigital.co.uk": null,
"ayc0zsm69431gfebd.xyz": null,
"blockmetrics.com": null,
"blogcatalog.com": null,
"blogengage.com": null,
"bloggergreetbox.googlecode.com": null,
"bloglines.com": null,
"blogtopsites.com": null,
"browser-updater.yandex.net": null,
"buzz-stats.com": null,
"celebjihad.com": null,
"chameleon.ad": null,
"complexmedianetwork.com": null,
"connatix.com": null,
"content-recommendation.net": null,
"contentexchange.me": null,
"convertsocial.com": null,
"d15r06k2ko210l.cloudfront.net": null,
"d1uh1a7az90pt0.cloudfront.net": null,
"d2ip7iv1l4ergv.cloudfront.net": null,
"d9etzk30b05yg.cloudfront.net": null,
"devscroll.com": null,
"dhpikd1t89arn.cloudfront.net": null,
"dotmailer-surveys.com": null,
"dotnetkicks.com": null,
"drivenetwork.ru": null,
"eventful.com": null,
"facebookicon.net": null,
"fast.eager.io": null,
"flashgroup.com": null,
"fluidsurveys.com": null,
"freetellafriend.com": null,
"garss.tv": null,
"getmailcounter.com": null,
"getsitecontrol.com": null,
"grvmedia.com": null,
"images.hitwise.co.uk": null,
"informvisitors.com": null,
"jobthread.com": null,
"letsgetsocialnow.com": null,
"mail.advantagebusinessmedia.com": null,
"mailmunch.s3.amazonaws.com": null,
"mixi.media": null,
"moreshare.com": null,
"optimonk.com": null,
"optmnstr.com": null,
"optmstr.com": null,
"partner.dw.com": null,
"phoenix-widget.com": null,
"pinddeals.com": null,
"platform.loyaltylion.com": null,
"plugin.me2day.net": null,
"popin.cc": null,
"privy.com": null,
"pubexchange.com": null,
"rating-widget.com": null,
"sail-horizon.com": null,
"scorespro.com": null,
"screenpopper.com": null,
"scripts.mailfire.io": null,
"secretrune.com": null,
"sendsay.ru": null,
"sharenice.org": null,
"siteswithcontent.com": null,
"sleeknoteboxcontent.sleeknote.com": null,
"smi2.ru": null,
"smiinformeri.online": null,
"snapwidget.com": null,
"sociallist.org": null,
"socialoomph.com": null,
"socialtwist.com": null,
"socialvibe.com": null,
"sodahead.com": null,
"statictapcdn-a.akamaihd.net": null,
"superwidget-assets.gowatchit.com": null,
"surfingbird.ru": null,
"survey.constantcontact.com": null,
"survey.io": null,
"swiftypecdn.com": null,
"thelovebucks.com": null,
"toolbar.avg.com": null,
"toolbar.complex.com": null,
"top100-images.rambler.ru": null,
"top100.ru": null,
"turnsocial.com": null,
"userdatatrust.com": null,
"widget.adviceiq.com": null,
"widget.breakingburner.com": null,
"widget.chipin.com": null,
"widget.clipix.com": null,
"widget.crowdignite.com": null,
"widget.firefeeder.com": null,
"widget.trustpilot.com": null,
"widget.zoorate.com": null,
"widgets.awe.sm": null,
"widgets.backtype.com": null,
"widgets.dzone.com": null,
"widgets.itunes.apple.com": null,
"widgets.seekitlocal.com": null,
"widgets.sprinkletxt.com": null,
"widgets.tapcdn.com": null,
"widgets.tapiture.com": null,
"widgetsplus.com": null,
"wisepops.com": null,
"zergnet.com": null,
"zoomanalytics.co": null,
"taboola.com": null,
"taboolasyndication.com": null,
"amplify.outbrain.com": null,
"hpr.outbrain.com": null,
"newsletter.outbrain.com": null,
"odb.outbrain.com": null,
"outbrainimg.com": null,
"sphere.outbrain.com": null,
"vrp.outbrain.com": null,
"vrt.outbrain.com": null,
"widgets.outbrain.com": null,
"d2r1yp2w7bby2u.cloudfront.net": null,
"getpushmonkey.com": null,
"notification.tubecup.net": null,
"propu.sh": null,
"push-ad.com": null,
"push-money.ru": null,
"push4site.com": null,
"pushiki.ru": null,
"pushpad.xyz": null,
"pushprofit.ru": null,
"realpush.media": null,
"snrcdn.net": null,
"ucfeed.ru": null,
"webpu.sh": null,
"whitepush.biz": null,
"wpush.biz": null,
"wwclicknews.club": null,
"addnow.com": null,
"addthis.com": null,
"addtoany.com": null,
"ahalogy.com": null,
"bshare.cn": null,
"button.spread.ly": null,
"connect.ok.ru": null,
"d5k6iufjynyu8.cloudfront.net": null,
"external.followgram.me": null,
"fanconverter.wetpaint.me": null,
"figshare.com": null,
"filamentapp-assets.s3.amazonaws.com": null,
"filamentapp.s3.amazonaws.com": null,
"followistic.com": null,
"instagramfollowbutton.com": null,
"instawidget.net": null,
"loveclaw.com": null,
"networkedblogs.com": null,
"newsharecounts.com": null,
"opensharecount.com": null,
"platform.foursquare.com": null,
"platform.linkedin.com": null,
"platform.tumblr.com": null,
"plusone.google.com": null,
"reactandshare.com": null,
"readrboard.com": null,
"saywidgets.awe.sm": null,
"search.twitter.com": null,
"share.itraffic.su": null,
"share.pluso.ru": null,
"share.static.skyrock.net": null,
"share.yandex.ru": null,
"shareaholic.com": null,
"sharedcount.com": null,
"shares.api.awe.sm": null,
"sharethis.com": null,
"sharexy.com": null,
"simplesharebuttons.com": null,
"social9.com": null,
"socialannex.com": null,
"socialmarker.com": null,
"socialmediabuttons.com": null,
"socialmediatabs.com": null,
"socialproof.it": null,
"socialrest.com": null,
"socialtools.fm": null,
"static.delicious.com": null,
"toolbar.cdn.gigya.com": null,
"tweetboard.com": null,
"twitcount.com": null,
"twitstat.us": null,
"twitter-badges.s3.amazonaws.com": null,
"twittercounter.com": null,
"twitterforweb.com": null,
"twittericon.com": null,
"twittermysite.com": null,
"usocial.pro": null,
"votes.buzz.yahoo.com": null,
"widget.stagram.com": null,
"widget.weibo.com": null,
"widget.whatshelp.io": null,
"widgets.digg.com": null,
"widgets.fbshare.me": null,
"widgets.getpocket.com": null,
"widgets.itaringa.net": null,
"widgets.twimg.com": null,
"xing-share.com": null,
"ywidgets.awe.sm": null,
"admiral.mgr.consensu.org": null,
"alma-cmp.almamedia.io": null,
"clickio.mgr.consensu.org": null,
"clickiocdn.com": null,
"cmp.nextday.media": null,
"consent.subscriptions.archant.co.uk": null,
"cookie-accept.com": null,
"cookie-script.com": null,
"cookie.support": null,
"cookieassistant.com": null,
"cookiebot.com": null,
"cookiechoices.org": null,
"cookieconsent.silktide.com": null,
"cookieinfoscript.com": null,
"cookielaw.org": null,
"cookiemanager1.contentforces.com": null,
"cookiemonster.is": null,
"cookiepro.com": null,
"cookieq.com": null,
"cookiereports.com": null,
"cookies.innershed.co.uk": null,
"cookiescript.info": null,
"dmgmediaprivacy.co.uk": null,
"gdpr.studybreakmedia.com": null,
"mycookies.it": null,
"optanon.blob.core.windows.net": null,
"sharethis.mgr.consensu.org": null,
"smartadserver.mgr.consensu.org": null,
"smartcookies.it": null,
"trustarc.com": null,
"alerts.thedailystar.net": null,
"forms.windowsitpro.com": null,
"subscriptions.cbc.ca": null,
"tmform.azurewebsites.net": null,
"social.dw.de": null,
"cookie.oup.com": null,
"gdpr.internetbrands.com": null,
"sp.knowyourmeme.com": null,
"traffic.styria.hr": null,
"gnezdo.ru": null,
"mirtesen.ru": null,
"news.net.finam.ru": null,
"static.smi2.net": null,
"top100.rambler.ru": null,
"share.gree.jp": null,
"linkwelove.com": null,
"linkwelove.it": null,
"player.streamshow.it": null,
"reviews.shoppydoo.it": null,
"smiling.video": null,
"videosynd.kataweb.it": null,
"widgets.trustedshops.com": null,
"kodcad.kr": null,
"share.baidu.com": null,
"social-bookmarking-tools.de": null,
"consent.prismamedia.com": null,
"cookies.leadplace.fr": null,
"cookie.vrt.be": null,
"cookie.wieni.be": null,
"cookies.nos.nl": null,
"cookie.aerostatonet.it": null,
"cookies.gardena.net": null,
"cookie.gazeta.pl": null,
"cookies.fakt.pl": null,
"cookies.forbes.pl": null,
"skryptcookies.pl": null,
"cookies.unidadeditorial.es": null,
"123count.com": null,
"168logger.com": null,
"1freecounter.com": null,
"24counter.com": null,
"24log.com": null,
"3dlivestats.com": null,
"3dstats.com": null,
"404tracker.com": null,
"4spoonyexperiment.com": null,
"77tracking.com": null,
"99counters.com": null,
"99stats.com": null,
"a-counters.com": null,
"a4b-tracking.com": null,
"aamsitecertifier.com": null,
"abcstats.com": null,
"absolstats.co.za": null,
"access-analyze.org": null,
"acecounter.com": null,
"acuityplatform.com": null,
"ad-score.com": null,
"ad.gt": null,
"adabra.com": null,
"adalyser.com": null,
"adblade.com": null,
"adblockrelief.com": null,
"adchemix.com": null,
"adchemy-content.com": null,
"adchemy.com": null,
"adclickstats.net": null,
"addfreestats.com": null,
"addlvr.com": null,
"adelixir.com": null,
"adform.net": null,
"adfox.ru": null,
"adgjl13.com": null,
"adgreed.com": null,
"adheart.de": null,
"adhslx.com": null,
"adinsight.co.kr": null,
"adinsight.com": null,
"adinsight.eu": null,
"adinte.jp": null,
"adku.co": null,
"adku.com": null,
"admantx.com": null,
"admaster.com.cn": null,
"admetric.io": null,
"admitad.com": null,
"admother.com": null,
"adobedtm.com": null,
"adobetag.com": null,
"adoftheyear.com": null,
"adoric-om.com": null,
"adpaths.com": null,
"adpies.com": null,
"adprotraffic.com": null,
"adregain.com": null,
"adregain.ru": null,
"adrizer.com": null,
"adrta.com": null,
"adsensedetective.com": null,
"adservicemedia.dk": null,
"adspsp.com": null,
"adsrvx.com": null,
"adswizz.com": null,
"adsymptotic.com": null,
"adtarget.me": null,
"adtelligence.de": null,
"adultblogtoplist.com": null,
"adunity.com": null,
"advanced-web-analytics.com": null,
"advconversion.com": null,
"advertising.com": null,
"adways.com": null,
"adwstats.com": null,
"adxadtracker.com": null,
"adxcel-ec2.com": null,
"adyapper.com": null,
"affilae.com": null,
"affiliateedge.eu": null,
"affiliates-pro.com": null,
"affiliatly.com": null,
"affistats.com": null,
"afsanalytics.com": null,
"agentanalytics.com": null,
"agkn.com": null,
"aidata.io": null,
"aimediagroup.com": null,
"akstat.com": null,
"akstat.io": null,
"alexacdn.com": null,
"alexametrics.com": null,
"alltagcloud.info": null,
"alltracked.com": null,
"alocdn.com": null,
"altastat.com": null,
"amazingcounters.com": null,
"analitits.com": null,
"analoganalytics.com": null,
"analysistools.net": null,
"analytics-egain.com": null,
"analytics-engine.net": null,
"analyticschecker.com": null,
"analyticson.com": null,
"analyticswizard.com": null,
"analytk.com": null,
"angelfishstats.com": null,
"answerscloud.com": null,
"apexstats.com": null,
"appboycdn.com": null,
"apsislead.com": null,
"aqtracker.com": null,
"arena-quantum.co.uk": null,
"athenainstitute.biz": null,
"autoaffiliatenetwork.com": null,
"avastats.com": null,
"awstrack.me": null,
"azalead.com": null,
"b1img.com": null,
"baremetrics.com": null,
"basicstat.com": null,
"bdash-cloud.com": null,
"beacon.kmi-us.com": null,
"beaconstreetservices.com": null,
"beanstalkdata.com": null,
"beencounter.com": null,
"belstat.be": null,
"belstat.com": null,
"belstat.de": null,
"belstat.fr": null,
"belstat.nl": null,
"bettermetrics.co": null,
"bigcattracks.com": null,
"bigstats.net": null,
"bigtracker.com": null,
"bionicclick.com": null,
"bkrtx.com": null,
"bkvtrack.com": null,
"blog-stat.com": null,
"blogmeetsbrand.com": null,
"blogpatrol.com": null,
"blogrankers.com": null,
"blogreaderproject.com": null,
"blogscounter.com": null,
"blogsontop.com": null,
"blogtoplist.com": null,
"blueconic.net": null,
"bluekai.com": null,
"blvdstatus.com": null,
"bmlmedia.com": null,
"botsvisit.com": null,
"bounceexchange.com": null,
"brandlock.io": null,
"brcdn.com": null,
"browser-statistik.de": null,
"btbuckets.com": null,
"btstatic.com": null,
"bubblestat.com": null,
"burstbeacon.com": null,
"c.adroll.com": null,
"c1exchange.com": null,
"c3metrics.com": null,
"c4tracking01.com": null,
"call-tracking.co.uk": null,
"calltrackingmetrics.com": null,
"calltracks.com": null,
"campaigncog.com": null,
"caphyon-analytics.com": null,
"capturemedia.network": null,
"cashburners.com": null,
"cashcount.com": null,
"cdn-net.com": null,
"cdnanalytics.xyz": null,
"cdnmaster.com": null,
"cdntrf.com": null,
"cedexis.com": null,
"celebros-analytics.com": null,
"cformanalytics.com": null,
"cftrack.com": null,
"chartaca.com": null,
"chartbeat.com": null,
"chartbeat.net": null,
"checkstat.nl": null,
"chickensaladandads.com": null,
"chrumedia.com": null,
"circular-counters.com": null,
"ck-cdn.com": null,
"cleananalytics.com": null,
"click-url.com": null,
"click4assistance.co.uk": null,
"clickable.net": null,
"clickaider.com": null,
"clickalyzer.com": null,
"clickbrainiacs.com": null,
"clickcease.com": null,
"clickclick.net": null,
"clickconversion.net": null,
"clickdensity.com": null,
"clickdimensions.com": null,
"clickening.com": null,
"clickferret.com": null,
"clickforensics.com": null,
"clickguard.com": null,
"clickguardian.co.uk": null,
"clickinc.com": null,
"clickmanage.com": null,
"clickmeter.com": null,
"clickonometrics.pl": null,
"clickpathmedia.com": null,
"clickprotector.com": null,
"clickreport.com": null,
"clicksagent.com": null,
"clicksen.se": null,
"clickshift.com": null,
"clickstream.co.za": null,
"clicktale.net": null,
"clicktrack1.com": null,
"clicktracks.com": null,
"clicktrkservices.com": null,
"clickx.io": null,
"clickzs.com": null,
"clickzzs.nl": null,
"clixcount.com": null,
"cloud-exploration.com": null,
"cloud-iq.com": null,
"cloudtracer101.com": null,
"codata.ru": null,
"cogmatch.net": null,
"cognitivematch.com": null,
"collecting.click": null,
"connectif.cloud": null,
"contactmonkey.com": null,
"content-square.net": null,
"content.ad": null,
"contentinsights.com": null,
"contentspread.net": null,
"contentsquare.net": null,
"convergetrack.com": null,
"conversionlogic.net": null,
"convertexperiments.com": null,
"convertro.com": null,
"cooladata.com": null,
"coralogix.com": null,
"coremetrics.com": null,
"countby.com": null,
"counter.gd": null,
"counter.top.kg": null,
"counter160.com": null,
"counterbot.com": null,
"countercentral.com": null,
"countergeo.com": null,
"counterland.com": null,
"counters4u.com": null,
"counterservis.com": null,
"countersforlife.com": null,
"countertracker.com": null,
"counterviews.net": null,
"counting4free.com": null,
"countomat.com": null,
"countz.com": null,
"cpx.to": null,
"cqcounter.com": null,
"craktraffic.com": null,
"crazyclickstats.com": null,
"criteo.net": null,
"crosspixel.net": null,
"crwdcntrl.net": null,
"csdata1.com": null,
"cttracking02.com": null,
"czx5eyk0exbhwp43ya.biz": null,
"dacounter.com": null,
"dailycaller-alerts.com": null,
"dashboard.io": null,
"data-analytics.jp": null,
"databrain.com": null,
"datacaciques.com": null,
"datacoral.com": null,
"datacoral.io": null,
"datadoghq-browser-agent.com": null,
"datafeedfile.com": null,
"datam.com": null,
"datamind.ru": null,
"dataperforma.com": null,
"datasteam.io": null,
"dataxpand.com": null,
"daylogs.com": null,
"dc.tremormedia.com": null,
"decdna.net": null,
"demdex.net": null,
"dialogtech.com": null,
"diffusion-tracker.com": null,
"digitaltarget.ru": null,
"dm-event.net": null,
"dmanalytics1.com": null,
"dmclick.cn": null,
"dmpcounter.com": null,
"dmtracker.com": null,
"dominocounter.net": null,
"dotomi.com": null,
"doubleclick.net": null,
"dstrack2.info": null,
"dwin2.com": null,
"e-contenta.com": null,
"e-webtrack.net": null,
"easy-hit-counter.com": null,
"easy-hit-counters.com": null,
"easycounter.com": null,
"easyhitcounters.com": null,
"ec-track.com": null,
"ecommstats.com": null,
"ecsanalytics.com": null,
"edigitalsurvey.com": null,
"eggplant.cloud": null,
"email-match.com": null,
"embeddedanalytics.com": null,
"emediatrack.com": null,
"emxdgt.com": null,
"engageclick.com": null,
"enquisite.com": null,
"eperfectdata.com": null,
"epiodata.com": null,
"epitrack.com": null,
"eps-analyzer.de": null,
"estat.com": null,
"estrack.net": null,
"etracker.com": null,
"etrafficcounter.com": null,
"eu-survey.com": null,
"euleriancdn.net": null,
"eventcapture03.com": null,
"evisitanalyst.com": null,
"evolvemediametrics.com": null,
"ewebanalytics.com": null,
"ewebcounter.com": null,
"exclusiveclicks.com": null,
"exovueplatform.com": null,
"experianmarketingservices.digital": null,
"explore-123.com": null,
"exponea.com": null,
"exposebox.com": null,
"eyereturn.com": null,
"ezytrack.com": null,
"fandommetrics.com": null,
"fanplayr.com": null,
"fast-thinking.co.uk": null,
"fastanalytic.com": null,
"fastly-analytics.com": null,
"fastly-insights.com": null,
"fastonlineusers.com": null,
"fastwebcounter.com": null,
"fdxstats.xyz": null,
"find-ip-address.org": null,
"fitanalytics.com": null,
"flagcounter.com": null,
"flash-counter.com": null,
"flashadengine.com": null,
"flashgamestats.com": null,
"flashtalking.com": null,
"flcounter.com": null,
"flixsyndication.net": null,
"fluencymedia.com": null,
"followercounter.com": null,
"forkcdn.com": null,
"fpctraffic2.com": null,
"free-counter.co.uk": null,
"free-counter.com": null,
"free-counters.co.uk": null,
"free-website-hit-counters.com": null,
"free-website-statistics.com": null,
"freebloghitcounter.com": null,
"freecountercode.com": null,
"freecounterstat.com": null,
"freegeoip.app": null,
"freegeoip.net": null,
"freehitscounter.org": null,
"freelogs.com": null,
"freeonlineusers.com": null,
"freesitemapgenerator.com": null,
"freestats.com": null,
"freetrafficsystem.com": null,
"freeusersonline.com": null,
"freeweblogger.com": null,
"freshcounter.com": null,
"fuse-data.com": null,
"fusestats.com": null,
"gameanalytics.com": null,
"gatorleads.co.uk": null,
"gbotvisit.com": null,
"geoplugin.net": null,
"getclicky.com": null,
"getfreebl.com": null,
"getsmartcontent.com": null,
"getstatistics.se": null,
"gglscr.online": null,
"gigcount.com": null,
"glbtracker.com": null,
"globalviptraffic.com": null,
"globetrackr.com": null,
"go-mpulse.net": null,
"goadservices.com": null,
"goldstats.com": null,
"goodcounter.org": null,
"googleadservices.com": null,
"googlerank.info": null,
"googletagmanager.com": null,
"gostats.com": null,
"gostats.org": null,
"gostats.ro": null,
"govmetric.com": null,
"grepdata.com": null,
"group-ib.ru": null,
"gsimedia.net": null,
"gstats.cn": null,
"gtopstats.com": null,
"gvisit.com": null,
"halldata.com": null,
"halstats.com": null,
"hdmtools.com": null,
"heapanalytics.com": null,
"hentaicounter.com": null,
"hexagon-analytics.com": null,
"highmetrics.com": null,
"histats.com": null,
"hit-counter-download.com": null,
"hit-counter.info": null,
"hit-counters.net": null,
"hit-counts.com": null,
"hitcounterstats.com": null,
"hitslog.com": null,
"hittracker.com": null,
"hitwebcounter.com": null,
"hivps.xyz": null,
"hmstats.com": null,
"hospitality-optimizer.com": null,
"host-tracker.com": null,
"hostip.info": null,
"hotdogsandads.com": null,
"hotjar.com": null,
"hotlog.ru": null,
"hs-analytics.net": null,
"hsadspixel.net": null,
"humanclick.com": null,
"hunt-leads.com": null,
"hxtrack.com": null,
"hyfntrak.com": null,
"hypestat.com": null,
"i-stats.com": null,
"icstats.nl": null,
"id-visitors.com": null,
"ideoclick.com": null,
"iesnare.com": null,
"igaming.biz": null,
"ilogbox.com": null,
"immanalytics.com": null,
"impactradius-event.com": null,
"impcounter.com": null,
"imrtrack.com": null,
"index.ru": null,
"indexstats.com": null,
"indextools.com": null,
"individuad.net": null,
"inferclick.com": null,
"infinity-tracking.net": null,
"inflectionpointmedia.com": null,
"infoprodata.com": null,
"innovateads.com": null,
"insideall.com": null,
"insitemetrics.com": null,
"instore.biz": null,
"intelli-tracker.com": null,
"intermundomedia.com": null,
"interstateanalytics.com": null,
"invisioncloudstats.com": null,
"invitemedia.com": null,
"iotechnologies.com": null,
"iperceptions.com": null,
"ipinyou.com.cn": null,
"iplocationtools.com": null,
"iproanalytics.com": null,
"ipstat.com": null,
"iqdata.ai": null,
"ist-track.com": null,
"istrack.com": null,
"itracker360.com": null,
"itrackerpro.com": null,
"itracmediav4.com": null,
"iwebtrack.com": null,
"iwstats.com": null,
"janrain.xyz": null,
"jscounter.com": null,
"jstracker.com": null,
"jumplead.com": null,
"jumplead.io": null,
"jwmstats.com": null,
"k-analytix.com": null,
"keymetric.net": null,
"killerwebstats.com": null,
"kissmetrics.com": null,
"knowlead.io": null,
"komtrack.com": null,
"krxd.net": null,
"ladsp.com": null,
"lead-123.com": null,
"lead-converter.com": null,
"leadlab.click": null,
"leadsius.com": null,
"leadsmonitor.io": null,
"leadsrx.com": null,
"legolas-media.com": null,
"les-experts.com": null,
"linksynergy.com": null,
"linkxchanger.com": null,
"listrakbi.com": null,
"litix.io": null,
"livecount.fr": null,
"livestat.com": null,
"livetrafficfeed.com": null,
"localytics.com": null,
"locotrack.net": null,
"logaholic.com": null,
"logbor.com": null,
"logcounter.com": null,
"logdy.com": null,
"logentries.com": null,
"logger.pw": null,
"loggly.com": null,
"logmatic.io": null,
"lognormal.net": null,
"logrocket.com": null,
"logrocket.io": null,
"logsss.com": null,
"losstrack.com": null,
"lxtrack.com": null,
"macandcheeseandads.com": null,
"mailstat.us": null,
"market2lead.com": null,
"marketo.net": null,
"masterstats.com": null,
"matheranalytics.com": null,
"mathtag.com": null,
"matomo.cloud": null,
"maxtracker.net": null,
"mbotvisit.com": null,
"meatballsandads.com": null,
"media01.eu": null,
"mediaarmor.com": null,
"mediaforgews.com": null,
"mediagauge.com": null,
"mediametrics.ru": null,
"mediaplex.com": null,
"mediarithmics.com": null,
"mediaseeding.com": null,
"mediaweaver.jp": null,
"mega-stats.com": null,
"memecounter.com": null,
"metricool.com": null,
"metricsdirect.com": null,
"mfadsrvr.com": null,
"millioncounter.com": null,
"ml314.com": null,
"mlclick.com": null,
"mlstat.com": null,
"mobalyzer.net": null,
"mongoosemetrics.com": null,
"monstat.com": null,
"mousestats.com": null,
"mpianalytics.com": null,
"mpstat.us": null,
"mstat.ga": null,
"mstracker.net": null,
"mtracking.com": null,
"mutinycdn.com": null,
"mvilivestats.com": null,
"mvtracker.com": null,
"mxcdn.net": null,
"myaffiliateprogram.com": null,
"mybloglog.com": null,
"myfastcounter.com": null,
"mynewcounter.com": null,
"myroitracking.com": null,
"myseostats.com": null,
"mysitetraffic.net": null,
"mysocialpixel.com": null,
"mytrack.pro": null,
"mywebstats.com.au": null,
"mywebstats.org": null,
"naturaltracking.com": null,
"ncaudienceexchange.com": null,
"neads.delivery": null,
"neatstats.com": null,
"nedstat.com": null,
"nedstat.net": null,
"nedstatbasic.net": null,
"nedstatpro.net": null,
"netclickstats.com": null,
"nextstat.com": null,
"northstartravelmedia.com": null,
"notifyvisitors.com": null,
"nr-data.net": null,
"nstracking.com": null,
"nuggad.net": null,
"nytlog.com": null,
"ohmystats.com": null,
"omtrdc.net": null,
"ondu.ru": null,
"onecount.net": null,
"onestat.com": null,
"onlinepbx.ru": null,
"openclick.com": null,
"openstat.net": null,
"opentracker.net": null,
"optimahub.com": null,
"optimix.asia": null,
"optimizely.com": null,
"optimost.com": null,
"os-data.com": null,
"osdata.solutions": null,
"ositracker.com": null,
"otracking.com": null,
"ournet-analytics.com": null,
"overstat.com": null,
"owlanalytics.io": null,
"pagefair.com": null,
"paidstats.com": null,
"parklogic.com": null,
"parrable.com": null,
"pclicks.com": null,
"performanceanalyser.net": null,
"performtracking.com": null,
"perimeterx.net": null,
"petametrics.com": null,
"phone-analytics.com": null,
"pi-stats.com": null,
"ping-fast.com": null,
"pixel.ad": null,
"pixel.watch": null,
"pixeleze.com": null,
"pixelinteractivemedia.com": null,
"pixelrevenue.com": null,
"pizzaandads.com": null,
"placemypixel.com": null,
"platformpanda.com": null,
"plugin.ws": null,
"pnstat.com": null,
"polarcdn-pentos.com": null,
"popsample.com": null,
"popt.in": null,
"populr.me": null,
"postaffiliatepro.com": null,
"postclickmarketing.com": null,
"precisioncounter.com": null,
"profilesnitch.com": null,
"projectsunblock.com": null,
"proofpositivemedia.com": null,
"provenpixel.com": null,
"prtracker.com": null,
"pstats.com": null,
"pulselog.com": null,
"purevideo.com": null,
"px-cloud.net": null,
"pzz.events": null,
"q-counter.com": null,
"q-stats.nl": null,
"qsstats.com": null,
"quantcount.com": null,
"quantserve.com": null,
"quantummetric.com": null,
"questradeaffiliates.com": null,
"qzlog.com": null,
"radarstats.com": null,
"rampmetrics.com": null,
"rankingpartner.com": null,
"rapidcounter.com": null,
"rapidstats.net": null,
"rapidtrk.net": null,
"readertracking.com": null,
"real5traf.ru": null,
"realcounter.eu": null,
"realcounters.com": null,
"realtimewebstats.net": null,
"realtracker.com": null,
"realtracking.ninja": null,
"redcounter.net": null,
"redistats.com": null,
"redstatcounter.com": null,
"relead.com": null,
"reliablecounter.com": null,
"remarketingpixel.com": null,
"remarketstats.com": null,
"repixel.co": null,
"research-tool.com": null,
"retargettracker.com": null,
"reztrack.com": null,
"rfksrv.com": null,
"riastats.com": null,
"richmetrics.com": null,
"rightmoveanalytics.co.uk": null,
"ritecounter.com": null,
"rlcdn.com": null,
"rockincontent.net": null,
"roia.biz": null,
"rollingcounters.com": null,
"rumanalytics.com": null,
"rumpelstiltskinhead.com": null,
"s7target.ru": null,
"safe-click.net": null,
"sageanalyst.net": null,
"saletrack.co.uk": null,
"sayutracking.co.uk": null,
"sc-static.net": null,
"scorecardresearch.com": null,
"scoutanalytics.net": null,
"script.ag": null,
"scripts21.com": null,
"scriptshead.com": null,
"sedotracker.com": null,
"segment.com": null,
"sendtraffic.com": null,
"serious-partners.com": null,
"servestats.com": null,
"serving-sys.com": null,
"servustats.com": null,
"sessioncam.com": null,
"sessions.exchange": null,
"sexcounter.com": null,
"sexystat.com": null,
"shareasale.com": null,
"shinystat.com": null,
"shoptimally.com": null,
"showroomlogic.com": null,
"silvergamed.com": null,
"silverpop.com": null,
"simpleanalytics.io": null,
"simplehitcounter.com": null,
"simplereach.com": null,
"site24x7rum.com": null,
"siteapps.com": null,
"sitebro.com": null,
"sitebro.net": null,
"sitebro.tw": null,
"sitecompass.com": null,
"siteimprove.com": null,
"siteimproveanalytics.com": null,
"siteimproveanalytics.io": null,
"sitelabweb.com": null,
"sitelinktrack.com": null,
"sitemeter.com": null,
"sitereport.org": null,
"sitestat.com": null,
"sitestats.live": null,
"sitetag.us": null,
"sitetagger.co.uk": null,
"sitetracker.com": null,
"sitetraq.nl": null,
"skimresources.com": null,
"smallseotools.com": null,
"smartology.co": null,
"smartracker.net": null,
"smileyhost.net": null,
"snapdeal.biz": null,
"snapsmedia.io": null,
"sniperlog.ru": null,
"social-sb.com": null,
"socialhoney.co": null,
"socialprofitmachine.com": null,
"socialtrack.co": null,
"socialtrack.net": null,
"softonic-analytics.net": null,
"sometrics.com": null,
"spamanalyst.com": null,
"sponsored.com": null,
"springmetrics.com": null,
"sprinklecontent.com": null,
"spycounter.net": null,
"spylog.com": null,
"spylog.ru": null,
"squidanalytics.com": null,
"stadsvc.com": null,
"stat-track.com": null,
"stat.social": null,
"stat08.com": null,
"stat24.com": null,
"statcount.com": null,
"statcounter.com": null,
"statcounterfree.com": null,
"stathat.com": null,
"stathound.com": null,
"staticiv.com": null,
"statisfy.net": null,
"statistiche-web.com": null,
"statistx.com": null,
"statowl.com": null,
"statpipe.ru": null,
"stats.cz": null,
"stats2.com": null,
"stats21.com": null,
"stats4all.com": null,
"stats4u.net": null,
"stats4you.com": null,
"statsbox.nl": null,
"statsevent.com": null,
"statsinsight.com": null,
"statsit.com": null,
"statsmachine.com": null,
"statsrely.com": null,
"statssheet.com": null,
"statsw.com": null,
"statswebtown.com": null,
"statsy.net": null,
"stattooz.com": null,
"stattrax.com": null,
"statun.com": null,
"statuncore.com": null,
"stcounter.com": null,
"steadfastsystem.com": null,
"steelhousemedia.com": null,
"stroeerdigitalmedia.de": null,
"summitemarketinganalytics.com": null,
"supercounters.com": null,
"superstats.com": null,
"surfcounters.com": null,
"surfertracker.com": null,
"surveyscout.com": null,
"surveywriter.com": null,
"swfstats.com": null,
"swiss-counter.com": null,
"sxtracking.com": null,
"synthasite.net": null,
"t-analytics.com": null,
"taskanalytics.com": null,
"tcimg.com": null,
"tdstats.com": null,
"terabytemedia.com": null,
"tetoolbox.com": null,
"thecounter.com": null,
"thefreehitcounter.com": null,
"thermstats.com": null,
"threat-analytics.com": null,
"tinycounter.com": null,
"tns-counter.ru": null,
"top100bloggers.com": null,
"top100webshops.com": null,
"top10sportsites.com": null,
"topblogarea.com": null,
"topblogging.com": null,
"topofblogs.com": null,
"topstat.cn": null,
"trace.events": null,
"track-re01.com": null,
"track-server-100.com": null,
"track-web.net": null,
"track2.me": null,
"trackalyzer.com": null,
"trackbar.info": null,
"trackcdn.com": null,
"trackcmp.net": null,
"trackconsole.com": null,
"trackdiscovery.net": null,
"trackeame.com": null,
"trackedlink.net": null,
"trackedweb.net": null,
"trackertest.org": null,
"tracking100.com": null,
"tracking202.com": null,
"trackinglabs.com": null,
"trackingpro.pro": null,
"trackkas.com": null,
"trackmethod.com": null,
"trackmytarget.com": null,
"trackmyusers.com": null,
"trackmyweb.net": null,
"trackonomics.net": null,
"trackset.com": null,
"tracksy.com": null,
"tracktrk.net": null,
"trackvoluum.com": null,
"trackword.biz": null,
"trackyourstats.com": null,
"tradescape.biz": null,
"trafficby.net": null,
"trafficengine.net": null,
"trafficfacts.com": null,
"trafficfuel.com": null,
"trafficjoint.com": null,
"trafficregenerator.com": null,
"trakken.de": null,
"trakzor.com": null,
"treasuredata.com": null,
"trekmedia.net": null,
"trendcounter.com": null,
"trgtcdn.com": null,
"trmnsite.com": null,
"tscounter.com": null,
"tvpixel.com": null,
"twcount.com": null,
"txmoadserver.net": null,
"ub-analytics.com": null,
"ubertracking.info": null,
"upscore.com": null,
"upstats.ru": null,
"uptrendsdata.com": null,
"uralweb.ru": null,
"usabilitytools.com": null,
"user-clicks.com": null,
"v3cdn.net": null,
"vantage-media.net": null,
"vbanalytics.com": null,
"vdna-assets.com": null,
"ventivmedia.com": null,
"video.oms.eu": null,
"videos.oms.eu": null,
"videostat.com": null,
"visibility-stats.com": null,
"visistat.com": null,
"visitor-analytics.io": null,
"visitor-analytics.net": null,
"visitor-track.com": null,
"visitorglobe.com": null,
"visitorinspector.com": null,
"visitorjs.com": null,
"visitorpath.com": null,
"visitorprofiler.com": null,
"visitortracklog.com": null,
"visitorville.com": null,
"visitstats.com": null,
"visitstreamer.com": null,
"visualwebsiteoptimizer.com": null,
"vtracker.net": null,
"w3counter.com": null,
"waframedia9.com": null,
"waplog.net": null,
"we-stats.com": null,
"web-counter.net": null,
"web-stat.com": null,
"web-stat.net": null,
"webclicktracker.com": null,
"webcounter.co.za": null,
"webcounter.ws": null,
"webflowmetrics.com": null,
"webglstats.com": null,
"webiqonline.com": null,
"webleads-tracker.com": null,
"website-hit-counters.com": null,
"websiteceo.com": null,
"websiteonlinecounter.com": null,
"websiteperform.com": null,
"websitewelcome.com": null,
"webstat.com": null,
"webstat.net": null,
"webstat.se": null,
"webstats.com": null,
"webstats4u.com": null,
"webtraffic.se": null,
"webtrafficagents.com": null,
"webtrekk-asia.net": null,
"webtrends-optimize.com": null,
"webtrends.com": null,
"webtrendslive.com": null,
"whackedmedia.com": null,
"whitepixel.com": null,
"whizstats.com": null,
"whoisvisiting.com": null,
"whosclickingwho.com": null,
"wikia-beacon.com": null,
"wildxtraffic.com": null,
"wisetrack.net": null,
"worldflagcounter.com": null,
"worldlogger.com": null,
"wowanalytics.co.uk": null,
"wp-stats.com": null,
"wpdstat.com": null,
"wtstats.com": null,
"wundercounter.com": null,
"x-stat.de": null,
"xtraffstat.com": null,
"xxxcounter.com": null,
"xyztraffic.com": null,
"y-track.com": null,
"ya-counter.ru": null,
"ybotvisit.com": null,
"yext-pixel.com": null,
"ymetrica1.com": null,
"youbora.com": null,
"youborafds01.com": null,
"youboranqs01.com": null,
"your-counter.be": null,
"youramigo.com": null,
"zanox-affiliate.de": null,
"zqtk.net": null,
"zroitracker.com": null,
"1q2w3.website": null,
"2giga.download": null,
"ad-miner.com": null,
"adless.io": null,
"adminer.com": null,
"adplusplus.fr": null,
"adzjzewsma.cf": null,
"aeros01.tk": null,
"aeros02.tk": null,
"aeros08.tk": null,
"ajplugins.com": null,
"aleinvest.xyz": null,
"alemoney.xyz": null,
"analytics.blue": null,
"anybest.host": null,
"anybest.site": null,
"assetscdn.stream": null,
"autologica.ga": null,
"avero.xyz": null,
"baiduccdn1.com": null,
"befirstcdn.com": null,
"berateveng.ru": null,
"cashbeet.com": null,
"cdn-code.host": null,
"cfcdist.loan": null,
"cloudcdn.gdn": null,
"cloudcoins.co": null,
"cloudflane.com": null,
"cloudflareinsights.com": null,
"cpu2cash.link": null,
"cpufan.club": null,
"datasecu.download": null,
"dzizsih.ru": null,
"etacontent.com": null,
"etzbnfuigipwvs.ru": null,
"filmoljupci.com": null,
"flare-analytics.com": null,
"flightsy.win": null,
"freecontent.bid": null,
"freecontent.date": null,
"freecontent.faith": null,
"freecontent.party": null,
"freecontent.science": null,
"freecontent.stream": null,
"freecontent.trade": null,
"g-content.bid": null,
"gay-hotvideo.net": null,
"goldoffer.online": null,
"googleanalytcs.com": null,
"goredirect.party": null,
"gus.host": null,
"hallaert.online": null,
"hashforcash.us": null,
"hashing.win": null,
"hemnes.win": null,
"hostcontent.live": null,
"hostingcloud.faith": null,
"hostingcloud.party": null,
"hostingcloud.racing": null,
"hostingcloud.science": null,
"igg.biz": null,
"ininmacerad.pro": null,
"intellecthosting.net": null,
"investhash.com": null,
"jqassets.download": null,
"jquery-cdn.download": null,
"jqwww.download": null,
"jscdndel.com": null,
"jwduahujge.ru": null,
"lindon-pool.win": null,
"livestatsnet.services": null,
"losital.ru": null,
"mataharirama.xyz": null,
"mine.torrent.pw": null,
"minemytraffic.com": null,
"minerad.com": null,
"minescripts.info": null,
"moneromining.online": null,
"moneroocean.stream": null,
"monkeyminer.net": null,
"nddmcconmqsy.ru": null,
"nextbdom.ru": null,
"nimiq.watch": null,
"onlinereserchstatistics.online": null,
"pampopholf.com": null,
"party-vqgdyvoycc.now.sh": null,
"play.vidzi.tv": null,
"premiumstats.xyz": null,
"proj2018.xyz": null,
"rand.com.ru": null,
"rtb.connatix.com": null,
"site.flashx.": null,
"smartoffer.site": null,
"statdynamic.com": null,
"static-sb.com": null,
"staticsfs.host": null,
"swiftmining.win": null,
"terethat.ru": null,
"thismetric.com": null,
"tidafors.xyz": null,
"traffic.tc-clicks.com": null,
"trk.connatix.com": null,
"uoldid.ru": null,
"videoplayer2.xyz": null,
"vkcdnservice.com": null,
"vuryua.ru": null,
"wasm.stream": null,
"webassembly.stream": null,
"wtmtrack.com": null,
"xfast.host": null,
"breakfastboat.com": null,
"broaddoor.com": null,
"calculatorstatement.com": null,
"carscannon.com": null,
"gulliblecamp.com": null,
"neighborlywatch.com": null,
"steadfastsound.com": null,
"123-counter.de": null,
"24log.de": null,
"4stats.de": null,
"active-tracking.de": null,
"adc-serv.net": null,
"adclear.net": null,
"adcrowd.com": null,
"admeira.ch": null,
"adnz.co": null,
"adquality.ch": null,
"adrank24.de": null,
"adtraxx.de": null,
"adtriba.com": null,
"adzoe.de": null,
"analysis.fi": null,
"analytics.rechtslupe.org": null,
"anormal-tracker.de": null,
"asadcdn.com": null,
"besucherstats.de": null,
"besucherzaehler-counter.de": null,
"blog-o-rama.de": null,
"blog-webkatalog.de": null,
"blogcounter.com": null,
"blogcounter.de": null,
"bloggeramt.de": null,
"bloggerei.de": null,
"blogtraffic.de": null,
"bluecounter.de": null,
"bonuscounter.de": null,
"businessclick.ch": null,
"clickmap.ch": null,
"count.im": null,
"count24.de": null,
"countar.de": null,
"counter-city.de": null,
"counter-go.de": null,
"counter-gratis.com": null,
"counter-kostenlos.info": null,
"counter-kostenlos.net": null,
"counter-treff.de": null,
"counter.de": null,
"counter27.ch": null,
"countercity.de": null,
"countercity.net": null,
"counterlevel.de": null,
"counteronline.de": null,
"counterseite.de": null,
"counterserver.de": null,
"counterstation.de": null,
"counterstatistik.de": null,
"counthis.com": null,
"counti.de": null,
"countino.de": null,
"countit.ch": null,
"countnow.de": null,
"counto.de": null,
"countok.de": null,
"countyou.de": null,
"cptrack.de": null,
"directcounter.de": null,
"dreamcounter.de": null,
"durocount.com": null,
"eanalyzer.de": null,
"easytracking.de": null,
"edococounter.de": null,
"erotikcounter.org": null,
"etracker.de": null,
"etracking24.de": null,
"eurocounter.com": null,
"fastcounter.de": null,
"fixcounter.com": null,
"free-counters.net": null,
"freetracker.biz": null,
"generaltracking.de": null,
"google-rank.org": null,
"gostats.de": null,
"gratis-counter-gratis.de": null,
"hiddencounter.de": null,
"hot-count.com": null,
"hotcounter.de": null,
"ingenioustech.biz": null,
"intelliad.de": null,
"ipcount.net": null,
"keytrack.de": null,
"klamm-counter.de": null,
"kostenlose-counter.com": null,
"leserservice-tracking.de": null,
"losecounter.de": null,
"microcounter.de": null,
"motorpresse-statistik.de": null,
"my-stats.info": null,
"netcounter.de": null,
"netdebit-counter.de": null,
"netzstat.ch": null,
"odoscope.cloud": null,
"optimierung-der-website.de": null,
"ourstats.de": null,
"pageranking-counter.de": null,
"powercount.com": null,
"pr-chart.com": null,
"pr-chart.de": null,
"r.movad.de": null,
"ranking-charts.de": null,
"ranking-counter.de": null,
"refinedads.com": null,
"rightstats.com": null,
"royalcount.de": null,
"scriptil.com": null,
"sedotracker.de": null,
"selfcampaign.com": null,
"semtracker.de": null,
"sitebro.de": null,
"slogantrend.de": null,
"speedcount.de": null,
"speedcounter.net": null,
"speedtracker.de": null,
"sponsorcounter.de": null,
"statistik-gallup.net": null,
"statistiq.com": null,
"stats.de": null,
"stats4free.de": null,
"tagtool.de": null,
"tamedia.ch": null,
"topstat.com": null,
"trafficmaxx.de": null,
"trendcounter.de": null,
"universaltrackingcontainer.com": null,
"urstats.de": null,
"verypopularwebsite.com": null,
"visitor-stats.de": null,
"webkatalog.li": null,
"websitesampling.com": null,
"webtrekk-us.net": null,
"webtrekk.de": null,
"webtrekk.net": null,
"webttracking.de": null,
"wecount4u.com": null,
"xcounter.ch": null,
"xl-counti.com": null,
"zaehler.tv": null,
"ad4m.at": null,
"admo.tv": null,
"adsixmedia.fr": null,
"adthletic.com": null,
"affilizr.com": null,
"air360tracker.net": null,
"analytics-cdiscount.com": null,
"canalstat.com": null,
"casualstat.com": null,
"compteur-visite.com": null,
"count.fr": null,
"countus.fr": null,
"datado.me": null,
"datadome.co": null,
"deliv.lexpress.fr": null,
"ivitrack.com": null,
"kdata.fr": null,
"lead-analytics.biz": null,
"libstat.com": null,
"livestats.fr": null,
"stats.fr": null,
"sync.tv": null,
"tracking.wlscripts.net": null,
"wysistat.com": null,
"call-tracking.by": null,
"99click.com": null,
"ad7.com": null,
"adop.cc": null,
"adskom.com": null,
"adxvip.com": null,
"blog104.com": null,
"blogtw.net": null,
"cdnmaster.cn": null,
"clicki.cn": null,
"cr-nielsen.com": null,
"datamaster.com.cn": null,
"gostats.cn": null,
"ipinyou.com": null,
"lndata.com": null,
"logly.co.jp": null,
"mediav.com": null,
"phpstat.com": null,
"pixanalytics.com": null,
"sitebot.cn": null,
"top-bloggers.com": null,
"youle55.com": null,
"dotmetrics.net": null,
"affilbox.cz": null,
"analights.com": null,
"monkeytracker.cz": null,
"chart.dk": null,
"euroads.dk": null,
"hitcount.dk": null,
"livecounter.dk": null,
"livewebstats.dk": null,
"netstats.dk": null,
"peakcounter.dk": null,
"zipstat.dk": null,
"active24stats.nl": null,
"istats.nl": null,
"mtrack.nl": null,
"mystats.nl": null,
"stealth.nl": null,
"synovite-scripts.com": null,
"traffic4u.nl": null,
"counter.ok.ee": null,
"stat.www.fi": null,
"vihtori-analytics.fi": null,
"lead.im": null,
"mimgoal.com": null,
"mystat.hu": null,
"analytic.rocks": null,
"0stats.com": null,
"avstat.it": null,
"digital-metric.com": null,
"freecounter.it": null,
"freestat.ws": null,
"freestats.biz": null,
"freestats.me": null,
"freestats.net": null,
"freestats.org": null,
"freestats.tk": null,
"freestats.tv": null,
"freestats.ws": null,
"hiperstat.com": null,
"hitcountersonline.com": null,
"laserstat.com": null,
"mwstats.net": null,
"mystat.it": null,
"ninestats.com": null,
"pagerankfree.com": null,
"shinystat.it": null,
"specialstat.com": null,
"statistiche-free.com": null,
"statistiche.it": null,
"statistiche.ws": null,
"statistichegratis.net": null,
"statsforever.com": null,
"superstat.info": null,
"thestat.net": null,
"trackset.it": null,
"vivistats.com": null,
"webads.eu": null,
"whoseesyou.com": null,
"wstatslive.com": null,
"admatrix.jp": null,
"aid-ad.jp": null,
"amoad.com": null,
"analyticsip.net": null,
"blogranking.net": null,
"cetlog.jp": null,
"ec-optimizer.com": null,
"f-counter.jp": null,
"f-counter.net": null,
"i2ad.jp": null,
"keyword-match.com": null,
"mobylog.jp": null,
"owldata.com": null,
"polymorphicads.jp": null,
"r-ad.ne.jp": null,
"rays-counter.com": null,
"rentracks.jp": null,
"smart-counter.net": null,
"smartnews-ads.com": null,
"speee-ad.jp": null,
"trackfeed.com": null,
"adpick.co.kr": null,
"adtive.com": null,
"aicontents.net": null,
"contentsfeed.com": null,
"dawin.tv": null,
"logger.co.kr": null,
"mcloudglobal.com": null,
"statistika.lv": null,
"topsite.lv": null,
"webstatistika.lv": null,
"maxtraffic.com": null,
"stats.lt": null,
"visits.lt": null,
"webstat.no": null,
"persianstat.com": null,
"persianstat.ir": null,
"tinystat.ir": null,
"adschoom.com": null,
"adstat.4u.pl": null,
"caanalytics.com": null,
"clickmatic.pl": null,
"gostats.pl": null,
"inistrack.net": null,
"ngastatic.com": null,
"stat.4u.pl": null,
"stat.pl": null,
"tagcdn.com": null,
"way2traffic.com": null,
"ad5track.com": null,
"rdstation.com.br": null,
"sambaads.com": null,
"profitshare.ro": null,
"retargeting.biz": null,
"statistics.ro": null,
"24log.ru": null,
"3wnp9.ru": null,
"a-counter.com.ua": null,
"a-counter.kiev.ua": null,
"adblockmetrics.ru": null,
"admile.ru": null,
"adx.com.ru": null,
"announcement.ru": null,
"apkonline.ru": null,
"bid.run": null,
"botdetector.ru": null,
"botscanner.com": null,
"cnstats.ru": null,
"cpaevent.ru": null,
"cszz.ru": null,
"directcrm.ru": null,
"e-kuzbass.ru": null,
"faststart.ru": null,
"ftrack.ru": null,
"gdeslon.ru": null,
"gostats.ru": null,
"hitmir.ru": null,
"idntfy.ru": null,
"infostroy.nnov.ru": null,
"inrd.ru": null,
"interakt.ru": null,
"intergid.ru": null,
"iryazan.ru": null,
"kmindex.ru": null,
"leadslabpixels.net": null,
"listtop.ru": null,
"livetex.ru": null,
"logger.su": null,
"logua.com": null,
"logxp.ru": null,
"logz.ru": null,
"lugansk-info.ru": null,
"luxup2.ru": null,
"luxupcdna.com": null,
"luxupcdnc.com": null,
"madnet.ru": null,
"mediaplan.ru": null,
"mediatoday.ru": null,
"mokuz.ru": null,
"musiccounter.ru": null,
"mystat-in.net": null,
"opentracking.ru": null,
"pladform.ru": null,
"pmbox.biz": null,
"quick-counter.net": null,
"retag.xyz": null,
"rutarget.ru": null,
"serating.ru": null,
"site-submit.com.ua": null,
"skylog.kz": null,
"stat-well.com": null,
"stat.media": null,
"stat24.ru": null,
"stattds.club": null,
"tbex.ru": null,
"tnative.ru": null,
"toptracker.ru": null,
"track.cooster.ru": null,
"vidigital.ru": null,
"vira.ru": null,
"volgograd-info.ru": null,
"vologda-info.ru": null,
"warlog.ru": null,
"webtalking.ru": null,
"webturn.ru": null,
"webvisor.ru": null,
"wwgate.ru": null,
"data.caroda.io": null,
"contadordevisitas.es": null,
"contadorvisitasgratis.com": null,
"delidatax.net": null,
"intrastats.com": null,
"adsettings.com": null,
"adten.eu": null,
"adtlgc.com": null,
"adtr.io": null,
"adtraction.com": null,
"brandmetrics.com": null,
"myvisitors.se": null,
"sifomedia.se": null,
"suntcontent.se": null,
"d-stats.com": null,
"tracker.stats.in.th": null,
"onlinewebstat.com": null,
"sitetistik.com": null,
"mediatraffic.com.ua": null,
"mycounter.com.ua": null,
"mycounter.ua": null,
"weblog.com.ua": null,
"zmctrack.net": null,
"amcdn.vn": null,
"gostats.vn": null,
"aan.amazon.com": null,
"acount.alley.ws": null,
"activetracker.activehotels.com": null,
"ad.aloodo.com": null,
"adfox.yandex.ru": null,
"adlog.com.com": null,
"ads-trk.vidible.tv": null,
"ads.bridgetrack.com": null,
"adtrack.calls.net": null,
"aevents.izooto.com": null,
"affiliate.iamplify.com": null,
"affiliate.mediatemple.net": null,
"affiliates.mgmmirage.com": null,
"affiliates.minglematch.com": null,
"affiliates.purevpn.com": null,
"akatracking.esearchvision.com": null,
"alexandria.marfeelcdn.com": null,
"amplifypixel.outbrain.com": null,
"an.yandex.ru": null,
"analytic.pho.fm": null,
"analytic.xingcloud.com": null,
"analyticapi.pho.fm": null,
"analyticcdn.globalmailer.com": null,
"analytics-cms.whitebeard.me": null,
"analytics-production.hapyak.com": null,
"analytics-rhwg.rhcloud.com": null,
"analytics-scripts.cablelabs.com": null,
"analytics-static.ugc.bazaarvoice.com": null,
"analytics.30m.com": null,
"analytics.amakings.com": null,
"analytics.anvato.net": null,
"analytics.apnewsregistry.com": null,
"analytics.atomiconline.com": null,
"analytics.audioeye.com": null,
"analytics.avanser.com.au": null,
"analytics.aweber.com": null,
"analytics.bigcommerce.com": null,
"analytics.brandcrumb.com": null,
"analytics.carambo.la": null,
"analytics.cincopa.com": null,
"analytics.clickpathmedia.com": null,
"analytics.cmg.net": null,
"analytics.codigo.se": null,
"analytics.cohesionapps.com": null,
"analytics.conmio.com": null,
"analytics.convertlanguage.com": null,
"analytics.cynapse.com": null,
"analytics.datahc.com": null,
"analytics.dev.springboardvideo.com": null,
"analytics.developer.riotgames.com": null,
"analytics.dvidshub.net": null,
"analytics.edgekey.net": null,
"analytics.edgesuite.net": null,
"analytics.fairfax.com.au": null,
"analytics.favcy.com": null,
"analytics.foresee.com": null,
"analytics.groupe-seb.com": null,
"analytics.gvim.mobi": null,
"analytics.humanautomation.ai": null,
"analytics.inform.com": null,
"analytics.kaltura.com": null,
"analytics.kapost.com": null,
"analytics.live.com": null,
"analytics.livestream.com": null,
"analytics.mailmunch.co": null,
"analytics.matchbin.com": null,
"analytics.midwesternmac.com": null,
"analytics.mlstatic.com": null,
"analytics.myfinance.com": null,
"analytics.newscred.com": null,
"analytics.onlyonlinemarketing.com": null,
"analytics.ooyala.com": null,
"analytics.optilead.co.uk": null,
"analytics.orenshmu.com": null,
"analytics.paddle.com": null,
"analytics.performable.com": null,
"analytics.photorank.me": null,
"analytics.piksel.com": null,
"analytics.prezly.com": null,
"analytics.prod.aws.ecnext.net": null,
"analytics.r17.com": null,
"analytics.radiatemedia.com": null,
"analytics.recruitics.com": null,
"analytics.reyrey.net": null,
"analytics.rogersmedia.com": null,
"analytics.shareaholic.com": null,
"analytics.sitewit.com": null,
"analytics.sleeknote.com": null,
"analytics.snidigital.com": null,
"analytics.sonymusic.com": null,
"analytics.springboardvideo.com": null,
"analytics.staticiv.com": null,
"analytics.stg.springboardvideo.com": null,
"analytics.strangeloopnetworks.com": null,
"analytics.suggestv.io": null,
"analytics.supplyframe.com": null,
"analytics.themarketiq.com": null,
"analytics.tout.com": null,
"analytics.tribeca.vidavee.com": null,
"analytics.urx.io": null,
"analytics.vanillaforums.com": null,
"analytics.vendemore.com": null,
"analytics.webgains.io": null,
"analytics.websolute.it": null,
"analytics.wildtangent.com": null,
"analytics.witglobal.net": null,
"analytics.worldtable.co": null,
"analytics.yola.net": null,
"analytics.yolacdn.net": null,
"analytics.ziftsolutions.com": null,
"analyticsengine.s3.amazonaws.com": null,
"analyze.full-marke.com": null,
"attributiontrackingga.googlecode.com": null,
"audience.newscgp.com": null,
"audit.median.hu": null,
"awaps.yandex.net": null,
"axislogger.appspot.com": null,
"bat.bing.com": null,
"beacon.affil.walmart.com": null,
"beacon.aimtell.com": null,
"beacon.errorception.com": null,
"beacon.gcion.com": null,
"beacon.gu-web.net": null,
"beacon.heliumnetwork.com": null,
"beacon.indieclick.com": null,
"beacon.livefyre.com": null,
"beacon.nrholding.net": null,
"beacon.riskified.com": null,
"beacon.rum.dynapis.com": null,
"beacon.securestudies.com": null,
"beacon.sojern.com": null,
"beacon.squixa.net": null,
"beacon.statful.com": null,
"beacon.thred.woven.com": null,
"beacon.tingyun.com": null,
"beacon.viewlift.com": null,
"beacon2.indieclick.com": null,
"beacon2.indieclicktv.com": null,
"beacons.brandads.net": null,
"beacons.mediamelon.com": null,
"bid.g.doubleclick.net": null,
"bitdash-reporting.appspot.com": null,
"blip.bizrate.com": null,
"bonsai.internetbrands.com": null,
"bs.yandex.ru": null,
"btn.clickability.com": null,
"btrace.video.qq.com": null,
"business.sharedcount.com": null,
"c.imedia.cz": null,
"c.wen.ru": null,
"c3metrics.medifast1.com": null,
"cadreon.s3.amazonaws.com": null,
"canvas-ping.conduit-data.com": null,
"canvas-usage-v2.conduit-data.com": null,
"caspionlog.appspot.com": null,
"ccexperimentsstatic.oracleoutsourcing.com": null,
"cdn.trafficexchangelist.com": null,
"cdnbigdata.azureedge.net": null,
"cf.overblog.com": null,
"cgicounter.oneandone.co.uk": null,
"cgicounter.puretec.de": null,
"chanalytics.merchantadvantage.com": null,
"chartaca.com.s3.amazonaws.com": null,
"click.appinthestore.com": null,
"click.aristotle.net": null,
"click.rssfwd.com": null,
"clicks.dealer.com": null,
"clicktale.pantherssl.com": null,
"clickthru.lefbc.com": null,
"clicktracker.iscan.nl": null,
"client-analytics.braintreegateway.com": null,
"cloudfront-labs.amazonaws.com": null,
"cm.g.doubleclick.net": null,
"collector.contentexchange.me": null,
"collector.nextguide.tv": null,
"collector.roistat.com": null,
"conversions.genieventures.co.uk": null,
"cookies.livepartners.com": null,
"cookietracker.cloudapp.net": null,
"cookiex.ngd.yahoo.com": null,
"count.asnetworks.de": null,
"count.carrierzone.com": null,
"count.channeladvisor.com": null,
"count.me.uk": null,
"count.paycounter.com": null,
"counter.bloke.com": null,
"counter.cam-content.com": null,
"counter.hyipexplorer.com": null,
"counter.maases.com": null,
"counter.packa2.cz": null,
"counter.pagesview.com": null,
"counter.powweb.com": null,
"counter.rambler.ru": null,
"counter.scribblelive.com": null,
"counter.snackly.co": null,
"counter.sparklit.com": null,
"counter.tldw.me": null,
"counter.top.ge": null,
"counter.yadro.ru": null,
"counters.freewebs.com": null,
"country.yepshare.com": null,
"crta.dailymail.co.uk": null,
"csi.gstatic.com": null,
"ct.pinterest.com": null,
"d.shareaholic.com": null,
"d10gj7yjsfriaj.cloudfront.net": null,
"d10lpsik1i8c69.cloudfront.net": null,
"d11a2fzhgzqe7i.cloudfront.net": null,
"d169bbxks24g2u.cloudfront.net": null,
"d16fk4ms6rqz1v.cloudfront.net": null,
"d16xpr36wrmcmk.cloudfront.net": null,
"d18p8z0ptb8qab.cloudfront.net": null,
"d191y0yd6d0jy4.cloudfront.net": null,
"d1cdnlzf6usiff.cloudfront.net": null,
"d1cerpgff739r9.cloudfront.net": null,
"d1clfvuu2240eh.cloudfront.net": null,
"d1cr9zxt7u0sgu.cloudfront.net": null,
"d1gp8joe0evc8s.cloudfront.net": null,
"d1hi41nc56pmug.cloudfront.net": null,
"d1iazwv1n1tsyi.cloudfront.net": null,
"d1m6l9dfulcyw7.cloudfront.net": null,
"d1qpxk1wfeh8v1.cloudfront.net": null,
"d1r27qvpjiaqj3.cloudfront.net": null,
"d1r55yzuc1b1bw.cloudfront.net": null,
"d1rgnfh960lz2b.cloudfront.net": null,
"d1ros97qkrwjf5.cloudfront.net": null,
"d1t9uctetvi0tu.cloudfront.net": null,
"d1uanozc5el74n.cloudfront.net": null,
"d1xfq2052q7thw.cloudfront.net": null,
"d1z2jf7jlzjs58.cloudfront.net": null,
"d21o24qxwf7uku.cloudfront.net": null,
"d22v2nmahyeg2a.cloudfront.net": null,
"d23p9gffjvre9v.cloudfront.net": null,
"d23pi6hvdpcc5i.cloudfront.net": null,
"d241ujsiy3yht0.cloudfront.net": null,
"d24cze5sab2jwg.cloudfront.net": null,
"d24rtvkqjwgutp.cloudfront.net": null,
"d25ezbwokoefx6.cloudfront.net": null,
"d28g9g3vb08y70.cloudfront.net": null,
"d2cpw6kwpff7n5.cloudfront.net": null,
"d2ibu2ug0mt5qp.cloudfront.net": null,
"d2kdl5wcwrtj90.cloudfront.net": null,
"d2nxi61n77zqpl.cloudfront.net": null,
"d2o67tzzxkqap2.cloudfront.net": null,
"d2oh4tlt9mrke9.cloudfront.net": null,
"d2ry9vue95px0b.cloudfront.net": null,
"d2san7t27xb2pn.cloudfront.net": null,
"d2tcg4i9q4js4a.cloudfront.net": null,
"d2tgfbvjf3q6hn.cloudfront.net": null,
"d2xgf76oeu9pbh.cloudfront.net": null,
"d303e3cdddb4ded4b6ff495a7b496ed5.s3.amazonaws.com": null,
"d34ko97cxuv4p7.cloudfront.net": null,
"d36lvucg9kzous.cloudfront.net": null,
"d3a2okcloueqyx.cloudfront.net": null,
"d3cxv97fi8q177.cloudfront.net": null,
"d3iouejux1os58.cloudfront.net": null,
"d3kyk5bao1crtw.cloudfront.net": null,
"d3l3lkinz3f56t.cloudfront.net": null,
"d3mskfhorhi2fb.cloudfront.net": null,
"d3n6i6eorggdxk.cloudfront.net": null,
"d3ojzyhbolvoi5.cloudfront.net": null,
"d3q7vxy7usqoub.cloudfront.net": null,
"d3qxwzhswv93jk.cloudfront.net": null,
"d3r7h55ola878c.cloudfront.net": null,
"d3s7ggfq1s6jlj.cloudfront.net": null,
"d3sbxpiag177w8.cloudfront.net": null,
"d3tglifpd8whs6.cloudfront.net": null,
"d4ax0r5detcsu.cloudfront.net": null,
"d6jkenny8w8yo.cloudfront.net": null,
"d81mfvml8p5ml.cloudfront.net": null,
"d8rk54i4mohrb.cloudfront.net": null,
"dadi.technology": null,
"daq0d0aotgq0f.cloudfront.net": null,
"data.alexa.com": null,
"data.circulate.com": null,
"data.gosquared.com": null,
"data.imakenews.com": null,
"data.marketgid.com": null,
"data.minute.ly": null,
"data.queryly.com": null,
"data.studybreakmedia.com": null,
"data2.gosquared.com": null,
"datadog-service.mvfglobal.com": null,
"dc8na2hxrj29i.cloudfront.net": null,
"dc8xl0ndzn2cb.cloudfront.net": null,
"dd6zx4ibq538k.cloudfront.net": null,
"demandmedia.s3.amazonaws.com": null,
"dfanalytics.dealerfire.com": null,
"diagnose.igstatic.com": null,
"djibeacon.djns.com": null,
"djtflbt20bdde.cloudfront.net": null,
"dl1d2m8ri9v3j.cloudfront.net": null,
"dlvkf5067xruv.cloudfront.net": null,
"dn34cbtcv9mef.cloudfront.net": null,
"dna8twue3dlxq.cloudfront.net": null,
"dnn506yrbagrg.cloudfront.net": null,
"doug1izaerwt3.cloudfront.net": null,
"dt1pxsve3tgas.cloudfront.net": null,
"du4rq1xqh3i1k.cloudfront.net": null,
"du8783wkf05yr.cloudfront.net": null,
"dufue2m4sondk.cloudfront.net": null,
"duu8lzqdm8tsz.cloudfront.net": null,
"dxwgpw0lkcum5.cloudfront.net": null,
"dy2xcjk8s1dbz.cloudfront.net": null,
"dymlo6ffhj97l.cloudfront.net": null,
"dzmxze7hxwn6b.cloudfront.net": null,
"ebay.northernhost.com": null,
"ecommstats.s3.amazonaws.com": null,
"event-api.contactatonce.co.uk": null,
"event-api.contactatonce.com.au": null,
"event-api.contactatonce.com": null,
"event-listener.air.tv": null,
"event.api.drift.com": null,
"event.getblue.io": null,
"eventapi.libring.com": null,
"eventgateway.soundcloud.com": null,
"eventlog.inspsearchapi.com": null,
"events.air.tv": null,
"events.antenna.is": null,
"events.apester.com": null,
"events.demoup.com": null,
"events.izooto.com": null,
"events.jotform.com": null,
"events.launchdarkly.com": null,
"events.medio.com": null,
"events.ocdn.eu": null,
"events.realgravity.com": null,
"events.tubecup.org": null,
"events.whisk.com": null,
"events.yourcx.io": null,
"eventtracker.videostrip.com": null,
"experience.contextly.com": null,
"fast.appcues.com": null,
"filament-stats.herokuapp.com": null,
"flashstats.libsyn.com": null,
"fog.pixual.co": null,
"future-fie-assets.co.uk": null,
"g2insights-cdn.azureedge.net": null,
"ga-beacon.appspot.com": null,
"ga.kvideo.io": null,
"geo.q5media.net": null,
"glogger.inspcloud.com": null,
"gsp1.baidu.com": null,
"gtrk.s3.amazonaws.com": null,
"gu-pix.appspot.com": null,
"hawkeye-data-production.sciencemag.org.s3-website-us-east-1.amazonaws.com": null,
"hello.staticstuff.net": null,
"hit-pool.upscore.io": null,
"hits.dealer.com": null,
"hm.baidu.com": null,
"hop.clickbank.net": null,
"ib.adnxs.com": null,
"imp.affiliator.com": null,
"imp.clickability.com": null,
"informer.yandex.ru": null,
"insight.rapid7.com": null,
"insights.sitesearch360.com": null,
"insitez.blob.core.windows.net": null,
"itracking.fccinteractive.com": null,
"javascriptcounter.appspot.com": null,
"js-agent.newrelic.com": null,
"k.streamrail.com": null,
"kalstats.kaltura.com": null,
"l.ooyala.com": null,
"l.player.ooyala.com": null,
"l.sharethis.com": null,
"leadtracking.plumvoice.com": null,
"livecounter.theyosh.nl": null,
"livestats.kaltura.com": null,
"log.aimtell.com": null,
"log.artipbox.net": null,
"log.invodo.com": null,
"log.kcisa.kr": null,
"log.kibboko.com": null,
"log.kukuplay.com": null,
"log.mediacategory.com": null,
"log.olark.com": null,
"log.outbrain.com": null,
"log.outbrainimg.com": null,
"log.pinterest.com": null,
"log.seekda.com": null,
"log000.goo.ne.jp": null,
"logger.snackly.co": null,
"logging.carambo.la": null,
"logging.prefixbox.com": null,
"loggingapi.spingo.com": null,
"loglady.skypicker.com": null,
"logs-api.shoprunner.com": null,
"logs.spilgames.com": null,
"logs.thebloggernetwork.com": null,
"logs.vmixcore.com": null,
"loxodo-analytics.ext.nile.works": null,
"lunametrics.wpengine.netdna-cdn.com": null,
"m.addthisedge.com": null,
"magnify360-cdn.s3.amazonaws.com": null,
"mc.yandex.ru": null,
"mediametrics.mpsa.com": null,
"metric.nwsource.com": null,
"metrics-api.dimensions.ai": null,
"metrics-api.librato.com": null,
"metrics.api.drift.com": null,
"metrics.brightcove.com": null,
"metrics.ctvdigital.net": null,
"metrics.el-mundo.net": null,
"metrics.feedroom.com": null,
"metrics.readme.io": null,
"metrics.scribblelive.com": null,
"metrics.seenon.com": null,
"metrics.sonymusicd2c.com": null,
"metrics.toptenreviews.com": null,
"metrics.upcload.com": null,
"metrics.wikinvest.com": null,
"mormont.gamer-network.net": null,
"myscoop-tracking.googlecode.com": null,
"neocounter.neoworx-blog-tools.net": null,
"newsanalytics.com.au": null,
"nol.yahoo.com": null,
"o.addthis.com": null,
"octopart-analytics.com": null,
"om.rogersmedia.com": null,
"onespot-tracking.herokuapp.com": null,
"optimizely.appspot.com": null,
"p.adbrn.com": null,
"pages-stats.rbl.ms": null,
"partner.cynapse.com": null,
"perr.h-cdn.com": null,
"pix.impdesk.com": null,
"pix.speedbit.com": null,
"pixel-a.basis.net": null,
"pixel.blivenyc.com": null,
"pixel.cdnwidget.com": null,
"pixel.condenastdigital.com": null,
"pixel.fanbridge.com": null,
"pixel.glimr.io": null,
"pixel.newscred.com": null,
"pixel.roymorgan.com": null,
"pixel.s3xified.com": null,
"pixel.solvemedia.com": null,
"pixel.sprinklr.com": null,
"pixel.tree.com": null,
"pixel.widgetly.com": null,
"pixel.wp.com": null,
"pixel.xmladfeed.com": null,
"pixel.yabidos.com": null,
"pixel.yola.com": null,
"platform.communicatorcorp.com": null,
"platform.iteratehq.com": null,
"pmetrics.performancing.com": null,
"postpixel.vindicosuite.com": null,
"pr.blogflux.com": null,
"providence.voxmedia.com": null,
"prstats.postrelease.com": null,
"pt.crossmediaservices.com": null,
"pt.ispot.tv": null,
"ptracker.nurturehq.com": null,
"ptsc.shoplocal.com": null,
"pub.sheknows.com": null,
"pulsar.ebay.com": null,
"px.excitedigitalmedia.com": null,
"px.owneriq.net": null,
"qubitanalytics.appspot.com": null,
"r.mail.ru": null,
"r.msn.com": null,
"rc.rlcdn.com": null,
"rich-agent.s3.amazonaws.com": null,
"rtt.campanja.com": null,
"rva.outbrain.com": null,
"s.clickability.com": null,
"s3-tracking.synthasite.net.s3.amazonaws.com": null,
"scout.haymarketmedia.com": null,
"scripts.psyma.com": null,
"seg.sharethis.com": null,
"segments.adap.tv": null,
"sftrack.searchforce.net": null,
"shared.65twenty.com": null,
"shopnetic.com": null,
"speedtrap.shopdirect.com": null,
"st.cdnco.us": null,
"stas.outbrain.com": null,
"stat.boredomtherapy.com": null,
"stat.glaze.ai": null,
"stat.mixi.media": null,
"stat.moevideo.net": null,
"stat.pladform.ru": null,
"stat.segitek.hu": null,
"stat.web-regie.com": null,
"statdb.pressflex.com": null,
"static.parsely.com": null,
"statistics.tattermedia.com": null,
"statistics.wibiya.com": null,
"statm.the-adult-company.com": null,
"stats-messages.gifs.com": null,
"stats-newyork1.bloxcms.com": null,
"stats.big-boards.com": null,
"stats.bitgravity.com": null,
"stats.bluebillywig.com": null,
"stats.cdn.pfn.bz": null,
"stats.clickability.com": null,
"stats.cloudwp.io": null,
"stats.cmcigroup.com": null,
"stats.datahjaelp.net": null,
"stats.dice.com": null,
"stats.edicy.com": null,
"stats.g.doubleclick.net": null,
"stats.geegain.com": null,
"stats.gifs.com": null,
"stats.heyoya.com": null,
"stats.highwire.com": null,
"stats.inergizedigitalmedia.com": null,
"stats.itweb.co.za": null,
"stats.kaltura.com": null,
"stats.lotlinx.com": null,
"stats.mituyu.com": null,
"stats.nebula.fi": null,
"stats.netbopdev.co.uk": null,
"stats.olark.com": null,
"stats.ozwebsites.biz": null,
"stats.polldaddy.com": null,
"stats.sa-as.com": null,
"stats.sawlive.tv": null,
"stats.shopify.com": null,
"stats.smartclip.net": null,
"stats.topofblogs.com": null,
"stats.twistage.com": null,
"stats.viddler.com": null,
"stats.webs.com": null,
"stats.webstarts.com": null,
"stats.wp.com": null,
"stats.wpmucdn.com": null,
"stats.zotabox.com": null,
"stats1.tune.pk": null,
"stats2.tune.pk": null,
"stats3.unrulymedia.com": null,
"statsadv.dadapro.com": null,
"statsapi.screen9.com": null,
"statsd.zmags.com": null,
"statsdev.treesd.com": null,
"statt-collect.herokuapp.com": null,
"stg-data-collector.playbuzz.com": null,
"su.addthis.com": null,
"survey.interquest.com": null,
"surveywall-api.survata.com": null,
"sync.adap.tv": null,
"t.a3cloud.net": null,
"t.brand-server.com": null,
"t.sharethis.com": null,
"t.smile.eu": null,
"t2.t2b.click": null,
"tag.aticdn.net": null,
"tag.brandcdn.com": null,
"tagger.opecloud.com": null,
"tags.cdn.circlesix.co": null,
"tags.master-perf-tools.com": null,
"tags.newscgp.com": null,
"target.mixi.media": null,
"tcheck.outbrainimg.com": null,
"te.supportfreecontent.com": null,
"telemetry.soundcloud.com": null,
"thetradedesk-tags.s3.amazonaws.com": null,
"tl.tradetracker.net": null,
"tm.tradetracker.net": null,
"top-fwz1.mail.ru": null,
"tr.cloud-media.fr": null,
"tr.connatix.com": null,
"tra.scds.pmdstatic.net": null,
"track.99acres.com": null,
"track.addevent.com": null,
"track.atgstores.com": null,
"track.atom-data.io": null,
"track.bannedcelebs.com": null,
"track.contently.com": null,
"track.cordial.io": null,
"track.did-it.com": null,
"track.digitalriver.com": null,
"track.juno.com": null,
"track.leadin.com": null,
"track.mailerlite.com": null,
"track.mycliplister.com": null,
"track.omg2.com": null,
"track.pricespider.com": null,
"track.qcri.org": null,
"track.qoof.com": null,
"track.searchignite.com": null,
"track.securedvisit.com": null,
"track.shop2market.com": null,
"track.sitetag.us": null,
"track.social.com": null,
"track.spots.im": null,
"track.sprinklecontent.com": null,
"track.strife.com": null,
"track.tcppu.com": null,
"track.td3x.com": null,
"track.uc.cn": null,
"track.untd.com": null,
"track.vdo.ai": null,
"track.vscash.com": null,
"track.wayin.com": null,
"track.written.com": null,
"track.yfret.com": null,
"track.yieldsoftware.com": null,
"tracker.affirm.com": null,
"tracker.beezup.com": null,
"tracker.data-vp.com": null,
"tracker.downdetector.com": null,
"tracker.financialcontent.com": null,
"tracker.icerocket.com": null,
"tracker.iqnomy.com": null,
"tracker.keywordintent.com": null,
"tracker.marinsoftware.com": null,
"tracker.neon-images.com": null,
"tracker.roitesting.com": null,
"tracker.softcube.com": null,
"tracker.timesgroup.com": null,
"tracker.twenga.": null,
"tracker.wpserveur.net": null,
"trackerapi.truste.com": null,
"trackicollect.ibase.fr": null,
"tracking.adalyser.com": null,
"tracking.aegpresents.com": null,
"tracking.badgeville.com": null,
"tracking.brandmentions.com": null,
"tracking.customerly.io": null,
"tracking.dealerwebwatcher.com": null,
"tracking.drsfostersmith.com": null,
"tracking.dsmmadvantage.com": null,
"tracking.edvisors.com": null,
"tracking.ehavior.net": null,
"tracking.fanbridge.com": null,
"tracking.fccinteractive.com": null,
"tracking.feedperfect.com": null,
"tracking.fits.me": null,
"tracking.g2crowd.com": null,
"tracking.godatafeed.com": null,
"tracking.interweave.com": null,
"tracking.jotform.com": null,
"tracking.keywee.co": null,
"tracking.leadlander.com": null,
"tracking.legacyoffers.com": null,
"tracking.lengow.com": null,
"tracking.listhub.net": null,
"tracking.livingsocial.com": null,
"tracking.maxcdn.com": null,
"tracking.monsido.com": null,
"tracking.musixmatch.com": null,
"tracking.pacharge.com": null,
"tracking.plattformad.com": null,
"tracking.plinga.de": null,
"tracking.practicefusion.com": null,
"tracking.quillion.com": null,
"tracking.quisma.com": null,
"tracking.rapidape.com": null,
"tracking.rightmessage.com": null,
"tracking.searchmarketing.com": null,
"tracking.sembox.it": null,
"tracking.skyword.com": null,
"tracking.sokrati.com": null,
"tracking.sponsorpay.com": null,
"tracking.synthasite.net": null,
"tracking.target2sell.com": null,
"tracking.thehut.net": null,
"tracking.waterfrontmedia.com": null,
"tracking.worldmedia.net": null,
"tracking1.brandmentions.com": null,
"tracking2.channeladvisor.com": null,
"trackingapi.cloudapp.net": null,
"trackla.stackla.com": null,
"traffic.acwebconnecting.com": null,
"traffic.prod.cobaltgroup.com": null,
"traffic.shareaholic.com": null,
"trafficfuelpixel.s3-us-west-2.amazonaws.com": null,
"trakksocial.googlecode.com": null,
"tree-pixel-log.s3.amazonaws.com": null,
"trf.intuitwebsites.com": null,
"trk.cloudsna.com": null,
"trk.vindicosuite.com": null,
"ts.tradetracker.net": null,
"ttdetect.staticimgfarm.com": null,
"ucounter.ucoz.net": null,
"urc.taboolasyndication.com": null,
"v.shopify.com": null,
"video-ad-stats.googlesyndication.com": null,
"videoevents.outbrain.com": null,
"visit.geocities.com": null,
"visit.webhosting.yahoo.com": null,
"vmstats.varrando.com": null,
"vtracking.in.com": null,
"weblog.livesport.eu": null,
"weblogger-dynamic-lb.playdom.com": null,
"webservices.websitepros.com": null,
"webstats.motigo.com": null,
"webstats.thaindian.com": null,
"webtracker.apicasystem.com": null,
"wibiya-actions.conduit-data.com": null,
"wibiya-june-new-log.conduit-data.com": null,
"widget.perfectmarket.com": null,
"widget.quantcast.com": null,
"win.staticstuff.net": null,
"wstat.wibiya.com": null,
"zdlogs.sphereup.com": null,
"clarium.global.ssl.fastly.net": null,
"analytics.cnd-motionmedia.de": null,
"analytics.gameforge.de": null,
"analytics.loop-cloud.de": null,
"analytics.pinpoll.com": null,
"analytics.praetor.im": null,
"cdntrf.de": null,
"cgicounter.onlinehome.de": null,
"counter.1i.kz": null,
"counter.blogoscoop.net": null,
"counter.webmart.de": null,
"d.adrolays.de": null,
"d.omsnative.de": null,
"data.econa.com": null,
"events.kaloo.ga": null,
"gocp.stroeermediabrands.de": null,
"insights.blogfoster.com": null,
"js.stroeermediabrands.de": null,
"log.worldsoft-cms.info": null,
"px.staticfiles.at": null,
"retrack.q-divisioncdn.de": null,
"stat.clichehosting.de": null,
"stat4.edev.at": null,
"statistics.klicktel.de": null,
"statistik.motorpresse.de": null,
"statistik.simaja.de": null,
"stats.blogoscoop.net": null,
"stats.clickforknowledge.com": null,
"stats.digital-natives.de": null,
"stats.fittkaumaass.de": null,
"stats.frankfurterneuepresse.de": null,
"stats.united-domains.de": null,
"stats.urban-media.com": null,
"stats2.algo.at": null,
"track2.dulingo.com": null,
"track2.mycliplister.com": null,
"tracker.euroweb.net": null,
"tracker.winload.de": null,
"tracking.base.de": null,
"tracking.emsmobile.de": null,
"tracking.gameforge.de": null,
"tracking.hannoversche.de": null,
"tracking.hi-pi.com": null,
"tracking.ladies.de": null,
"tracking.mindshare.de": null,
"tracking.netzathleten-media.de": null,
"tracking.promiflash.de": null,
"tracking.rtl.de": null,
"tracking.s24.com": null,
"tracking.srv2.de": null,
"tracking.webtradecenter.com": null,
"urtracker.q-sis.de": null,
"webcounter.goweb.de": null,
"webstatistik.odav.de": null,
"x.bloggurat.net": null,
"affiliation.planethoster.info": null,
"analytics.freespee.com": null,
"analytics.grupogodo.com": null,
"analytics.ladmedia.fr": null,
"analytics.valiuz.com": null,
"bbtrack.net": null,
"btstats.devtribu.fr": null,
"cdn-analytics.ladmedia.fr": null,
"collect.adback.co": null,
"compteur.websiteout.net": null,
"events.sk.ht": null,
"piximedia.com": null,
"stat.prsmedia.fr": null,
"stats-dc1.frz.io": null,
"stats.buzzea.com": null,
"stats.ipmgroup.be": null,
"stats.tipser.com": null,
"track.byzon.swelen.net": null,
"track.kyoads.com": null,
"track.laredoute.fr": null,
"trackcustomer.laredoute.com": null,
"tracking.ecookie.fr": null,
"tracking.kdata.fr": null,
"tracking.netvigie.com": null,
"trk.adbutter.net": null,
"visitping.rossel.be": null,
"analytics.styria.hr": null,
"analytics.21cn.com": null,
"analytics.meituan.net": null,
"atanx.alicdn.com": null,
"beacon.sina.com.cn": null,
"bzclk.baidu.com": null,
"cdn.hiido.cn": null,
"click.bokecc.com": null,
"cms.grandcloud.cn": null,
"counter.pixplug.in": null,
"d17m68fovwmgxj.cloudfront.net": null,
"dup.baidustatic.com": null,
"g.yccdn.com": null,
"haostat.qihoo.com": null,
"hyrankhit.meldingcloud.com": null,
"imp.ad-plus.cn": null,
"log.hiiir.com": null,
"log.tagtic.cn": null,
"pos.baidu.com": null,
"stat.ws.126.net": null,
"tce.alicdn.com": null,
"track.ra.icast.cn": null,
"tracking.cat898.com": null,
"v.emedia.cn": null,
"tracking.vid4u.org": null,
"bisko.mall.tv": null,
"counter.cnw.cz": null,
"fimg-resp.seznam.cz": null,
"h.imedia.cz": null,
"i.imedia.cz": null,
"log.idnes.cz": null,
"pixel.cpex.cz": null,
"stat.cncenter.cz": null,
"stat.ringier.cz": null,
"track.leady.cz": null,
"counter.nope.dk": null,
"log.ecgh.dk": null,
"statistics.jfmedier.dk": null,
"ubt.berlingskemedia.net": null,
"analytics.belgacom.be": null,
"cookies.reedbusiness.nl": null,
"hottraffic.nl": null,
"statistics.rbi-nl.com": null,
"counter.zone.ee": null,
"inpref.s3.amazonaws.com": null,
"analytics.dol.gr": null,
"analyticsv2.dol.gr": null,
"rum.marquardmedia.hu": null,
"videostat-new.index.hu": null,
"videostat.index.hu": null,
"analytics.bhaskar.com": null,
"analytics.competitoor.com": null,
"analytics00.meride.tv": null,
"click.kataweb.it": null,
"counter.ksm.it": null,
"counter2.condenast.it": null,
"d32hwlnfiv2gyn.cloudfront.net": null,
"encoderfarmstatsnew.servicebus.windows.net": null,
"fcstats.altervista.org": null,
"livestats.matrix.it": null,
"log.superweb.ws": null,
"logger.kataweb.it": null,
"nanostats.nanopress.it": null,
"rcsmetrics.it": null,
"sem.triboomedia.it": null,
"stat.acca.it": null,
"stat.freetool.it": null,
"stats.itsol.it": null,
"stats.rcsobjects.it": null,
"stats.technopia.it": null,
"tag.triboomedia.it": null,
"track.adintend.com": null,
"track.cedsdigital.it": null,
"track.veedio.it": null,
"track.youniversalmedia.com": null,
"tracker.bestshopping.com": null,
"tracker.iltrovatore.it": null,
"tracking.conversion-lab.it": null,
"tracking.trovaprezzi.it": null,
"tracks.arubamediamarketing.it": null,
"analysis.shinobi.jp": null,
"analyzer51.fc2.com": null,
"asumi.shinobi.jp": null,
"clickanalyzer.jp": null,
"counter2.blog.livedoor.com": null,
"imgstat.ameba.jp": null,
"l.popin.cc": null,
"log.nordot.jp": null,
"omt.shinobi.jp": null,
"rcm.shinobi.jp": null,
"speee-ad.akamaized.net": null,
"sync.shinobi.jp": null,
"track.thebase.in": null,
"webtracker.jp": null,
"x9.shinobi.jp": null,
"log.cizion.com": null,
"teralog.techhub.co.kr": null,
"tracking.adweb.co.kr": null,
"counter.hackers.lv": null,
"engage-cdn.schibsted.media": null,
"analytics.aasaam.com": null,
"analytics.ceneo.pl": null,
"analytics.greensender.pl": null,
"marketing.tr.netsalesmedia.pl": null,
"pixel.homebook.pl": null,
"scontent.services.tvn.pl": null,
"stats.asp24.pl": null,
"stats.media.onet.pl": null,
"stats.ulixes.pl": null,
"statystyki.panelek.com": null,
"track.omgpl.com": null,
"tracking.novem.pl": null,
"events.chaordicsystems.com": null,
"track.e7r.com.br": null,
"webstats.sapo.pt": null,
"a.pr-cy.ru": null,
"1l-hit.mail.ru": null,
"awaps.yandex.ru": null,
"banstat.nadavi.net": null,
"cnstats.cdev.eu": null,
"cnt.logoslovo.ru": null,
"cnt.nov.ru": null,
"cnt.rambler.ru": null,
"cnt.rate.ru": null,
"count.yandeg.ru": null,
"counter.insales.ru": null,
"counter.megaindex.ru": null,
"counter.nn.ru": null,
"counter.photopulse.ru": null,
"counter.pr-cy.ru": null,
"counter.rian.ru": null,
"counter.star.lg.ua": null,
"counter.tovarro.com": null,
"counter.wapstart.ru": null,
"crm-analytics.imweb.ru": null,
"error.videonow.ru": null,
"mediator.mail.ru": null,
"metrics.aviasales.ru": null,
"montblanc.rambler.ru": null,
"piper.amocrm.ru": null,
"rbc.magna.ru": null,
"s.agava.ru": null,
"scnt.rambler.ru": null,
"scounter.rambler.ru": null,
"service-stat.tbn.ru": null,
"stat.eagleplatform.com": null,
"stat.radar.imgsmail.ru": null,
"stat.rum.cdnvideo.ru": null,
"stat.sputnik.ru": null,
"stat.tvigle.ru": null,
"stats.seedr.com": null,
"target.mirtesen.ru": null,
"target.smi2.ru": null,
"tbe.tom.ru": null,
"telemetry.jivosite.com": null,
"tms-st.cdn.ngenix.net": null,
"top.elec.ru": null,
"track.recreativ.ru": null,
"tracking.i-vengo.com": null,
"tracking.retailrocket.net": null,
"upstats.yadro.ru": null,
"webtrack.biz": null,
"stat.ringier.sk": null,
"analitica.webrpp.com": null,
"analytics.epi.es": null,
"g-stats.openhost.es": null,
"pixel.zumby.io": null,
"stats.miarroba.info": null,
"tracker.thinkindot.com": null,
"counter.mtgnewmedia.se": null,
"stat.matichon.co.th": null,
"hit.dogannet.tv": null,
"counter.opinion.com.ua": null,
"aax-us-iad.amazon.com": null,
"abeagle-public.buzzfeed.com": null,
"acookie.alibaba.com": null,
"adc-js.nine.com.au": null,
"adc.9news.com.au": null,
"adc.api.nine.com.au": null,
"adc.nine.com.au": null,
"adv.drtuber.com": null,
"advancedtracker.appspot.com": null,
"affiliate.mercola.com": null,
"affiliate.resellerclub.com": null,
"affiliates.genealogybank.com": null,
"affiliates.londonmarketing.com": null,
"affiliates.mozy.com": null,
"affiliates.myfax.com": null,
"affiliates.treasureisland.com": null,
"affiliates.vpn.ht": null,
"agg.lifedaily.com": null,
"ai.inmdata.io": null,
"analytic.imlive.com": null,
"analytics.adfreetime.com": null,
"analytics.archive.org": null,
"analytics.bloomberg.com": null,
"analytics.brave.com": null,
"analytics.chase.com": null,
"analytics.ecosia.org": null,
"analytics.eip.telegraph.co.uk": null,
"analytics.getshogun.com": null,
"analytics.global.sky.com": null,
"analytics.gorillanation.com": null,
"analytics.hindustantimes.com": null,
"analytics.ifood.tv": null,
"analytics.iraiser.eu": null,
"analytics.islamicfinder.org": null,
"analytics.jabong.com": null,
"analytics.kaggle.io": null,
"analytics.localytics.com": null,
"analytics.meaww.com": null,
"analytics.mindjolt.com": null,
"analytics.mouthshut.com": null,
"analytics.ngfiles.com": null,
"analytics.plex.tv": null,
"analytics.posttv.com": null,
"analytics.productreview.com.au": null,
"analytics.schoolwires.com": null,
"analytics.shorte.st": null,
"analytics.sketchup.com": null,
"analytics.skyscanner.net": null,
"analytics.slashdotmedia.com": null,
"analytics.socialblade.com": null,
"analytics.sportybet.com": null,
"analytics.teespring.com": null,
"analytics.thegedsection.com": null,
"analytics.thenest.com": null,
"analytics.thenewslens.com": null,
"analytics.thetab.com": null,
"analytics.tradedoubler.com": null,
"analytics.twitter.com": null,
"analytics.upworthy.com": null,
"analytics.us.archive.org": null,
"analytics.yahoo.com": null,
"analytics.zg-api.com": null,
"analytics2.socialblade.com": null,
"analyzer52.fc2.com": null,
"anon-stats.eff.org": null,
"atax.gamermetrics.com": null,
"athenatmpbeacon.theglobeandmail.ca": null,
"atlas.astrology.com": null,
"atrack.allposters.com": null,
"atrack.art.com": null,
"bat.adforum.com": null,
"bats.video.yahoo.com": null,
"beacon-1.newrelic.com": null,
"beacon.ehow.com": null,
"beacon.examiner.com": null,
"beacon.indieclicktv.com": null,
"beacon.lycos.com": null,
"beacon.netflix.com": null,
"beacon.nuskin.com": null,
"beacon.shazam.com": null,
"beacon.toyota.co.jp": null,
"beacon.wikia-services.com": null,
"beacon.www.theguardian.com": null,
"beap-bc.yahoo.com": null,
"bi.medscape.com": null,
"bn.adultempire.com": null,
"cbs.wondershare.com": null,
"cdnstats.tube8.com": null,
"cl.expedia.com": null,
"clck.yandex.com": null,
"clck.yandex.ru": null,
"click.engage.xbox.com": null,
"click.jasmin.com": null,
"click.livejasmin.com": null,
"click.oneplus.com": null,
"click.udimg.com": null,
"click2.cafepress.com": null,
"clicks.hurriyet.com.tr": null,
"clicks.traffictrader.net": null,
"client-event-reporter.twitch.tv": null,
"clkstat.china.cn": null,
"clog.go.com": null,
"cmstrendslog.indiatimes.com": null,
"cmstrendslog.timesnow.tv": null,
"cnt.vivatube.com": null,
"collector-cdn.github.com": null,
"collector.prod.expedia.com": null,
"collector.statowl.com": null,
"collector.wallapop.com": null,
"coolertracks.emailroi.com": null,
"count.prx.org": null,
"count.rin.ru": null,
"counter.entertainmentwise.com": null,
"counter.sina.com.cn": null,
"counter.theconversation.edu.au": null,
"counter.zerohedge.com": null,
"creativefactory.zalando.": null,
"da.virginmedia.com": null,
"data.mic.com": null,
"data.younow.com": null,
"dl.meliacloud.com": null,
"dmtracking2.alibaba.com": null,
"dwh-tracking.it.auth0.com": null,
"ekg.riotgames.com": null,
"enlightenment.secureshoppingbasket.com": null,
"eu.groupondata.com": null,
"event-collector.udsrv.com": null,
"event-reporting-dot-webylytics.appspot.com": null,
"eventlog.jackpot.de": null,
"eventlogger.soundcloud.com": null,
"events.avantisvideo.com": null,
"events.godaddy.com": null,
"events.jora.com": null,
"events.privy.com": null,
"events.reddit.com": null,
"events.redditmedia.com": null,
"events.secureserver.net": null,
"events.turbosquid.com": null,
"evisit.exeter.ac.uk": null,
"expbl2ro.xbox.com": null,
"expdb2.msn.com": null,
"extra.tvmaze.com": null,
"f.staticlp.com": null,
"fast.forbes.com": null,
"firebaselogging.googleapis.com": null,
"g.msn.com": null,
"ga.nsimg.net": null,
"ganon.yahoo.com": null,
"gcpdata.telegraph.co.uk": null,
"geo.battle.net": null,
"geo.yahoo.com": null,
"geobeacon.ign.com": null,
"gj.mmstat.com": null,
"glean.pop6.com": null,
"gmonitor.aliimg.com": null,
"imgtrack.domainmarket.com": null,
"immassets.s3.amazonaws.com": null,
"imp-media-lab.thenewslens.com": null,
"laas.americanexpress.com": null,
"lh.secure.yahoo.com": null,
"lilb2.shutterstock.com": null,
"localads-statistics.maps.me": null,
"log.china.cn": null,
"log.go.com": null,
"log.hypebeast.com": null,
"log.mappy.net": null,
"log.newsvine.com": null,
"log.optimizely.com": null,
"log.prezi.com": null,
"log.quora.com": null,
"log.snapdeal.com": null,
"log.wat.tv": null,
"log.webnovel.com": null,
"logg.kiwi.com": null,
"logger.dailymotion.com": null,
"logger.nerdwallet.com": null,
"logging.goodgamestudios.com": null,
"loggly.cheatsheet.com": null,
"loglady.publicbroadcasting.net": null,
"logs.dashlane.com": null,
"logs.gaana.com": null,
"logs.hotstar.com": null,
"lslmetrics.djlmgdigital.com": null,
"mcdp-sadc1.outbrain.com": null,
"metric-agent.i10c.net": null,
"metric.inetcore.com": null,
"metrics.apartments.com": null,
"metrics.bangbros.com": null,
"metrics.cbn.com": null,
"metrics.cbslocal.com": null,
"metrics.cnn.com": null,
"metrics.ee.co.uk": null,
"metrics.extremetech.com": null,
"metrics.tbliab.net": null,
"metrics.ted.com": null,
"metrics.washingtonpost.com": null,
"mms.cloudpro.co.uk": null,
"mms.deadspin.com": null,
"mms.expertreviews.co.uk": null,
"mms.newyorkupstate.com": null,
"mts-ws.rueducommerce.fr": null,
"nmtracking.netflix.com": null,
"nozem.tvmaze.com": null,
"oimg.m.cnbc.com": null,
"oimg.mobile.cnbc.com": null,
"oms.expedia.com": null,
"oneid.mmstat.com": null,
"optimize-stats.voxmedia.com": null,
"origin-tracking.trulia.com": null,
"page-events-ustats.udemy.com": null,
"partner.worldoftanks.com": null,
"partners.badongo.com": null,
"partners.mysavings.com": null,
"pclick.europe.yahoo.com": null,
"pclick.internal.yahoo.com": null,
"pclick.yahoo.com": null,
"performances.bestofmedia.com": null,
"pings.blip.tv": null,
"pix.eads.com": null,
"pix.gfycat.com": null,
"pix.nbcuni.com": null,
"pixel-static.spotify.com": null,
"pixel.anyclip.com": null,
"pixel.archive.": null,
"pixel.digitalspy.co.uk": null,
"pixel.dorehernowi.pro": null,
"pixel.facebook.com": null,
"pixel.honestjohn.co.uk": null,
"pixel.naij.com": null,
"pixel.newscgp.com": null,
"pixel.newsdiscover.com.au": null,
"pixel.pcworld.com": null,
"pixel.propublica.org": null,
"pixel.reddit.com": null,
"pixel.spotify.com": null,
"pixel.staging.tree.com": null,
"pixel.tuko.co.ke": null,
"pixels.livingsocial.com": null,
"pixiedust.buzzfeed.com": null,
"presentationtracking.netflix.com": null,
"proxypage.msn.com": null,
"pvstat.china.cn": null,
"reco.hardsextube.com": null,
"rel.msn.com": null,
"revsci.tvguide.com": null,
"rs.mail.ru": null,
"rta.dailymail.co.uk": null,
"s.youtube.com": null,
"sana.newsinc.com.s3.amazonaws.com": null,
"scribe.twitter.com": null,
"session-tracker.badcreditloans.com": null,
"sitelife.ehow.com": null,
"slipstream.skyscanner.net": null,
"smetrics.att.com": null,
"smetrics.delta.com": null,
"sp.battlecreekenquirer.com": null,
"sp.burlingtonfreepress.com": null,
"sp.dailyrecord.com": null,
"sp.dailyworld.com": null,
"sp.fanatical.com": null,
"sp.freep.com": null,
"sp.gametimepa.com": null,
"sp.hattiesburgamerican.com": null,
"sp.lansingstatejournal.com": null,
"sp.sheboyganpress.com": null,
"sp.shreveporttimes.com": null,
"sp.statesmanjournal.com": null,
"sp.thedailyjournal.com": null,
"sp.wausaudailyherald.com": null,
"sp.wisconsinrapidstribune.com": null,
"srtb.msn.com": null,
"sstats.oui.sncf": null,
"st.arte.tv": null,
"stat.alibaba.com": null,
"stat.dealtime.com": null,
"stat.kbs.co.kr": null,
"stat.pubhtml5.com": null,
"stat.ruvr.ru": null,
"stat.tildacdn.com": null,
"stat.xhamsterpremium.com": null,
"statistics.crowdynews.com": null,
"stats.aplus.com": null,
"stats.articlesbase.com": null,
"stats.avg.com": null,
"stats.bbc.co.uk": null,
"stats.binki.es": null,
"stats.blogg.se": null,
"stats.cardschat.com": null,
"stats.cheddar.com": null,
"stats.christianpost.com": null,
"stats.clear-media.com": null,
"stats.digg.com": null,
"stats.dnaindia.com": null,
"stats.eyeviewdigital.com": null,
"stats.fs.com": null,
"stats.harpercollins.com": null,
"stats.ibtimes.co.in": null,
"stats.ibtimes.co.uk": null,
"stats.nimiq-network.com": null,
"stats.nymag.com": null,
"stats.opoloo.de": null,
"stats.oui.sncf": null,
"stats.pandora.com": null,
"stats.paste2.org": null,
"stats.piaggio.com": null,
"stats.propublica.org": null,
"stats.pusher.com": null,
"stats.searchftps.net": null,
"stats.searchftps.org": null,
"stats.shoppydoo.com": null,
"stats.slideshare.net": null,
"stats.someecards.com": null,
"stats.townnews.com": null,
"stats.uswitch.com": null,
"stats.videodelivery.net": null,
"stats.visistat.com": null,
"stats.vulture.com": null,
"stats.wordpress.com": null,
"stats.wwd.com": null,
"stats.wwitv.com": null,
"stats.ynet.co.il": null,
"stats.zmags.com": null,
"stats02.topix.com": null,
"statstracker.celebrity-gossip.net": null,
"stattrack.0catch.com": null,
"sugar.gameforge.com": null,
"surveys.cnet.com": null,
"t.dailymail.co.uk": null,
"t.freelancer.com": null,
"tags.msnbc.com": null,
"ted.dailymail.co.uk": null,
"timeslogtn.timesnow.tv": null,
"timestrends.timesnow.tv": null,
"tools.ranker.com": null,
"tracelog.www.alibaba.com": null,
"track.briskfile.com": null,
"track.catalogs.com": null,
"track.cbs.com": null,
"track.collegehumor.com": null,
"track.dictionary.com": null,
"track.engagesciences.com": null,
"track.fxstreet.com": null,
"track.hubspot.com": null,
"track.netzero.net": null,
"track.ning.com": null,
"track.pushbullet.com": null,
"track.searchiq.co": null,
"track.slideshare.net": null,
"track.thesaurus.com": null,
"track.ugamezone.com": null,
"track.ultimate-guitar.com": null,
"track.wattpad.com": null,
"track.webgains.com": null,
"track.websiteceo.com": null,
"track.wildblue.com": null,
"track.workablemetro.com": null,
"track.zalando.": null,
"track.zomato.com": null,
"tracker-api.my.com": null,
"tracker.anandtech.com": null,
"tracker.calameo.com": null,
"tracker.cpapath.com": null,
"tracker.jawcloud.co": null,
"tracker.lolalytics.com": null,
"tracker.mattel.com": null,
"tracker.nbcuas.com": null,
"tracker.nitropay.com": null,
"tracker.pandora.com": null,
"tracker.pinnaclesports.com": null,
"tracker.realclearpolitics.com": null,
"tracker.secretescapes.com": null,
"tracker.shopclues.com": null,
"tracker.uprinting.com": null,
"tracker.wordstream.com": null,
"tracking.ancestry.com": null,
"tracking.batanga.com": null,
"tracking.battleon.com": null,
"tracking.carsales.com.au": null,
"tracking.chacha.com": null,
"tracking.conduit.com": null,
"tracking.epicgames.com": null,
"tracking.eurosport.com": null,
"tracking.goodgamestudios.com": null,
"tracking.hsn.com": null,
"tracking.military.com": null,
"tracking.mycapture.com": null,
"tracking.nextdoor.com": null,
"tracking.olx-st.com": null,
"tracking.olx.": null,
"tracking.oui.sncf": null,
"tracking.porndoelabs.com": null,
"tracking.pornhd.com": null,
"tracking.resumecompanion.com": null,
"tracking.shoptogether.buy.com": null,
"tracking.softwareprojects.com": null,
"tracking.teamskeet.com": null,
"tracking.tidalhifi.com": null,
"tracking.ukwm.co.uk": null,
"tracking.unitednaturals.com": null,
"tracking.unrealengine.com": null,
"trackpm.shop2market.com": null,
"traffic.buyservices.com": null,
"trk.freepik.com": null,
"trowel.twitch.tv": null,
"trx.smdatalabs.com": null,
"uie.data.cbc.ca": null,
"uptpro.homestead.com": null,
"user-metrics.onthemarket.com": null,
"video-stats.video.google.com": null,
"videotracker.washingtonpost.com": null,
"visit.asb.co.nz": null,
"visit.dealspwn.com": null,
"visit.mobot.net": null,
"visit.theglobeandmail.com": null,
"visitors.sourcingmap.com": null,
"vstats.digitaltrends.com": null,
"weblog.strawberrynet.com": null,
"webstats.thesoul-publishing.com": null,
"wstats.e-wok.tv": null,
"bucksfreepress-gb.bucksfreepress.co.uk": null,
"eurogamer-uk.eurogamer.net": null,
"yourlocalguardian-gb.yourlocalguardian.co.uk": null,
"ea.jeuxvideopc.com": null,
"ea.lexpress.fr": null,
"ea.pixmania.": null,
"ea.rueducommerce.fr": null,
"eulerian.brandalley.fr": null,
"tdf1.admyjob.com": null,
"xay5o.toscane-boutique.fr": null,
"yoc.younited-credit.com": null,
"cdn1.pebx.pl": null,
"event-analytics.yesware.com": null,
"abakus.freenet.de": null,
"ac.express.de": null,
"analytics.arz.at": null,
"analytics.industriemagazin.net": null,
"analytics.moviepilot.de": null,
"analytics.proxer.me": null,
"analytics.solidbau.at": null,
"banner.t-online.de": null,
"beacon.gutefrage.net": null,
"bt.mediaimpact.de": null,
"count.merian.de": null,
"count.rtl.de": null,
"count.spiegel.de": null,
"event.dkb.de": null,
"log.suchen.de": null,
"log.wilmaa.com": null,
"logging.wilmaa.com": null,
"metrics.n-tv.de": null,
"multicounter.de": null,
"pix.telekom.de": null,
"pixel.1und1.de": null,
"pixel.4players.de": null,
"pixel.bild.de": null,
"pixel.prosieben.de": null,
"powercount.jswelt.de": null,
"rem-track.bild.de": null,
"statistics.raiffeisen.ch": null,
"statistics.riskommunal.net": null,
"stats.autoscout24.ch": null,
"stats.bmw.de": null,
"stats01.20min.ch": null,
"subpixel.4players.de": null,
"track.bazonline.ch": null,
"track.berliner-kurier.de": null,
"track.bernerzeitung.ch": null,
"track.cinestar.de": null,
"track.derbund.ch": null,
"track.express.de": null,
"track.mopo.de": null,
"trackerstatistik.init-ag.de": null,
"tracking.beilagen-prospekte.de": null,
"tracking.finanzen.net": null,
"tracking.hrs.de": null,
"tracking.krone.at": null,
"tracking.linda.de": null,
"tracking.mobile.de": null,
"tracking.oe24.at": null,
"tracking.sport1.de": null,
"tracking.statravel.de": null,
"tracking.tchibo.de": null,
"tracksrv.zdf.de": null,
"web-track.telekom-dienste.de": null,
"webts.adac.de": null,
"jppolid-track.trackprod.integration.jppol.dk": null,
"analytics.allovoisins.com": null,
"dm.commentcamarche.net": null,
"events.guesttoguest.com": null,
"k.rueducommerce.fr": null,
"logs-qos.tf1.fr": null,
"secure-stat.canal-plus.com": null,
"stat.ouedkniss.com": null,
"stat.webevolutis.com": null,
"stats.grafikart.fr": null,
"stats.sexemodel.com": null,
"stats1x1.kapaza.be": null,
"track.24heures.ch": null,
"tracker-id.cdiscount.com": null,
"tracker.cds-tracking.com": null,
"tracker.mspy.com": null,
"tracking.ha.rueducommerce.fr": null,
"counter.search.bg": null,
"adgeo.163.com": null,
"analy.qq.com": null,
"analyse.weather.com.cn": null,
"analytics.163.com": null,
"analytics.shop.hisense.com": null,
"analytics.zhihu.com": null,
"anti-bot.baidu.com": null,
"atm.youku.com": null,
"bdwblog.eastmoney.com": null,
"bglog.bitauto.com": null,
"click.ali213.net": null,
"click.gamersky.com": null,
"click.suning.cn": null,
"clkstat.qihoo.com": null,
"cmstool.youku.com": null,
"count.kandian.com": null,
"count.taobao.com": null,
"count.video.sina.com.cn": null,
"count.vrs.sohu.com": null,
"count5.pconline.com.cn": null,
"counter.people.cn": null,
"dmtrack.xiu.com": null,
"dmtracking.1688.com": null,
"dwtracking.sdo.com": null,
"eclick.baidu.com": null,
"imgstat.baidu.com": null,
"imp.appledaily.com": null,
"lg.tr.pandora.tv": null,
"log.51cto.com": null,
"log.bitauto.com": null,
"log.flight.qunar.com": null,
"log.kuwo.cn": null,
"log.m.sm.cn": null,
"log1.17173.com": null,
"loginlog.sdo.com": null,
"logs.51cto.com": null,
"logstat.caixin.com": null,
"logx.mtime.cn": null,
"logx.mtime.com": null,
"p-log.ykimg.com": null,
"rcgi.video.qq.com": null,
"referer.pixplug.in": null,
"sclick.baidu.com": null,
"stat.1688.com": null,
"stat.55bbs.com": null,
"stat.caijing.com.cn": null,
"stat.funshion.net": null,
"stat.hudong.com": null,
"stat.iteye.com": null,
"stat.ppstream.com": null,
"stat.stheadline.com": null,
"stat.tianya.cn": null,
"stat.uuu9.com": null,
"stat.zol.com.cn": null,
"statistic.qzone.qq.com": null,
"statistic.takungpao.com": null,
"stats.autohome.com.cn": null,
"stats.yinyuetai.com": null,
"track.sohu.com": null,
"uestat.video.qiyi.com": null,
"utrack.hexun.com": null,
"vatrack.hinet.net": null,
"webstat.kuwo.cn": null,
"wkctj.baidu.com": null,
"zhihu-web-analytics.zhihu.com": null,
"zz.bdstatic.com": null,
"stat.novinky.cz": null,
"analytics.rambla.be": null,
"logs.ggweb.nl": null,
"stats.fd.nl": null,
"webstatistieken.xs4all.nl": null,
"analytics.sanoma.fi": null,
"events.il.fi": null,
"stat.mtv3.fi": null,
"cellstats.mako.co.il": null,
"stats.mako.co.il": null,
"events.ingatlan.com": null,
"analytics.tio.ch": null,
"analytics.traderlink.com": null,
"click.tv.repubblica.it": null,
"livestats.la7.tv": null,
"siteinfo.libero.it": null,
"stats.splinder.com": null,
"track.tesiteca.it": null,
"tracker.stileo.it": null,
"tracking.gruppo.mps.it": null,
"analytics.cocolog-nifty.com": null,
"analyzer.fc2.com": null,
"analyzer2.fc2.com": null,
"count.upc.rakuten.co.jp": null,
"log.suumo.jp": null,
"mmstat.com": null,
"pvtag.yahoo.co.jp": null,
"rdsig.yahoo.co.jp": null,
"tr.api.itmedia.jp": null,
"yjtag.yahoo.co.jp": null,
"count.munhwa.com": null,
"log.sv.pandora.tv": null,
"prism.pandora.tv": null,
"stat.tiara.kakao.com": null,
"track.tiara.daum.net": null,
"track.tiara.kakao.com": null,
"tracker.cauly.co.kr": null,
"weblog.eseoul.go.kr": null,
"weblog2.eseoul.go.kr": null,
"stats.tunt.lv": null,
"click.vgnett.no": null,
"stats.proff.no": null,
"analytics.gazeta.pl": null,
"mklik.gazeta.pl": null,
"pixel.wp.pl": null,
"stats.teledyski.info": null,
"audience-mostread.r7.com": null,
"click.uol.com.br": null,
"logger.rm.uol.com.br": null,
"logger.uol.com.br": null,
"metrics.uol.com.br": null,
"tracker.bt.uol.com.br": null,
"tracker.publico.pt": null,
"ad7.bigmir.net": null,
"analytics.carambatv.ru": null,
"counter.drom.ru": null,
"dot-stat.radikal.ru": null,
"kiks.auto.ru": null,
"link.subscribe.ru": null,
"log.ren.tv": null,
"montblanc.lenta.ru": null,
"radar.imgsmail.ru": null,
"ssp.rambler.ru": null,
"stat.api.2gis.ru": null,
"stat.bankiros.ru": null,
"stat.pravmir.ru": null,
"stat.russianfood.com": null,
"stat.stars.ru": null,
"stats.mos.ru": null,
"sync.rambler.ru": null,
"tracker.tiu.ru": null,
"yast.rutube.ru": null,
"tracker.azet.sk": null,
"analytics.infobae.com": null,
"analytics.redlink.com.ar": null,
"pixel.europapress.net": null,
"wssgmstats.vibbo.com": null,
"wsstats.coches.net": null,
"stat.nyheter24.se": null,
"counter.ukr.net": null,
"logsbin.dantri.com.vn": null,
"ktracker.kumparan.com": null,
"connect.facebook.com": null,
"connect.facebook.net": null,
"platform.twitter.com": null,
"api.areametrics.com": null,
"api.beaconsinspace.com": null,
"mobileapi.mobiquitynetworks.com": null,
"incoming-data-sense360.s3.amazonaws.com": null,
"ios-quinoa-events-prod.sense360eng.com": null,
"ios-quinoa-high-frequency-events-prod.sense360eng.com": null,
"v1.blueberry.cloud.databerries.com": null,
"outbrain.com": null };
var bad_da_host_exact_flag = 3394 > 0 ? true : false;  // test for non-zero number of rules
    
// 15 rules as an efficient NFA RegExp:
var bad_da_host_RegExp = /^(?:[\w-]+\.)*?(?:tracking(?=([\s\S]*?\.euroads\.fi))\1|tracking\.(?=([\s\S]*?\.miui\.com))\2|minero\-proxy\-(?=([\s\S]*?\.sh))\3|analytics\-beacon\-(?=([\s\S]*?\.amazonaws\.com))\4|collector\-(?=([\s\S]*?\.elb\.amazonaws\.com))\5|collector\-(?=([\s\S]*?\.tvsquared\.com))\6|datacollect(?=([\s\S]*?\.abtasty\.com))\7|log\-(?=([\s\S]*?\.previewnetworks\.com))\8|metro\-trending\-(?=([\s\S]*?\.amazonaws\.com))\9|trk(?=([\s\S]*?\.vidible\.tv))\10|vtnlog\-(?=([\s\S]*?\.elb\.amazonaws\.com))\11|stats2\.(?=([\s\S]*?\.fdnames\.com))\12|stats\-(?=([\s\S]*?\.p2pnow\.ru))\13|logger\-(?=([\s\S]*?\.dailymotion\.com))\14|metric(?=([\s\S]*?\.rediff\.com))\15)/i;
var bad_da_host_regex_flag = 15 > 0 ? true : false;  // test for non-zero number of rules

// 898 rules:
var bad_da_hostpath_JSON = { "facebook.com/plugins/activity.php": null,
"facebook.com/plugins/comments.php": null,
"facebook.com/plugins/facepile.php": null,
"facebook.com/plugins/fan.php": null,
"facebook.com/plugins/follow.php": null,
"facebook.com/plugins/like.php": null,
"facebook.com/plugins/like_box.php": null,
"facebook.com/plugins/likebox.php": null,
"facebook.com/plugins/post.php": null,
"facebook.com/plugins/recommendations.php": null,
"facebook.com/plugins/recommendations_bar.php": null,
"facebook.com/plugins/send.php": null,
"facebook.com/plugins/share_button.php": null,
"facebook.com/plugins/subscribe.php": null,
"facebook.com/whitepages/wpminiprofile.php": null,
"facebook.com/widgets/activity.php": null,
"facebook.com/widgets/fan.php": null,
"facebook.com/widgets/like.php": null,
"facebook.com/widgets/recommendations.php": null,
"google.com/js/plusone.js": null,
"spot.im/embed/scripts/launcher.js": null,
"alluremedia.com.au/s/au.js": null,
"amazonaws.com/fby.js": null,
"cloudfront.net/js/slide.js": null,
"jobvite.com/widget20.js": null,
"mailjet.com/statics/js/widget.modal.js": null,
"tapcdn.com/mosaic/tap_button.js": null,
"vuukle.com/platform.js": null,
"webseed.com/javascripts/messagebar.js": null,
"apis.google.com/js/platform.js": null,
"assets.pinterest.com/js/pinit.js": null,
"assets.pinterest.com/pidget.html": null,
"assets.tumblr.com/assets/html/iframe/o.html": null,
"assets.tumblr.com/assets/html/iframe/teaser.html": null,
"bit.ly/TweetAndTrack.js": null,
"facebook.com/plugins/page.php": null,
"facebook.com/plugins/save.php": null,
"iconosquare.com/widget.php": null,
"pinterest.com/js/pinit_main.js": null,
"pinterest.com/v1/urls/count.json": null,
"platform.twitter.com/anywhere.js": null,
"smartaddon.com/share_addon.js": null,
"statigr.am/widget.php": null,
"vk.com/share.php": null,
"vk.com/widget_community.php": null,
"vk.com/widget_community_messages.php": null,
"vk.com/widget_like.php": null,
"vkontakte.ru/share.php": null,
"vkontakte.ru/widget_community.php": null,
"vkontakte.ru/widget_like.php": null,
"vuukle.com/widgets/emotes.html": null,
"vuukle.com/widgets/powerbar.html": null,
"weibo.com/staticjs/weiboshare.html": null,
"jimstatic.com/ckies.js": null,
"anews.com/s/js/widget.js": null,
"d.yimg.com/ds/badge2.js": null,
"dailymaverick.co.za/images/iabsa.png": null,
"easytutoriel.com/wp-content/themes/easytutoriel-10-1/js/scripts.js": null,
"emailsherlock.com/javascripts/lightbox.js": null,
"redbunker.net/images/redb/redyeni.gif": null,
"annahar.com/assets/js/notifications.js": null,
"bdstatic.com/linksubmit/push.js": null,
"irishtimes.com/assets/js/notify.js": null,
"ndtv.com/popupNotification.aspx": null,
"ultimedia.com/js/common/notification.js": null,
"breitbart.com/t/assets/js/fancybox.js": null,
"indiatimes.com/subscriptionhomepage.cms": null,
"insidesources.com/wp-content/themes/insidesources/js/jquery.fancybox.js": null,
"dailypioneer.com/images/top.png": null,
"3dmark.com/proxycon/images/front-some-fb.png": null,
"5movies.to/share.php": null,
"ana.net/contentimage/genicon/facebook.png": null,
"ana.net/contentimage/genicon/twitter.png": null,
"bdupload.info/js/share.js": null,
"burntorangereport.com/upload/scripts/popup.js": null,
"csgoreportbot.net/jquery.fancybox.min.js": null,
"dailykostv.com/digg.html": null,
"enjin.com/images/layout/footer-icons.png": null,
"eurotrucksimulator2.com/images/logo_blog.png": null,
"feedsportal.com/images/bookmark.gif": null,
"file025.com/images_mega/ico_tr.png": null,
"freehostinghero.com/img/tw.png": null,
"hulkshare.com/facebox.html": null,
"impactloud.com/img/follow.png": null,
"livescience.com/social.php": null,
"marketingsherpa.com/Zlatko/facebook.jpg": null,
"moltenusa.com/images/com_connecton.gif": null,
"mybetting.co.uk/facebook.png": null,
"mybetting.co.uk/twitter.png": null,
"newsarama.com/social.php": null,
"shine.cn/js/share.js": null,
"store.yahoo.net/lib/directron/icons-test02.jpg": null,
"theecologist.org/siteimage/scale/0/0/132471.gif": null,
"theecologist.org/siteimage/scale/0/0/132472.gif": null,
"theecologist.org/siteimage/scale/0/0/132473.gif": null,
"webopedia.com/img/header_icon_google.png": null,
"winhelponline.com/facebook.png": null,
"agicssecurity.com/Header/ajax/cookie.php": null,
"freedoflondon.com/Styles/dialog-popup/jquery-ui.js": null,
"harpercollins.co.uk/js/cookie.js": null,
"hunstoncanoeclub.co.uk/media/system/js/modal.js": null,
"omgubuntu.co.uk/wp-content/plugins/omg-magnific/magnific.min.js": null,
"pourquoidocteur.fr/img2/face.png": null,
"pourquoidocteur.fr/img2/in.png": null,
"cambiodns.com/img/up.png": null,
"dirittierisposte.it/Images/corriere_sera.png": null,
"ilquotidianodellazio.it/img/top.png": null,
"js.adv.dadapro.net/collector.js/prcy.js": null,
"milanofinanza.it/img/top.png": null,
"simplymarket.it/images/scroll-top.png": null,
"mingpao.com/image/sms.gif": null,
"plugins.mixi.jp/favorite.pl": null,
"dict.cc/img/fbplus1.png": null,
"die-kopie.info/bilder/facebook.png": null,
"sanoma.nl/media/static/images/icon_zienl.png": null,
"spynews.ro/templates/default/img/face.png": null,
"vestifinance.ru/js/share.js": null,
"nioutaik.fr/themes/freshy/images/facedebouc.gif": null,
"nioutaik.fr/themes/freshy/images/googlepeuluss.gif": null,
"nioutaik.fr/themes/freshy/images/zoiseau.gif": null,
"nrj-play.fr/js/social.js": null,
"condominioweb.com/img_cdw/seguici.png": null,
"byom.de/js/cookie.de.js": null,
"thesiteoueb.net/js/cm-head.js": null,
"bastabugie.it/it/cookies.js": null,
"cippy.it/Scripts/toastr.js": null,
"spesasicura.com/Scripts/cookie.js": null,
"4hifi.pl/scripts/jquery.cookie.js": null,
"animesub.info/skrypty/pierdolecookie.js": null,
"gry-online.pl/js/cookie2.js": null,
"lubuskie.pl/themes/src/cookie.js": null,
"nowehoryzonty.pl/js/cookies.js": null,
"orange.pl/ocp-http/map/js/cookies.js": null,
"prideandglory.pl/polityka_cookies.js": null,
"sycow.pl/a/cookie.js": null,
"google-analytics.com/analytics.js": null,
"google-analytics.com/analytics_debug.js": null,
"google-analytics.com/cx/api.js": null,
"google-analytics.com/ga_exp.js": null,
"google-analytics.com/internal/analytics.js": null,
"google-analytics.com/siteopt.js": null,
"quantserve.com/aquant.js": null,
"101apps.com/tracker.ashx": null,
"148.251.8.156/track.js": null,
"198.101.148.38/update_counter.php": null,
"5251.net/stat.jsp": null,
"aao.org/aao/sdc/track.js": null,
"acces-charme.com/fakebar/track.php": null,
"addthis.com/red/p.png": null,
"addtoany.com/menu/transparent.gif": null,
"adultmastercash.com/e1.php": null,
"aiya.com.cn/stat.js": null,
"akamai.com/crs/lgsitewise.js": null,
"akamaized.net/js3/tracker.js": null,
"alex.leonard.ie/misc-images/transparent.png": null,
"amatomu.com/log.php": null,
"amazonaws.com/accio-lib/accip_script.js": null,
"amazonaws.com/amacrpr/crpr.js": null,
"amazonaws.com/g.aspx": null,
"amazonaws.com/gaL.js": null,
"amazonaws.com/js/reach.js": null,
"aolcdn.com/js/mg2.js": null,
"aolcdn.com/omniunih_int.js": null,
"app.cdn-cs.com/__t.png": null,
"appliedsemantics.com/images/x.gif": null,
"atom-data.io/session/latest/track.html": null,
"audioeye.com/frame/cookieStorage.html": null,
"autoline-top.com/counter.php": null,
"b5media.com/bbpixel.php": null,
"bidsystem.com/ppc/sendtracker.aspx": null,
"bobparsons.com/image.aspx": null,
"bpath.com/count.dll": null,
"breakingburner.com/stats.html": null,
"breakmedia.com/track.jpg": null,
"buybox.click/analytics.js": null,
"canecto.info/analytics.js": null,
"cdnma.com/apps/capture.js": null,
"cdnplanet.com/static/rum/rum.js": null,
"cdnweb.aoscdn.com/hawkeye.js": null,
"clickfunnels.com/assets/pushcrew.js": null,
"clickfunnels.com/cf.js": null,
"cloudfront.net/abw.js": null,
"cloudfront.net/analytics.js": null,
"cloudfront.net/code/keen-2.1.0-min.js": null,
"cloudfront.net/esf.js": null,
"cloudfront.net/js/ca.js": null,
"cloudfront.net/js/reach.js": null,
"cloudfront.net/khp.js": null,
"cloudfront.net/log.js": null,
"cloudfront.net/lp.js": null,
"cloudfront.net/powr.js": null,
"cloudfront.net/pt1x1.gif": null,
"cloudfront.net/rc.js": null,
"cloudfront.net/rum/bacon.min.js": null,
"cloudfront.net/scripts/cookies.js": null,
"cloudfront.net/sentinel.js": null,
"cloudfront.net/sso.js": null,
"cloudfront.net/track.html": null,
"cloudfront.net/trackb.html": null,
"cloudfront.net/websites/sb.js": null,
"cloudfront.net/zephyr.js": null,
"cnetcontent.com/jsc/h.js": null,
"comic-rocket.com/metrics.js": null,
"compendiumblog.com/sp.js": null,
"contactatonce.com/GetAgentStatusImage.aspx": null,
"contactatonce.com/VisitorContext.aspx": null,
"crowdskout.com/analytics.js": null,
"d27s92d8z1yatv.cloudfront.net/js/jquery.jw.analitycs.js": null,
"d2nq0f8d9ofdwv.cloudfront.net/track.js": null,
"d3qxef4rp70elm.cloudfront.net/m.js": null,
"demandmedia.com/wm.js": null,
"digimedia.com/pageviews.php": null,
"digitalgov.gov/Universal-Federated-Analytics-Min.js": null,
"disqus.com/stats.html": null,
"ecustomeropinions.com/survey/nojs.php": null,
"embedly.com/widgets/xcomm.html": null,
"evidon.com/pub/tag.js": null,
"facebook.com/ai.php": null,
"facebook.com/brandlift.php": null,
"facebook.com/common/scribe_endpoint.php": null,
"facebook.com/email_open_log_pic.php": null,
"facebook.com/fr/u.php": null,
"facebook.com/js/conversions/tracking.js": null,
"facebook.com/offsite_event.php": null,
"files-hawk.co.uk/hl/hawklinks.js": null,
"ftimg.net/js/log.js": null,
"gatehousemedia.com/wickedlocal/ip.js": null,
"geckofoot.com/gfcounterimg.aspx": null,
"geckofoot.com/gfvisitormap.aspx": null,
"glam.com/ctagsimgcmd.act": null,
"goaww.com/stats.php": null,
"godaddy.com/js/gdwebbeacon.js": null,
"googleapis.com/aam.js": null,
"googleapis.com/ivc.js": null,
"googletagmanager.com/ns.html": null,
"gotdns.com/track/blank.aspx": null,
"gowatchit.com/analytics.js": null,
"gstatic.com/gadf/ga_dyn.js": null,
"hostingtoolbox.com/bin/Count.cgi": null,
"hqq.tv/js/counters.js": null,
"icbdr.com/images/pixel.gif": null,
"imgfarm.com/images/trk/myexcitetr.gif": null,
"imghostsrc.com/counter.php": null,
"ind.sh/view.php": null,
"infogr.am/logger.php": null,
"intensedebate.com/remotevisit.php": null,
"isitelab.io/ite_sitecomV1ANA.min.js": null,
"jobvite.com/analytics.js": null,
"keywee.co/analytics.js": null,
"klaviyo.com/onsite/js/klaviyo.js": null,
"kxcdn.com/track.js": null,
"lederer.nl/incl/stats.js.php": null,
"lightboxcdn.com/static/identity.html": null,
"lijit.com/res/images/wijitTrack.gif": null,
"linkdeli.com/widget.js": null,
"linkwithin.com/pixel.png": null,
"mailmax.co.nz/login/open.php": null,
"makantime.tv/analytics.js": null,
"mansion.com/mts.tracker.js": null,
"maxmind.com/js/country.js": null,
"mkcms.com/stats.js": null,
"mtvnservices.com/aria/uuid.html": null,
"museter.com/track.php": null,
"myfreecams.com/mfc2/lib/o-mfccore.js": null,
"mymarketing.co.il/Include/tracker.js": null,
"mzbcdn.net/mngr/mtm.js": null,
"naver.net/wcslog.js": null,
"nbcudigitaladops.com/hosted/housepix.gif": null,
"neon-lab.com/neonbctracker.js": null,
"nsdsvc.com/scripts/action-tracker.js": null,
"nude.hu/html/track.js": null,
"o.aolcdn.com/js/mg1.js": null,
"odnaknopka.ru/stat.js": null,
"onsugar.com/static/ck.php": null,
"ora.tv/j/ora_evttracking.js": null,
"pageturnpro.com/tracker.aspx": null,
"pcrl.co/js/jstracker.min.js": null,
"pendo.io/data/ptm.gif": null,
"phncdn.com/js/ssig_helper.js": null,
"pixhosting.com/ct/jct.php": null,
"pixlee.com/assets/pixlee_events.js": null,
"platform.twitter.com/impressions.js": null,
"pornhost.com/count_hit_player.php": null,
"print2webcorp.com/mkt3/_js/p2w_tracker.js": null,
"privacytool.org/AnonymityChecker/js/fontdetect.js": null,
"project-syndicate.org/fwat.js": null,
"quora.com/qevents.js": null,
"rackcdn.com/easie.js": null,
"rackcdn.com/icon2.gif": null,
"rackcdn.com/knotice.api.js": null,
"rackcdn.com/stf.js": null,
"redditstatic.com/ads/pixel.js": null,
"ria.ru/js/counter.js": null,
"royalecms.com/statistics.php": null,
"saymedia.com/latest/tetrapak.js": null,
"searchcompletion.com/BannerHandler.ashx": null,
"sendtonews.com/player/loggingajax.php": null,
"shareaholic.com/partners.js": null,
"shareit.com/affiliate.html": null,
"shoplocal.com/it.ashx": null,
"skimresources.com/api/ref-banners.js": null,
"snazzyspace.com/generators/viewer-counter/counter.php": null,
"stats.screenresolution.org/get.php": null,
"storage.data-vp.com/vp/t.js": null,
"swiftypecdn.com/cc.js": null,
"swiftypecdn.com/te.js": null,
"technorati.com/technoratimedia-pixel.js": null,
"thepornstarlist.com/lo/lo/track.php": null,
"tout.com/tracker.js": null,
"trackjs.com/usage.gif": null,
"tritondigital.com/ltflash.php": null,
"twitter.com/jot.html": null,
"twitter.com/oct.js": null,
"v.giantrealm.com/players/stats.swf": null,
"video.msn.com/report.aspx": null,
"visual.ly/track.php": null,
"vk.com/videostats.php": null,
"vooxe.com/analytics.js": null,
"voxmedia.com/beacon-min.js": null,
"vpoweb.com/counter.php": null,
"vvhp.net/read/view.gif": null,
"vwdealerdigital.com/cdn/sd.js": null,
"weather.ca/counter.gif": null,
"websuccess-data.com/tracker.js": null,
"webvoo.com/wt/Track.aspx": null,
"widgeo.net/tracking.php": null,
"widgethost.com/pax/counter.js": null,
"wn.com/count.js": null,
"wondershare.es/jslibs/track.js": null,
"wsj.net/MW5/content/analytics/hooks.js": null,
"yahoo.co.jp/js/s_retargeting.js": null,
"yellowbrix.com/images/content/cimage.gif": null,
"yimg.com/ss/vops.js": null,
"yimg.com/wi/ytc.js": null,
"zapcdn.space/zapret.js": null,
"fastly.net/plw.js": null,
"fastly.net/sp.js": null,
"adc-srv.net/retargeting.php": null,
"cloudfront.net/customers/24868.min.js": null,
"gameforge.de/init.gif": null,
"gibts-hier.com/counter.php": null,
"goldsilbershop.de/go.cgi": null,
"hittracker.org/count.php": null,
"hittracker.org/counter.php": null,
"kt-g.de/counter.php": null,
"mapandroute.de/log.xhr": null,
"mindwerk.net/zaehlpixel.php": null,
"movad.de/c.ount": null,
"ntmb.de/count.html": null,
"onlex.de/_counter.php": null,
"onlinepresse.info/counter.php": null,
"plista.com/iframeShowItem.php": null,
"script.idgentertainment.de/gt.js": null,
"spox.com/pub/js/track.js": null,
"ss4w.de/counter.php": null,
"xnewsletter.de/count/counter.php": null,
"bnpparibas.fr/JavascriptInsert.js": null,
"ced-ns.sascdn.com/diff/js/smart.js": null,
"free.fr/cgi-bin/wwwcount.cgi": null,
"free.fr/services/compteur_page.php": null,
"linguee.fr/white_pixel.gif": null,
"live-medias.net/button.php": null,
"neteventsmedia.be/hit.cfm": null,
"tsphone.biz/pixelvoleur.jpg": null,
"webtutoriaux.com/services/compteur-visiteurs/index.php": null,
"ladesk.com/scripts/track.js": null,
"minsk-in.net/counter.php": null,
"aixifan.com/acsdk/log.min.js": null,
"alicdn.com/tkapi/click.js": null,
"baidu.com/cpro/ui/c.js": null,
"baidu.com/cpro/ui/f.js": null,
"baidu.com/h.js": null,
"baidu.com/hm.gif": null,
"baidu.com/js/m.js": null,
"baidu.com/js/o.js": null,
"baidu.com/x.js": null,
"cdnmaster.com/sitemaster/sm360.js": null,
"js.static.m1905.cn/pingd.js": null,
"sitemaji.com/nownews.php": null,
"stargame.com/g.js": null,
"tanx.com/t/tanxclick.js": null,
"wwwportal.dk/statistik.php": null,
"bbvms.com/zone/js/zonestats.js": null,
"ugent.be/js/log.js": null,
"mediaquark.com/tracker.js": null,
"digiland.it/count.cgi": null,
"eage.it/count2.php": null,
"mrwebmaster.it/work/stats.php": null,
"sembox.it/js/sembox-tracking.js": null,
"webbificio.com/add.asp": null,
"wmtools.it/wmtcounter.php": null,
"future-shop.jp/rview.gif": null,
"pia.jp/images/pt.gif": null,
"s.yimg.jp/images/listing/tool/cv/ytag.js": null,
"yahoo.co.jp/js/retargeting.js": null,
"cafe24.com/weblog.js": null,
"cafenews.pl/mpl/static/static.js": null,
"statig.com.br/pub/setCookie.js": null,
"xl.pt/api/stats.ashx": null,
"all-top.ru/cgi-bin/topcount.cgi": null,
"bigday.ru/counter.php": null,
"dp.ru/counter.gif": null,
"gainings.biz/counter.php": null,
"gde.ru/isapi/tracker.dll": null,
"kvartirant.ru/counter.php": null,
"mediaplus.fm/cntr.php": null,
"niknok.ru/count.asp": null,
"odessaaccommodations.com/counter.php": null,
"onlines.su/counter.php": null,
"optimizavr.ru/counter.php": null,
"pluso.ru/counter.php": null,
"pluso.ru/ping.php": null,
"properm.ru/top/counter_new.php": null,
"rambler.ru/counter.js": null,
"retailrocket.ru/content/javascript/tracking.js": null,
"sishik.ru/counter.php": null,
"stainlesssteel.ru/counter.php": null,
"ulogin.ru/js/stats.js": null,
"zahodi-ka.ru/ic/index_cnt.fcgi": null,
"contentexchange.me/static/tracker.js": null,
"mgz.com.ua/counter.php": null,
"1e400.net/tracking.js": null,
"24hourfitness.com/includes/script/siteTracking.js": null,
"3dcartstores.com/3droi/monstertrack.asp": null,
"4hds.com/js/camstats.js": null,
"9msn.com.au/share/com/js/fb_google_intercept.js": null,
"accountnow.com/SyslogWriter.ashx": null,
"accuterm.com/data/stat.js": null,
"aclu.org/aclu_statistics_image.php": null,
"ad2links.com/lpajax.php": null,
"advancedmp3players.co.uk/support/visitor/index.php": null,
"advfn.com/space.gif": null,
"agendize.com/analytics.js": null,
"agoda.net/js/abtest/analytics.js": null,
"allmovieportal.com/hostpagescript.js": null,
"alot.com/tb/cookiewriter.php": null,
"amazon.com/empty.gif": null,
"amazonaws.com/beacon/vtpixpc.gif": null,
"androidfilehost.com/libs/otf/stats.otf.php": null,
"angelfire.com/cgi-bin/count.cgi": null,
"apphit.com/js/count.js": null,
"arstechnica.com/dragons/breath.gif": null,
"atlantis.com/_scripts/tsedge/pagemarker.gif": null,
"audiusa.com/us/brand/en.usertracking_javascript.js": null,
"autobytel.com/content/shared/markerfile.bin": null,
"autosite.com/scripts/markerfile.bin": null,
"azfamily.com/images/pixel.gif": null,
"baidu.com/js/log.js": null,
"bankofamerica.com/cookie-id.js": null,
"barclaycard.co.uk/cs/static/js/esurveys/esurveys.js": null,
"beeg.com/logo.gif": null,
"bestofmedia.com/i/tomsguide/a.gif": null,
"beyond.com/common/track/trackgeneral.asp": null,
"bing.com/widget/metrics.js": null,
"blackplanet.com/images/shim.gif": null,
"blastro.com/log_player_actions.php": null,
"blockchain.info/Resources/analytics.js": null,
"boards.ie/timing.php": null,
"branica.com/counter.php": null,
"brightcove.com/1pix.gif": null,
"broadbandchoices.co.uk/track.js": null,
"bulgari.com/bulgari/wireframe_script/BulgariGa.js": null,
"business.com/images2/anal.gif": null,
"businessinsider.com/tracker.js": null,
"buzzamedia.com/js/track.js": null,
"cardomain.com/js/tibbylog.js": null,
"cardstore.com/affiliate.jsp": null,
"cbsimg.net/js/cbsi/dw.js": null,
"centerblog.net/stats.js": null,
"cert.org/images/1pxinv.gif": null,
"chanel.com/js/flashtrack.js": null,
"charter.com/static/scripts/mock/tracking.js": null,
"cheapsalesconsulting.com/adaptive.php": null,
"china.com/statistic.js": null,
"cloudfront.net/amznUrchin.js": null,
"cloudfront.net/bbc-filter.js": null,
"cloudfront.net/m/princess/ae.js": null,
"cloudfront.net/m/princess/ae.live.js": null,
"cloudfront.net/tracker-latest.min.js": null,
"cloudfront.net/vis_opt.js": null,
"cloudfront.net/vis_opt_no_jquery.js": null,
"codecguide.com/stats.js": null,
"codeweblog.com/js/count.js": null,
"collarity.com/ucs/tracker.js": null,
"collegehumor.com/track.php": null,
"crowdignite.com/img/l.gif": null,
"crunchsports.com/tracking_fetchinfo.aspx": null,
"current.com/tracking.htm": null,
"dealnews.com/lw/ul.php": null,
"depositfiles.com/stats.php": null,
"designtaxi.com/tracker.php": null,
"destructoid.com/img2.phtml": null,
"domainit.com/scripts/track.js": null,
"domaintools.com/buffer.pgif": null,
"domaintools.com/tracker.php": null,
"dragonstatic.com/parking/js/track.js": null,
"dump8.com/js/stat.php": null,
"dvdempire.com/images/empty2.asp": null,
"ectnews.com/shared/missing.gif": null,
"edvantage.com.sg/site/servlet/tracker.jsp": null,
"egg.com/rum/data.gif": null,
"exchangeandmart.co.uk/js/ga.js": null,
"expatnetwork.com/mtc.js": null,
"experiandirect.com/javascripts/tracking.js": null,
"experts-exchange.com/pageloaded.jsp": null,
"extendoffice.com/analytics.js": null,
"facebook.com/ct.php": null,
"facebook.com/search/web/instrumentation.php": null,
"facebook.com/xti.php": null,
"fanhow.com/script/tracker.js": null,
"fansshare.com/t.gif": null,
"fantasticfiction.co.uk/cgi-bin/checker.cgi": null,
"farmville.com/trackaction.php": null,
"fastexercise.com/logging.js": null,
"fc2.com/counter.php": null,
"fc2.com/counter_img.php": null,
"fccbrea.org/javascript/stats.js": null,
"filmlinks4u.net/twatch/jslogger.php": null,
"flipkart.com/bbeacon.php": null,
"flixist.com/img2.phtml": null,
"fncstatic.com/static/all/js/geo.js": null,
"forbes.com/fps/cookie_backup.php": null,
"forbesimg.com/assets/js/forbes/fast_pixel.js": null,
"ford.com/ngtemplates/ngassets/com/forddirect/ng/newMetrics.js": null,
"ford.com/ngtemplates/ngassets/ford/general/scripts/js/galleryMetrics.js": null,
"free-tv-video-online.me/resources/js/counter.js": null,
"freebiesms.com/tracker.aspx": null,
"fujifilm.com/js/shared/analyzer.js": null,
"gamerdeals.net/aggbug.aspx": null,
"geico.com/vs/track2.js": null,
"giganews.com/images/rpp.gif": null,
"globes.co.il/shared/s.ashx": null,
"google.com/dssw.js": null,
"hanksgalleries.com/stxt/counter.php": null,
"healthcarejobsite.com/Common/JavaScript/functions.tracking.js": null,
"helium.com/javascripts/helium-beacons.js": null,
"heroku.com/track.js": null,
"herold.at/images/stathbd.gif": null,
"honda.ca/_Global/js/includes/tracker.js": null,
"hoseasons.co.uk/tracking/js.html": null,
"hostels.com/includes/lb.php": null,
"hostels.com/includes/thing.php": null,
"hotmovs.com/get_country.php": null,
"hotnews.ro/pageCount.htm": null,
"howcast.com/images/h.gif": null,
"howtogeek.com/public/stats.php": null,
"hsn.com/code/pix.aspx": null,
"hulkshare.com/ajax/tracker.php": null,
"hulkshare.com/stats.php": null,
"hulu.com/beaconservice.swf": null,
"hulu.com/google_conversion_video_view_tracking.html": null,
"hwscdn.com/analytics.js": null,
"i-am-bored.com/cad.asp": null,
"ibt.com/front/js/counter.js": null,
"icq.com/search/js/stats.js": null,
"ign.com/global/analytics/drones.js": null,
"imagefap.com/images/yes.gif": null,
"images.military.com/pixel.gif": null,
"imgur.com/albumview.gif": null,
"imgur.com/imageview.gif": null,
"imgur.com/lumbar.gif": null,
"infogr.am/js/metrics.js": null,
"infomine.com/imcounter.js": null,
"ino.com/img/sites/mkt/click.gif": null,
"investegate.co.uk/Weblogs/IGLog.aspx": null,
"ipetitions.com/img.php": null,
"irs.gov/js/irs_reporting_cookie.js": null,
"javher.com/analytics.js": null,
"jetsetter.com/tracker.php": null,
"jeuxjeux2.com/stats.php": null,
"jobthread.com/js/t.js": null,
"joins.com/hc.aspx": null,
"klm.com/travel/generic/static/js/measure_async.js": null,
"kloth.net/images/pixel.gif": null,
"kyte.tv/flash/MarbachMetricsOmniture.swf": null,
"kyte.tv/flash/MarbachMetricsProvider.swf": null,
"lancasteronline.com/javascript/ga.php": null,
"lastpass.com/analytics2.php": null,
"latimes.com/images/pixel.gif": null,
"legalmatch.com/scripts/lmtracker.js": null,
"lendingtree.com/javascript/tracking.js": null,
"lexus.com/lexus-share/js/campaign_tracking.js": null,
"localmonero.co/static/ga.js": null,
"log.player.cntv.cn/stat.html": null,
"lovefilm.com/lovefilm/images/dot.gif": null,
"madthumbs.com/tlog.php": null,
"matchesfashion.com/js/Track.js": null,
"mdmpix.com/js/connector.php": null,
"mealime.com/assets/mealytics.js": null,
"medscape.com/pi/1x1/pv/profreg-1x1.gif": null,
"merchantcircle.com/static/track.js": null,
"merck.com/js/mercktracker.js": null,
"met-art.com/visit.js": null,
"microsoft.com/blankpixel.gif": null,
"microsoft.com/getsilverlight/scripts/silverlight/SilverlightAtlas-MSCOM-Tracking.js": null,
"microsoft.com/getsilverlight/scripts/Tracker.js": null,
"military.com/cgi-bin/redlog2.cgi": null,
"military.com/Scripts/mnfooter.js": null,
"modernsalon.com/includes/sc_video_tracking.js": null,
"momtastic.com/libraries/pebblebed/js/pb.track.js": null,
"monkeyquest.com/monkeyquest/static/js/ga.js": null,
"mozilla.com/js/track.js": null,
"msn.com/ro.aspx": null,
"myanimelist.net/static/logging.html": null,
"myfitnesspal.com/assets/mfp_localytics.js": null,
"mytravel.co.uk/thomascooktrack.gif": null,
"nabble.com/static/analytics.js": null,
"naptol.com/usr/local/csp/staticContent/js/ga.js": null,
"nationalpayday.com/1pix.gif": null,
"ncsoft.com/tracker.js": null,
"ndtv.com/Status24x7.lv": null,
"net-a-porter.com/intl/trackpage.nap": null,
"netu.tv/js/netu_counters.js": null,
"netzero.net/account/event.do": null,
"newsarama.com/common/track.php": null,
"newstatesman.com/js/NewStatesmanSDC.js": null,
"next.co.uk/log.php": null,
"nih.gov/medlineplus/images/mplus_en_survey.js": null,
"nih.gov/share/scripts/survey.js": null,
"nike.com/cms/analytics-store-desktop.js": null,
"noip.com/images/em.php": null,
"nova.pub/track.php": null,
"nysun.com/tracker.js": null,
"oasisactive.com/pixels.cfm": null,
"onetravel.com/TrackOnetravelAds.js": null,
"oodle.com/js/suntracking.js": null,
"optimizely.com/js/geo.js": null,
"oracle.com/js/stats.js": null,
"osalt.com/js/track.js": null,
"oscars.org/scripts/wt_include1.js": null,
"oscars.org/scripts/wt_include2.js": null,
"ostkcdn.com/js/p13n.js": null,
"pages03.net/WTS/event.jpeg": null,
"papajohns.com/index_files/activityi.html": null,
"paper.li/javascripts/analytics.js": null,
"pardot.com/pd.js": null,
"pbsrc.com/common/pixel.png": null,
"pepsi.com/js/pepsi_tracking.js": null,
"phonearena.com/_track.php": null,
"photobucket.com/ss/open.php": null,
"playlist.com/scripts/remote_logger.js": null,
"plentyoffish.com/tracking.js": null,
"pokernews.com/track-views.php": null,
"porndoo.com/lib/ajax/track.php": null,
"pricegrabber.com/analytics.php": null,
"prospects.ac.uk/assets/js/prospectsWebTrends.js": null,
"ps-deals.com/aggbug.aspx": null,
"pubarticles.com/add_hits_by_user_click.php": null,
"qbn.com/media/static/js/ga.js": null,
"quintcareers.4jobs.com/Common/JavaScript/functions.tracking.js": null,
"quotesonic.com/vendor/pixel.cfm": null,
"racingbase.com/tracking_fetchinfo.aspx": null,
"radio-canada.ca/lib/TrueSight/markerFile.gif": null,
"razor.tv/site/servlet/tracker.jsp": null,
"reachlocal.com/js/tracklandingpage.js": null,
"realitytvworld.com/images/pixel.gif": null,
"reddit.com/static/pixel.png": null,
"redtube.com/_status/pix.php": null,
"redtube.com/_status/pixa.php": null,
"redtube.com/js/track.js": null,
"redtube.com/pix.php": null,
"resellerclub.com/helpdesk/visitor/index.php": null,
"rightmove.co.uk/ps/images/logging/timer.gif": null,
"ringcentral.com/misc/se_track.asp": null,
"rismedia.com/tracking.js": null,
"rte.ie/player/playertracker.js": null,
"russellgrant.com/hostedsearch/panelcounter.aspx": null,
"s-msn.com/br/gbl/js/2/report.js": null,
"s-msn.com/s/js/loader/activity/trackloader.min.js": null,
"sap.com/global/ui/js/trackinghelper.js": null,
"sciencedaily.com/blank.htm": null,
"sciencedaily.com/cache.php": null,
"scoop.co.nz/images/pixel.gif": null,
"scoot.co.uk/ajax/log_serps.php": null,
"scotts.com/smg/js/omni/customTracking.js": null,
"scribol.com/traffix-tracker.gif": null,
"scriptlance.com/cgi-bin/freelancers/ref_click.cgi": null,
"scripts.snowball.com/scripts/images/pixy.gif": null,
"sdc.com/sdcdata.js": null,
"search.usa.gov/javascripts/stats.js": null,
"searchyc-naity.ru/analytics.js": null,
"securepaynet.net/image.aspx": null,
"sharecast.com/counter.php": null,
"shopautoweek.com/js/modules/tracker.js": null,
"shopify.com/track.js": null,
"shoplocal.com/dot_clear.gif": null,
"shopsubmit.co.uk/visitor.ashx": null,
"sitemeter.com/meter.asp": null,
"skypeassets.com/i/js/jquery/tracking.js": null,
"skyrock.net/img/pix.gif": null,
"skyrock.net/js/stats_blog.js": null,
"slant.co/js/track.min.js": null,
"slashdot.org/images/js.gif": null,
"smartname.com/scripts/cookies.js": null,
"soe.com/js/web-platform/web-data-tracker.js": null,
"sofascore.com/geoip.js": null,
"soonnight.com/stats.htm": null,
"sourceforge.net/images/mlopen_post.html": null,
"sovereignbank.com/utils/track.asp": null,
"spinmedia.com/clarity.min.js": null,
"sporcle.com/adn/yaktrack.php": null,
"staticice.com.au/cgi-bin/stats.cgi": null,
"staticworld.net/pixel.gif": null,
"statravel.co.uk/static/uk_division_web_live/Javascript/wt_gets.js": null,
"stickpage.com/counter.php": null,
"streetfire.net/flash/trackingutility.swf": null,
"streetfire.net/handlers/logstreamfileimpression.ashx": null,
"sublimevideo.net/_.gif": null,
"sugarvine.com/inc/tracking.asp": null,
"t3.com/js/trackers.js": null,
"tdwaterhouse.ca/includes/javascript/rtesurvey.js": null,
"tfl.gov.uk/tfl-global/scripts/stats-config.js": null,
"tfl.gov.uk/tfl-global/scripts/stats.js": null,
"theconversation.com/javascripts/lib/content_tracker_hook.js": null,
"thecreatorsproject.com/tracker.html": null,
"thefreedictionary.com/x/tp.ashx": null,
"thegameslist.com/wb/t.gif": null,
"tickco.com/track.js": null,
"tinypic.com/track.php": null,
"tortoise.proboards.com/tortoise.pl": null,
"trainup.com/inc/TUPTracking.js": null,
"trb.com/hive/swf/analytics.swf": null,
"tubeplus.me/geoip.php": null,
"tubepornclassic.com/js/111.js": null,
"tubxporn.com/track.php": null,
"turn.com/js/module.tracking.js": null,
"tvshark.com/stats.js": null,
"twitter.com/1.1/jot/client_event.json": null,
"twitter.com/1.1/promoted_content/log.json": null,
"twitvid.com/mediaplayer/players/tracker.swf": null,
"u.tv/utvplayer/everywhere/tracking.aspx": null,
"ulogin.ru/stats.html": null,
"unrulymedia.com/loader-analytics.html": null,
"validome.org/valilogger/track.js": null,
"vbs.tv/tracker.html": null,
"venere.com/common/js/track.js": null,
"victoriassecret.com/m/a.gif": null,
"video.msn.com/frauddetect.aspx": null,
"video.syfy.com/lg.php": null,
"videopremium.tv/dev/tr.js": null,
"villarenters.com/inttrack.aspx": null,
"vimeocdn.com/js_opt/ablincoln_combined.min.js": null,
"vimeocdn.com/js_opt/modules/utils/vuid.min.js": null,
"viralnova.com/track.php": null,
"viralogy.com/javascript/viralogy_tracker.js": null,
"virginholidays.co.uk/_assets/js/dc_storm/track.js": null,
"vixy.net/fb-traffic-pop.js": null,
"vogue.co.uk/_/logic/statistics.js": null,
"voyeurhit.com/get_country.php": null,
"wal.co/cdn-perf.min.js": null,
"wallpaperstock.net/partners.js": null,
"washingtonpost.com/rw/sites/twpweb/js/init/init.track-header-1.0.0.js": null,
"watch-series.to/analytics.html": null,
"webcamgalore.com/aslog.js": null,
"webmd.com/dtmcms/live/webmd/PageBuilder_Assets/JS/oas35.js": null,
"webyclip.com/WebyClipAnalytics.html": null,
"weeklyblitz.net/tracker.js": null,
"wikio.com/shopping/tracking/hit.jsp": null,
"windowsphone.com/scripts/siteTracking.js": null,
"wired.com/tracker.js": null,
"worldnow.com/global/tools/video/Namespace_VideoReporting_DW.js": null,
"worldreviewer.com/_search/tracker.png": null,
"xda-cdn.com/analytics.js": null,
"xozilla.com/js/analytics.js": null,
"yahoo.com/perf.gif": null,
"yellowpages.com/images/li.gif": null,
"younewstv.com/js/easyxdm.min.js": null,
"yourbittorrent.com/collect.php": null,
"yourfilehost.com/counter.htm": null,
"yourtv.com.au/share/com/js/fb_google_intercept.js": null,
"youtube-nocookie.com/robots.txt": null,
"zawya.com/zscripts/ajaxztrack.cfm": null,
"zedo.com/img/bh.gif": null,
"zylom.com/pixel.jsp": null,
"vg247.com/wp-content/themes/vg247/scripts/mvg247-fsm.js": null,
"fs.com/js/analysis.js": null,
"bhphotovideo.com/otohphnbwwwdfrecfrassezttzratf.js": null,
"gus.host/coins.js": null,
"stackpathdns.com/assets/javascript/cr.js": null,
"aircanada.com/shared/common/sitecatalyst/s_code.js": null,
"csmonitor.com/extension/csm_base/design/csm_design/javascript/omniture/s_code.js": null,
"csmonitor.com/extension/csm_base/design/standard/javascript/adobe/s_code.js": null,
"expressen.se/static/scripts/s_code.js": null,
"ge.com/sites/all/themes/ge_2012/assets/js/bin/s_code.js": null,
"mercola.com/Assets/js/omniture/sitecatalyst/mercola_s_code.js": null,
"mercuryinsurance.com/static/js/s_code.js": null,
"mnginteractive.com/live/js/omniture/SiteCatalystCode_H_22_1_NC.js": null,
"nyteknik.se/ver02/javascript/2012_s_code_global.js": null,
"paypal.com/acquisition-app/static/js/s_code.js": null,
"playstation.com/pscomauth/groups/public/documents/webasset/community_secured_s_code.js": null,
"sephora.com/javascripts/analytics/wa2.js": null,
"sltrib.com/csp/mediapool/sites/Shared/assets/csp/includes/omniture/SiteCatalystCode_H_17.js": null,
"vitacost.com/Javascripts/s_code.js": null,
"vmware.com/files/templates/inc/s_code_my.js": null,
"radio-canada.ca/omniture/omni_stats_base.js": null,
"watchseries.to/piwik.js": null,
"billiger.de/js/statistik.js": null,
"billiger.de/trackimg.gif": null,
"boersennews.de/js/lib/BnPageTracker.js": null,
"comdirect.de/ccf/img/ecrm2.gif": null,
"computerbild.de/images/pic.gif": null,
"dab-bank.de/img/dummy.gif": null,
"daenischesbettenlager.de/analytics.js": null,
"dat.de/inc/count.js": null,
"digital-zoom.de/counter.js": null,
"elitepartner.de/km/tcnt.do": null,
"feed-reader.net/tracking.php": null,
"fireball.de/statistikframe.asp": null,
"goyellow.de/trackbrowser.jsp": null,
"hdm-stuttgart.de/count.cgi": null,
"homepage-baukasten.de/cookie.php": null,
"jobanova.de/stats.php": null,
"k-files.de/screen.js": null,
"lokalisten.de/tracking.gif": null,
"macnews.de/logreferrer.php": null,
"macwelt.de/images/pic.gif": null,
"news.ch/newslogbug.asp": null,
"nox.to/files/frame.htm": null,
"npage.de/get_statistics.php": null,
"orf.at/ivwscript.js": null,
"playomat.de/sfye_noscript.php": null,
"rtl.de/count/ut/x.gif": null,
"rtlradio.de/stats.php": null,
"rtlradio.lu/stats.php": null,
"shortnews.de/iframes/view_news.cfm": null,
"sportal.de/js/cf.analytics.js": null,
"superfunblog.com/stats/stats.php": null,
"textundblog.de/powercounter.js": null,
"viviano.de/cgi-bin/stat_gateway.cgi": null,
"wikipedia.de/tracking.js": null,
"clubic.com/editorial/publier_count.php": null,
"developpez.com/public/js/track.js": null,
"editeurjavascript.com/hit-parade.php": null,
"jeuxvideo.com/contenu/medias/video/countv.php": null,
"nouvelobs.com/scripts/stats.php": null,
"nouvelobs.com/tools/csrum.php": null,
"pagesjaunes.fr/bva/track.js": null,
"sfr.fr/js/pent-stats.jsp": null,
"unblog.fr/cu.js": null,
"zonecss.fr/images/stat_robocop.gif": null,
"zonecss.fr/images/statscreen.gif": null,
"cdn.mosoah.com/analytics.js": null,
"2cat.or.tl/pmccounter.swf": null,
"acfun.tv/api/count.aspx": null,
"autohome.com.cn/count.js": null,
"baidu.com/push.js": null,
"baidu.com/tb/pms/img/st.gif": null,
"cdn.baidupcs.com/monitor.jpg": null,
"douyucdn.cn/fish3/1.gif": null,
"duowan.com/public/s/market_count.js": null,
"eastmoney.com/counter.js": null,
"ebook.tianya.cn/js/stat.js": null,
"ftchinese.com/js/log.js": null,
"hdslb.com/images/isptrack.js": null,
"his.tv.sohu.com/his/ping.do": null,
"jscss.kdslife.com/club/html/count/PChome_Count.js": null,
"luobo.tv/staticts.html": null,
"map.baidu.com/newmap_test/static/common/images/transparent.gif": null,
"narutom.com/stat.js": null,
"s.pixfs.net/js/pixlogger.min.js": null,
"sbeacon.sina.com.cn/e.gif": null,
"titan24.com/scripts/stats.js": null,
"top.baidu.com/js/nsclick.js": null,
"v.blog.sohu.com/dostat.do": null,
"wumii.com/images/pixel.png": null,
"youdao.com/cf.gif": null,
"youdao.com/imp/cac.js": null,
"yxdown.com/count.js": null,
"jutarnji.hr/template/js/eph_analytics.js": null,
"kbmg.cz/tracker.js": null,
"walla.co.il/CountsHP.asp": null,
"videa.hu/flvplayer_setcookie.php": null,
"bachecaannunci.it/statins3.php": null,
"deagostinipassion.it/collezioni/analytics.js": null,
"ilsole24ore.com/static/js/track.js": null,
"la7.it/js-live/nielsen1.js": null,
"libero.it/cgi-bin/cdcounter.cgi": null,
"libero.it/cgi-bin/cdcountersp.cgi": null,
"mediaset.it/cgi-bin/getcod.cgi": null,
"pornolupo.org/track.js": null,
"smsaffari.it/count_new.php": null,
"spaziogames.it/ajax/player_impression.ashx": null,
"tiscali.it/banner-tiscali/stats.html": null,
"tuttogratis.it/gopix.php": null,
"amazonaws.com/ai-img/aia.js": null,
"retty.me/javascripts/common/logging.js": null,
"seesaawiki.jp/img/rainman.gif": null,
"ytn.co.kr/_comm/ylog.php": null,
"cv.ee/static/stat.php": null,
"tanks.lv/top/stats.php": null,
"consultant.ru/js/counter.js": null,
"mirtesen.ru/js/ms.js": null,
"mytoys.ru/ka_z.jpg": null,
"rutube.ru/counters.html": null,
"tonkosti.ru/go.php": null,
"bankinter.com/res/img/documento_cargado.gif": null,
"esmas.com/scripts/esmas_stats.js": null,
"taringa.net/ajax/track-visit.php": null };
var bad_da_hostpath_exact_flag = 898 > 0 ? true : false;  // test for non-zero number of rules
    
// 499 rules as an efficient NFA RegExp:
var bad_da_hostpath_RegExp = /^(?:[\w-]+\.)*?(?:facebook\.com\/connect\/|facebook\.com\/plugins\/subscribe|adzuna\-jobbox\.fairfaxmedia\.com\.au\/adzuna\/|amazonaws\.com\/fby\/|bing\.com\/widget\/render\/|civicscience\.com\/widget\/jspoll\/|ctctcdn\.com\/js\/signup\-form\-widget\/|diigo\.com\/images\/diigo\-icon\/|download\.skype\.com\/share\/|dukecms\.com\/deals2\/|eff\.org\/bloggers\/badges\/|img\.fark\.net\/pub\/|instapaper\.com\/javascript\/|kaango\.com\/feCustomWidgetDisplay\/|list\-manage1\.com\/subscriber\-count|magimg\.com\/random|mailjet\.com\/widget\/|mobj\.space\/js\/appsdiscover\/|mozo\.com\.au\/widgets\/|nrcdn\.com\/custom\-script\/|sail\-horizon\.com\/horizon\/|sail\-horizon\.com\/scout\/|services\.webklipper\.com\/geoip\/|sheknows\.com\/widget\/|teamautofollow\.com\/modules\/mod_jtwitter\/|techbeat\.com\/wp\-content\/custom\-php\/|vk\.com\/images\/|yimg\.com\/uq\/syndication\/|youappi\.com\/widget\/|zimbio\.com\/images\/badges\/|ziprecruiter\.com\/jobs\-widget\/|contentsitesrv\.com\/js\/push\/|amazonaws\.com\/share\.typeform\.com\/|b\.st\-hatena\.com\/images\/|bloglovin\.com\/widget\/|delicious\.com\/static\/img\/delicious\.|digg\.com\/img\/badges\/|facebook\.com\/plugins\/follow|facebook\.com\/plugins\/likebox\/|feedly\.com\/img\/follows\/|flipboard\.com\/web\/buttons\/|getsocial\.io\/widget\/|houzz\.com\/buttonWidget|karmacracy\.com\/widget|linkedin\.com\/countserv\/|linkedin\.com\/img\/|pinterest\.com\/images\/|platform\.twitter\.com\/js\/button\.|po\.st\/static\/|reddit\.com\/static\/|socialhoney\.co\/widget\/|spiceworks\.com\/share\/|spotify\.com\/follow\/|storeya\.com\/externalscript\/|stumbleupon\.com\/hostedbadge|syndication\.twimg\.com\/widgets\/|twitter\.com\/account\/|twitter\.com\/i\/jot|twitter\.com\/javascripts\/|vuukle\.com\/widgets\/powerbar\/|wer\-kennt\-wen\.de\/js\/widgets\/external\/|werkenntwen\.de\/images\/empfehlen_buttons\/|widgets\.wp\.com\/likes\/|wykop\.pl\/dataprovider\/diggerwidget\/|xing\.com\/img\/buttons\/|yandex\.st\/share\/|youtube\.com\/subscribe_embed|youtube\.com\/subscribe_widget|zextit\.com\/partners\/|complex\.com\/toolbar\/|findthebest\.co\.uk\/ajax\/load_tracker|gameyum\.com\/_static\/popup\/|goodreads\.com\/sign_in_prompt|imgzzz\.com\/styles\/buttons_|newegg\.com\/newegg\/survey\/|rudaw\.net\/images\/icsubscribe\.|space\.com\/images\/site\/social\/|tutorvista\.com\/iframe_container\/|wp\.com\/wp\-content\/mu\-plugins\/post\-flair\/|xhamster\.com\/ajax\/wil\-cams\-widget\/|xhamster\.one\/ajax\/wit\-cams\-widget\/|attn\.com\/survey|motorsport\.com\/join\/popup\/|oilprice\.com\/iframes\/sidebar_signupform\/|scmp\.com\/misc\/inkstone_sub_widget\/|thejewishstar\.com\/images\/enews\-|alwaght\.com\/upload\/logo\/case\/|bwwstatic\.com\/socialtop|cloudfront\.net\/facebook\/|cloudfront\.net\/facebookpage\/|cloudfront\.net\/googleplus\/|cloudfront\.net\/instagram\/|cloudfront\.net\/linkedin\/|cloudfront\.net\/twitter\/|huffingtonpost\.com\/images\/bookmarking\/|linkis\.com\/ajax\/get\-popup\-html|monova\.org\/ajax\/get_lightbox_content|presstv\.ir\/images\/sn_|rackcdn\.com\/Instagram\/|reuters\.tv\/socialLinks\/|schwalbe\.co\.uk\/_webedit\/cached\-images\/172\-37\-38\-0\-0\-37\-38|schwalbe\.co\.uk\/_webedit\/cached\-images\/174\-37\-38\-0\-0\-37\-38|sourceforge\.net\/social\/|onlive\.co\.uk\/account\/cookie_notice|parliamentlive\.tv\/cookie\/|propcom\.co\.uk\/cookie\/|espreso\.rs\/widget|gluecksdetektiv\.de\/wp\-content\/plugins\/easy\-fancybox\-pro\/|vebidoo\.de\/images\/xtotop\.|currenttime\.tv\/a\/signup\-sidebar\-widget\/|out\.be\/widgets\/|cure\-naturali\.it\/banner\/|dday\.it\/assets\/img\/cds_logo\-|hikoki\-powertools\.it\/image\/top\-|draugiem\.lv\/business\/ext\/fans\/|draugiem\.lv\/business\/ext\/follow\/|draugiem\.lv\/lapas\/widgets\/|cts\.com\.tw\/images\/bot_|auto\-motor\-und\-sport\.de\/img\/google\.svg|werkenntwen\.de\/images\/buttons\/|nouvelobs\.com\/social\/|calciomercato\.it\/img\/notizie\/social\/|ilquotidianodellazio\.it\/img\/mi\-piace\-|qatarradio\.qa\/images\/LB\/|shabiba\.com\/images\/snapchat\-|shabiba\.com\/images\/whatsapp\-|cookiesv2\.publiekeomroep\.nl\/light\/|creaweb\.it\/cookie\/|cure\-naturali\.it\/cookies|effekt\.it\/analytics\/|remixshop\.com\/bg\/site\/ajaxCheckCookiePolicy|doubleclick\.net\/activity|doubleclick\.net\/imp%|doubleclick\.net\/json|doubleclick\.net\/pixel|google\-analytics\.com\/batch[^\w.%-]|google\-analytics\.com\/collect|google\-analytics\.com\/gtm\/js|google\-analytics\.com\/internal\/collect[^\w.%-]|google\-analytics\.com\/plugins\/|google\-analytics\.com\/r\/collect[^\w.%-]|googletagmanager\.com\/gtag\/|quantserve\.com\/api\/|quantserve\.com\/pixel\/|netquattro\.com\/stats\/|208\.91\.157\.30\/viewtrack\/|216\.18\.176\.4\/logger\/|3qsdn\.com\/watchtime|5min\.com\/flashcookie\/StorageCookieSWF_|88\.208\.248\.58\/tracking\/|99widgets\.com\/counters\/|9fine\.ru\/js\/counter\.|activengage\.com\/overwatch\/|ad\.atdmt\.com\/c\/|ad\.atdmt\.com\/e\/|ad\.atdmt\.com\/i\/img\/|ad\.atdmt\.com\/m\/|ad\.atdmt\.com\/s\/|addnow\.com\/tracker\/|addthis\.com\/at\/|addthis\.com\/live\/|addthiscdn\.com\/live\/|addthisedge\.com\/live\/|adf\.ly\/ad\/conv|adsv7\.com\/t\/|affilired\.com\/analytic\/|affirm\.com\/api\/v2\/cookie_sent|affirm\.com\/api\/v2\/session\/touch_track|afrigator\.com\/track\/|akamai\.net\/chartbeat\.|akamaihd\.net\/javascripts\/browserfp\.|akamaihd\.net\/log|akanoo\.com\/tracker\/|alexa\.com\/minisiteinfo\/|alexa\.com\/traffic\/|aliyun\.com\/actionlog\/|allanalpass\.com\/track\/|alooma\.com\/track\/|alooma\.io\/track\/|alphasitebuilder\.co\.za\/tracker\/|amatomu\.com\/link\/log\/|amazonaws\.com\/analytics\.|amazonaws\.com\/avsmetrics\/|amazonaws\.com\/cdn\.barilliance\.com\/|amazonaws\.com\/fstrk\.net\/|amazonaws\.com\/initialize\/|amazonaws\.com\/ki\.js\/|amazonaws\.com\/new\.cetrk\.com\/|amazonaws\.com\/searchdiscovery\-satellite\-production\/|amazonaws\.com\/statics\.reedge\.com\/|amazonaws\.com\/wgntrk\/|ancestrycdn\.com\/tao\/at\/|aolanswers\.com\/wtrack\/|apester\.com\/event[^\w.%-]|appinthestore\.com\/click\/|appspot\.com\/analytics\/|appspot\.com\/api\/track\/|appspot\.com\/stats|areyouahuman\.com\/kitten|asterpix\.com\/tagcloudview\/|azureedge\.net\/javascripts\/Tracking\.|azureedge\.net\/track|azurewebsites\.net\/TrackView\/|baidu\.com\/pixel|bhphotovideo\.com\/imp\/|bing\.com\/aclick\/|bit\.ly\/stats|bitclouds\.ru\/trd|bizrate\.co\.uk\/js\/survey_|blogblog\.com\/tracker\/|brandaffinity\.net\/icetrack\/|brandcdn\.com\/pixel\/|bravenet\.com\/counter\/|break\.com\/apextracker\/|browserscope\.org\/user\/beacon\/|canada\.com\/js\/analytics\/|capture\.bi\.movideo\.com\/dc|carambo\.la\/analytics\/|carambo\.la\/logging\/|cdn3\.net\/pixe\/|checkout\.com\/logger\/|citygridmedia\.com\/tracker\/|citysearch\.com\/tracker\/|cityzen\.io\/Pixel\/|clickchatsold\.com\/d0\/|clickfunnels\.com\/userevents\/|clipsyndicate\.com\/cs_api\/cliplog|cloudapp\.net\/l\/|cloudfront\.net\/analyticsengine\/|cloudfront\.net\/autotracker|cloudfront\.net\/bti\/|cloudfront\.net\/performable\/|cloudfront\.net\/sitegainer_|cloudfront\.net\/track|cloudfunctions\.net\/commonBonnierDataLayer|cloudfunctions\.net\/ingest|clustrmaps\.com\/counter\/|cnetcontent\.com\/log|cnevids\.com\/metrics\/|cnpapers\.com\/scripts\/library\/|cnzz\.com\/stat\.|competitoor\.com\/analytics\/|conde\.io\/beacon|condenastdigital\.com\/content|connect\.facebook\.net\/signals\/|contentpass\.net\/stats|creativecdn\.com\/pix\/|creativecdn\.com\/tags|crm\-vwg\.com\/tracker\/|crowdfactory\.com\/tracker\/|cumulus\-cloud\.com\/trackers\/|customerlobby\.com\/ctrack\-|d31bfnnwekbny6\.cloudfront\.net\/customers\/|d3hb14vkzrxvla\.cloudfront\.net\/health\-check|data\.microsoft\.com\/OneCollector\/|daumcdn\.net\/tiara\/|daxab\.com\/logger\/|daylogs\.com\/counter\/|dditscdn\.com\/log\/|dealerfire\.com\/analytics\/|deb\.gs\/track\/|delivra\.com\/tracking\/|delvenetworks\.com\/player\/plugins\/analytics\/|desert\.ru\/tracking\/|desipearl\.com\/tracker\/|directnews\.co\.uk\/feedtrack\/|dmcdn\.net\/behavior\/|drift\.com\/track|dtym7iokkjlif\.cloudfront\.net\/dough\/|early\-birds\.fr\/tracker\/|egmontpublishing\.dk\/tracking\/|email\.mediafire\.com\/wf\/open|emarketeer\.com\/tracker\/|epromote\.co\.za\/track\/|eventful\.com\/apps\/generic\/|evgnet\.com\/beacon\/|eviesays\.com\/js\/analytics\/|evri\.com\/analytics\/|exitintel\.com\/log\/|facebook\.com\/audience_network\/|facebook\.com\/method\/links\.getStats|facebook\.com\/rtb_impression\/|facebook\.com\/rtb_video\/|facebook\.com\/tr|fairfax\.com\.au\/js\/track\/|feed\.informer\.com\/fdstats|filesonic\.com\/referral\/|fitanalytics\.com\/metrics\/|flex\.msn\.com\/mstag\/|followistic\.com\/widget\/stat\/|footballmedia\.com\/tracking\/|foxcontent\.com\/tracking\/|fp\-cdn\.azureedge\.net\/prod\/|freecurrencyrates\.com\/statgif\.|gamegecko\.com\/gametrack|getrockerbox\.com\/pixel|github\.com\/notifications\/beacon\/|google\.com\/analytics\/|googleusercontent\.com\/tracker\/|gotmojo\.com\/track\/|grabnetworks\.com\/beacons\/|gstatic\.com\/gen_204|gubagoo\.com\/modules\/tracking\/|gubagoo\.io\/track\/|hasbro\.com\/includes\/js\/metrics\/|hello\.myfonts\.net\/count\/|hgcdn\.net\/|hocalwire\.com\/tracking\-|hubspot\.com\/analytics\/|hubspot\.com\/tracking\/|ibmcloud\.com\/collector\/|impdesk\.com\/smartpix\/|inphonic\.com\/tracking\/|inq\.com\/tagserver\/logging\/|inq\.com\/tagserver\/tracking\/|insnw\.net\/assets\/dsc\/dsc\.fingerprint\-|instagram\.com\/logging\/|instagram\.com\/logging_client_events|installiq\.com\/Pixels\/|intensedebate\.com\/widgets\/blogstats\/|internetfuel\.com\/tracking\/|intuitwebsites\.com\/tracking\/|ipstatp\.com\/growth\/fe_sdk\/reportsdk\/|ipstatp\.com\/static_magic\/|kbb\.com\/partner\/|klickly\.com\/track|kxcdn\.com\/actor\/|kxcdn\.com\/prj\/|l\-host\.net\/etn\/omnilog|legacy\.com\/globalscripts\/tracking\/|letv\.com\/cloud_pl\/|ligatus\.com\/script\/viewtracker\-|lingows\.appspot\.com\/page_data\/|link\.indiegogo\.com\/img\/|linkbucks\.com\/visitScript\/|linkedin\.com\/countserv\/count\/|list\-manage\.com\/track\/|live\-partner\.com\/tags|livefyre\.com\/libs\/tracker\/|livefyre\.com\/tracking\/|liverail\.com\/track\/|location3\.com\/analytics\/|ltassrv\.com\/track\/|luminate\.com\/track\/|magnify\.net\/decor\/track\/|mail\-app\.com\/pvtracker\/|mail\.ru\/grstat|mail\.ru\/k|mandrillapp\.com\/track\/|mangomolo\.com\/tracking\/|mapquestapi\.com\/logger\/|maptrackpro\.com\/track\/|mashery\.com\/analytics\/|mbsvr\.net\/js\/tracker\/|media\-imdb\.com\/twilight\/|mediabong\.com\/t\/|mediabong\.net\/t\/|merchenta\.com\/track\/|mixpanel\.com\/track|mochiads\.com\/clk\/|msecnd\.net\/script\/raptor\-|msecnd\.net\/scripts\/a\/ai\.|msecnd\.net\/scripts\/b\/ai\.|mshcdn\.com\/assets\/metrics\-|mtvnservices\.com\/metrics\/|mxmfb\.com\/rsps\/img\/|mysociety\.org\/track\/|nastydollars\.com\/trk\/|needle\.com\/pageload|netalpaca\.com\/beacon|netdna\-ssl\.com\/tracker\/|netne\.net\/stats\/|newton\.pm\/events\/track_bulk|ngpvan\.com\/v1\/Track\/|nice264\.com\/data|nitropay\.com\/nads\/|nspmotion\.com\/tracking\/|onescreen\.net\/os\/static\/pixels\/|ooyala\.com\/3rdparty\/comscore_|ooyala\.com\/sas\/analytics|ooyala\.com\/verify|pair\.com\/itero\/tracker_ftc\/|payments\.amazon\.com\/cs\/uedata|pega\.com\/logserver|penton\.com\/analytics\/|performgroup\.com\/metrics\/|photobox\.com\/event|photobox\.com\/logs|piano\.io\/tracker\/|pixel\.indieclicktv\.com\/annonymous\/|planet49\.com\/log\/|player\.ooyala\.com\/errors\/report|playtomic\.com\/Tracker\/|plugins\.longtailvideo\.com\/googlytics|plugins\.longtailvideo\.com\/yourlytics|poweredbyeden\.com\/widget\/tracker\/|ppx\.com\/tracking\/|primedia\.co\.za\/analytics\/|propelplus\.com\/track\/|publicbroadcasting\.net\/analytics\/|pushly\.com\/pushly\-event\-tracker|px\-cdn\.net\/b\/s|qcloud\.com\/report\.go|qq\.com\/dataimport\/|qq\.com\/stats|quisma\.com\/tracking\/|quora\.com\/_\/ad\/|rapidspike\.com\/rum\/|raygun\.io\/events|rbl\.ms\/res\/users\/tracking\/|readcube\.com\/tracking\/|rebel\.ai\/track|recart\.com\/tracking\/|reelevant\.dev\/tracker|reevoo\.com\/track\/|reevoo\.com\/track_url\/|reflow\.tv\/pixels\/|relaymedia\.com\/ping|reverbnation\.com\/widgets\/trk\/|richrelevance\.com\/rrserver\/tracking|rokt\.com\/pixel\/|ru4\.com\/click|s24cloud\.net\/log[^\w.%-]|s24cloud\.net\/metrics\/|schibsted\.com\/autoTracker|scribol\.com\/traffix\/widget_tracker\/|searchmaestros\.com\/trackpoint\/|share\-online\.biz\/affiliate\/|shareaholic\.com\/analytics_|shareholder\.com\/track\/|sharethis\.com\/increment_clicks|sharethis\.com\/pageviews|sinajs\.cn\/open\/analytics\/|sitebooster\.com\/sb\/wix\/p|skysa\.com\/tracker\/|smartertravel\.com\/ext\/pixel\/|smg\.com\/Etrack\/|snapkit\.com\/v1\/sdk\/metrics\/|soccer\.ru\/counter\/|sohu\.com\/stat\/|southafricahome\.com\/statsmodulev2\/|spaceprogram\.com\/webstats\/|sparklit\.com\/counter\/|spot\.im\/api\/tracker\/|streamads\.com\/view|su\.pr\/hosted_js|sulia\.com\/papi\/sulia_partner\.js\/|survey\.io\/log|synergizeonline\.net\/trackpoint\/|taboola\.com\/tb|taboolasyndication\.com\/log\/|tagcdn\.com\/pix\/|techweb\.com\/beacon\/|thefilter\.com\/events\/view|themesltd\.com\/hit\-counter\/|themesltd\.com\/online\-users\-counter\/|thespringbox\.com\/analytics\/|thismoment\.com\/tracking\/|thron\.com\/shared\/plugins\/tracking\/|tinyurl\.com\/pixel\.gif\/|toast\.com\/log|topix\.net\/t6track\/|torrentprotect\.com\/geoip|totallylayouts\.com\/hit\-counter\/|totallylayouts\.com\/online\-users\-counter\/|touchcommerce\.com\/tagserver\/logging\/|tourradar\.com\/def\/partner|traq\.li\/tracker\/|travel\-assets\.com\/datacapture\/|trendmd\.com\/events|trustpilot\.com\/stats\/|trustsquare\.net\/trafficmonitor\/|turnto\.com\/webEvent\/|twik\.io\/track|twimg\.com\/jot|twitter\.com\/scribe\/|ultimatebootcd\.com\/tracker\/|ultimedia\.com\/v\/|uptime\.com\/static\/rum\/|userway\.org\/api\/stats\/|va\.tawk\.to\/log|vanilladev\.com\/analytics\.|veeseo\.com\/tracking\/|ventunotech\.com\/beacon\/|verticalacuity\.com\/varw\/sendEvent|vidazoo\.com\/event\/|video\-cdn\.net\/event|video\.google\.com\/api\/stats\/|videopress\.com\/plugins\/stats\/|viglink\.com\/api\/ping|vimeocdn\.com\/add\/player\-stats|vindicosuite\.com\/track\/|vindicosuite\.com\/tracking\/|vindicosuite\.com\/xumo\/swf\/|viralize\.tv\/track\/|virgingames\.com\/tracker\/|visa\.com\/logging\/logEvent|visualstudio\.com\/v2\/track|vivociti\.com\/images\/)/i;
var bad_da_hostpath_regex_flag = 499 > 0 ? true : false;  // test for non-zero number of rules
    
// 154 rules as an efficient NFA RegExp:
var bad_da_RegExp = /^(?:[\w-]+\.)*?(?:api\-read\.facebook\.com\/restserver\.php\?api_key=|google\.com\/js\/client\:plusone\.js|graph\.facebook\.com\/\?id=|google\.com\/uds\/\?file=orkut&|google\.com\/_\/\+1\/|graph\.facebook\.com\/fql\?q=SELECT|intagme\.com\/in\/\?u=|orain\.org\/w\/index\.php\/Special\:BannerRandom\?|sheknows\.com\/api\/module\?id=follow_social|getjoys\.com\/js\/popup\.js\?v=|piwik\.|doubleclick\.net\/imp;|irs01\.|24option\.com\/\?oftc=|6waves\.com\/edm\.php\?uid=|ad\.atdmt\.com\/i\/go;|akamaized\.net\/\?u=|amazonaws\.com\/\?wsid=|anvato\.com\/anvatoloader\.swf\?analytics=|bufferapp\.com\/wf\/open\?upn=|ceros\.com\/a\?data|cloudfront\.net\/\?a=|cloudfront\.net\/i\?stm=|consensu\.org\/\?log=|dditscdn\.com\/\?a=|ebayrtm\.com\/rtm\?RtmCmd&a=img&|heroku\.com\/\?callback=getip|id\.verticalhealth\.net\/script\.js\?partnerid=|k7\-labelgroup\.com\/g\.html\?uid=|l2\.io\/ip\.js\?var=|liverail\.com\/\?metric=|madmimi\.com\/view\?id=|ooyala\.com\/authorized\?analytics|p\.po\.st\/p\?t=view&|px\-cdn\.net\/api\/v2\/collector$|qualtrics\.com\/WRSiteInterceptEngine\/\?Q_Impress=|s5labs\.io\/common\/i\?impressionId|stripe\.com\/\?event=|sugarops\.com\/w\?action=impression|netreviews\.eu\/index\.php\?action=act_access&|etwun\.com\:8080\/counter\.php\?|api\.tinypic\.com\/api\.php\?action=track|bloomberg\.com\/apps\/data\?referrer|ebay\.com\/op\/t\.do\?event|freelotto\.com\/offer\.asp\?offer=|freeones\.com\/cd\/\?cookies=|gamezone\.com\/\?act=|imagetwist\.com\/\?op=|imdb\.com\/rd\/\?q|ip\-adress\.com\/gl\?r=|juno\.com\/start\/javascript\.do\?message=|linkbucks\.com\/clean\.aspx\?task=record|mail\.yahoo\.com\/dc\/rs\?log=|musicstack\.com\/livezilla\/server\.php\?request=track|overstock\.com\/dlp\?cci=|photographyblog\.com\/\?ACT|quantserve\.com\/pixel;|redtube\.com\/blockcount$|slickdeals\.net\/lf\?t=|totalporn\.com\/videos\/tracking\/\?url=|usage\.zattoo\.com\/\?adblock=|voxmedia\.com\/needle\?d=|wikimedia\.org\/wiki\/Special\:RecordImpression\?|xhamster\.com\/\?log=|xhamster\.com\/ajax\.php\?act=track_event|yahoo\.com\/p\.gif;|yahoo\.com\/serv\?s|yahoo\.com\/sig=|yahoo\.com\/yi\?bv=|ab\-in\-den\-urlaub\.de\/resources\/cjs\/\?f=\/resources\/cjs\/tracking\/|baidu\.com\/nocache\/mp\/b\.jpg\?cmd=|inn\.co\.il\/Controls\/HPJS\.ashx\?act=log|yahoo\.co\.jp\/b\?p=|yahoo\.co\.jp\/s\?s=|kommersant\.ru\/a\.asp\?p=|ok\.ru\/dk\?cmd=videoStatNew|24ur\.com\/bin\/player\/\?mod=statistics&|etahub\.com[^\w.%-](?=([\s\S]*?\/track\?site_id))\1|secureprovide1\.com\/(?=([\s\S]*?=tracking))\2|ws\.amazon\.com\/widgets\/(?=([\s\S]*?=gettrackingid$))\3|sim\-technik\.de[^\w.%-](?=([\s\S]*?&uniqueTrackId=))\4|photobucket\.com[^\w.%-](?=([\s\S]*?\/api\.php\?))\5(?=([\s\S]*?&method=track&))\6|truste\.com\/notice\?(?=([\s\S]*?consent\-track))\7|bild\.de\/code\/linktracking,(?=([\s\S]*?\.js))\8|t\-online\.de[^\w.%-](?=([\s\S]*?\/noresult\.js\?track=))\9|t\-online\.de[^\w.%-](?=([\s\S]*?\/stats\.js\?track=))\10|facebook\.com\/restserver\.php\?(?=([\s\S]*?\.getStats&))\11|apis\.google\.com\/_\/scs\/apps\-static\/(?=([\s\S]*?=page,plusone\/))\12|facebook\.com\/connect\/connect\.php\?(?=([\s\S]*?width))\13(?=([\s\S]*?&height))\14|civiccomputing\.com[^\w.%-](?=([\s\S]*?=cookie))\15|realstylenetwork\.com\/celebrities\/(?=([\s\S]*?&action=inc_popup))\16|bitcoinist\.net\/wp\-content\/(?=([\s\S]*?\/g\+\.png))\17|ad\.atdmt\.com\/i\/(?=([\s\S]*?=))\18|addthis\.com[^\w.%-](?=([\s\S]*?\/p\.json\?))\19(?=([\s\S]*?&ref=))\20|addthiscdn\.com\/(?=([\s\S]*?\.gif\?uid=))\21|amazon\.com\/gp\/(?=([\s\S]*?&linkCode))\22|amazonaws\.com[^\w.%-](?=([\s\S]*?\/i\?stm=))\23|amazonaws\.com[^\w.%-](?=([\s\S]*?=avnts_error))\24|assoc\-amazon\.(?=([\s\S]*?[^\w.%-]e\/ir\?t=))\25|branch\.io[^\w.%-](?=([\s\S]*?_fingerprint_id=))\26|c\.ypcdn\.com[^\w.%-](?=([\s\S]*?&ptid))\27|c\.ypcdn\.com[^\w.%-](?=([\s\S]*?\?ptid))\28|cloudfront\.net(?=([\s\S]*?\/sp\.js$))\29|events\.eyeviewdigital\.com[^\w.%-](?=([\s\S]*?\.gif\?r=))\30|exacttarget\.com[^\w.%-](?=([\s\S]*?\?eventType))\31|facebook\.com\/(?=([\s\S]*?\/plugins\/send_to_messenger\.php\?app_id=))\32|freehostedscripts\.net[^\w.%-](?=([\s\S]*?\.php\?site=))\33(?=([\s\S]*?&s=))\34(?=([\s\S]*?&h=))\35|imagepix\.okoshechka\.net[^\w.%-](?=([\s\S]*?\/\?sid=))\36|inq\.com[^\w.%-](?=([\s\S]*?\/onEvent\?_))\37|jangomail\.com[^\w.%-](?=([\s\S]*?\?UID))\38|licdn\.com\/(?=([\s\S]*?\.gif\?rnd=))\39|lijit\.com\/blog_wijits\?(?=([\s\S]*?=trakr&))\40|mediaplex\.com[^\w.%-](?=([\s\S]*?\?mpt=))\41|metaffiliation\.com[^\w.%-](?=([\s\S]*?[^\w.%-]mclic=))\42|ooyala\.com[^\w.%-](?=([\s\S]*?\/report\?log))\43|r\.ypcdn\.com[^\w.%-](?=([\s\S]*?\/rtd\?ptid))\44|redplum\.com[^\w.%-](?=([\s\S]*?&pixid=))\45|shopify\.com\/(?=([\s\S]*?\/page\?))\46(?=([\s\S]*?&eventType=))\47|socialreader\.com[^\w.%-](?=([\s\S]*?\?event=email_open[^\w.%-]))\48|soundcloud\.com[^\w.%-](?=([\s\S]*?\/plays\?referer=))\49|speedtestbeta\.com\/(?=([\s\S]*?\.gif\?cb))\50|tritondigital\.com\/lt\?sid(?=([\s\S]*?&hasads=))\51|trove\.com[^\w.%-](?=([\s\S]*?&uid=))\52|wikinvest\.com\/plugin\/(?=([\s\S]*?=metricpv))\53|yandex\.(?=([\s\S]*?\/data\?referrer=))\54|yellowpages\.com[^\w.%-](?=([\s\S]*?\.gif\?tid))\55|yimg\.com[^\w.%-](?=([\s\S]*?\/l\?ig=))\56|zoomtv\.me[^\w.%-](?=([\s\S]*?\?pixel=))\57|frontlineshop\.com\/ev\/co\/frontline\?(?=([\s\S]*?&uid=))\58|7host\.ru\/tr\/(?=([\s\S]*?\?r=))\59|amazon\.(?=([\s\S]*?\/batch\/))\60(?=([\s\S]*?uedata=))\61|arstechnica\.com[^\w.%-](?=([\s\S]*?\.gif\?id=))\62|c\.ypcdn\.com[^\w.%-](?=([\s\S]*?\/webyp\?rid=))\63|cbox\.ws[^\w.%-](?=([\s\S]*?\/relay\.swf\?host=))\64|computerarts\.co\.uk\/(?=([\s\S]*?\.php\?cmd=site\-stats))\65|ebayobjects\.com\/(?=([\s\S]*?;dc_pixel_url=))\66|fls\-(?=([\s\S]*?\.amazon\.))\67(?=([\s\S]*?&))\68|freeones\.com[^\w.%-](?=([\s\S]*?\/cd\/\?cookies=))\69|google\.(?=([\s\S]*?\/stats\?frame=))\70|humanclick\.com\/hc\/(?=([\s\S]*?\/\?visitor=))\71|liveperson\.net\/hc\/(?=([\s\S]*?\/\?visitor=))\72|mozilla\.org\/includes\/min\/(?=([\s\S]*?=js_stats))\73|netflix\.com\/beacons\?(?=([\s\S]*?&ssizeCat=))\74(?=([\s\S]*?&vsizeCat=))\75|optimum\.net[^\w.%-](?=([\s\S]*?=pageview&))\76|rover\.ebay\.com\.au[^\w.%-](?=([\s\S]*?&cguid=))\77|skyscanner\.(?=([\s\S]*?\/slipstream\/applog$))\78|skyscanner\.(?=([\s\S]*?\/slipstream\/view$))\79|twitter\.com[^\w.%-](?=([\s\S]*?\/anonymize\?data))\80|uploadrocket\.net\/downloadfiles\.php\?(?=([\s\S]*?&ip))\81|wikinvest\.com\/plugin\/api\.php\?(?=([\s\S]*?=metricld&))\82|www\.imdb\.(?=([\s\S]*?\/rd\/\?q=))\83|arte\.tv[^\w.%-](?=([\s\S]*?=countstats,))\84|manager\-magazin\.de\/js\/http\/(?=([\s\S]*?,testat_))\85|cosmo\.ru\/(?=([\s\S]*?\/\.js\?i=))\86(?=([\s\S]*?&r=))\87)/i;
var bad_da_regex_flag = 154 > 0 ? true : false;  // test for non-zero number of rules
    
// 0 rules as an efficient NFA RegExp:
var good_url_parts_RegExp = /^$/;
var good_url_parts_flag = 0 > 0 ? true : false;  // test for non-zero number of rules
    
// 499 rules as an efficient NFA RegExp:
var bad_url_parts_RegExp = /(?:\-job\-widget\.|\/1pixel\.|\/alerte_tracking\.|\/altClickToSearch\.|\/bloglines\.gif|\/conversional\-popup\.|\/dealsaver\/widget\/|\/disable\-right\-click\-|\/disable\-right\-click\/|\/disablerightclick\.|\/dsv_video_bar\.|\/e\-digital\-survey\.|\/ExitIntentPopUp\.|\/getnetworkwidget\?|\/headsoc\.|\/icon\-blog\-|\/jquery\.androidbanner\.js|\/logo_eskup\.|\/mailchimp\-iframe\/|\/norightclick\.|\/pixel_transparent\.|\/pixel_trasp\.gif\?|\/plugins\/rightclick\/|\/plugins\/scroll\-triggered\-boxes\/|\/plugins\/wp\-emailfeedburnerpop\/|\/popup_do_|\/pubExchange\.min\.js|\/recommendations\-widget\/|\/script\/snow\.js|\/show\-join\-email\.jsonp\?|\/signup_widget\.js|\/signup_widget\.min\.js|\/surveyShower\.|\/toolbarxooit\/\?|\/transparent\-pixel\.|\/wp\-content\/plugins\/rating\-widget\/|\/wp\-content\/plugins\/tab\-slide\/|\/wp\-content\/plugins\/vto_plus\/|\/taboola\-iframe\/|\/taboola\/head\.|\/taboolaArticleHead\.|\/taboolaHead\.|\/outbrain\-load\-|\/outbrainAd\.|\/onesignal\-free\-|\/plugins\/wp\-notification\-bars\/|\/push_subscription\.|\/russmediapush\/|\/scripts\/onesignal\.|\/webPushIframe\.|\-newsletter\-popup\.|\-newsletter\-subscription\-|\-newsletter\/popup\/|\-newsletterwidget\-|\-newsletterwidget\.|\-subscription\-popup\/|\-subscription\-widget\/|\/addthis_subscribe\.|\/assets\/newsletter\-|\/banner\-newsletter\.|\/banner\/newsletter\.|\/bannerino\-newsletter\.|\/BannerNewsletter\.|\/content\/newsletter\/|\/content\/newsletter_|\/emma\-content\-aggregates\-prd\.|\/esnewsletterad\.|\/images\/newslette\-|\/images\/Newsletter\.|\/images\/newsletter_|\/images\/subscribe\-|\/img\/newsletter\.|\/img\/newsletter\/|\/inscription\-newsletter\-|\/inscription_newsletter\?|\/investors\-newsletters\/|\/Javascripts\/Newsletter\.|\/layout\/newsletter\.|\/Masthead\-Newsletter\-|\/media\/newsletters\/|\/Newsletter\-Banner\-|\/newsletter\-banner\.|\/newsletter\-logo\-|\/newsletter\-subscription\-|\/newsletter\/pop\-|\/newsletter\/popin\/|\/newsletter\/popup\-|\/newsletter\/popup\/|\/newsletter\/subscription\/|\/newsletter_banner\.|\/newsletter_popup\/|\/newsletter_popup_|\/newsletter_widget\.|\/newsletterpopup\.|\/newsletterpopup\/|\/NewsletterSubscription\.|\/newsletterwidget\/|\/plugins\/mega\-subscribe\-popup\/|\/plugins\/newsletter\-|\/plugins\/newsletter\/|\/plugins\/NKS\-subscription\/|\/plugins\/wp\-subscribe\-pro\/|\/pop\-in\-newsletter\/|\/popinNewsletter\.|\/popinNewsletter\/|\/popups\/subscribe\-|\/site\/newsletter\-|\/social\/newsletters_|\/static\/newsletter\.|\/subscribe\-popup\.|_banners\/newsletter_|_down_newsletter_|_img\/newsletter\.|_newletter_banner2\.|_popup\/newsletter\.|~popinNewsletter\.|\-blog\-rss\.|\-rss\-social\.|\-social\-rss\.|\/follow\-rss\.|\/follow\/rss\-|\/follow_rss\.|\/imagen_rss_|\/images\/rss\-|\/images\/rss\/|\/images\/rss_|\/img\/rss\.|\/img\/rss_|\/rss\-follow\.|\/rss\-google\.|\/rss\-head\.|\/rss\-logo\.|\/rss\-yahoo\.|\/rss\/feed_widget\/|\/rss\/syndication2\.|\/rss_follow\.|\/rss_logo\.|\/RSS_social\.|\/rss_widget\/|\/rssimg\.|\/social\-rss\-|\/social\-rss\.|\/social\/rss_|\/social_rss_|\/subscribe\-to\-blog_rss\.|_fullimage_RSS\.|_rss_logo_|_social_rss\.|\/scrolltoplugin\.|\-box\-facebook_|\-box\-twitter_|\-btn\-facebook\.|\-btn\-social\-|\-btn\-twitter\.|\-btn\-youtube\-|\-btn\-youtube\.|\-buttons\-facebook\.|\-buttons\-twitter\.|\-facebook\-128\-|\-facebook\-128x128\.|\-facebook\-15x15\.|\-facebook\-64\-|\-facebook\-64\.|\-facebook\-btn\.|\-facebook\-icon\-|\-facebook\-icon\.|\-facebook\-icons\-|\-facebook\-like\-box\/|\-facebook\-share\.|\-facebook\-widget\.|\-facebook\.svg|\-facebook1\.|\-facebook2\.|\-fb\-logo\.|\-fb\-share\.|\-fbpopup\.|\-follow\-icon\-|\-follow\-icons\.|\-follow\-us\-icons\.|\-followicons\.|\-foot\-twitter\.|\-footer\-social\-|\-footer\-social\.|\-footer\-youtube\-|\-footer_social\.|\-google\-32\.|\-google\-icon\.|\-google\-plus\-|\-google\-plus\.|\-google\-plus_|\-googleplus\.|\-googleplus_|\-header\-social\-|\-ico\-google\.|\-ico\-twitter\.|\-icon\-facebook\.|\-icon\-google\-|\-icon\-social\-|\-icon\-twitter\.|\-icon\-youtube\.|\-icon_social\.|\-iconFacebook\.|\-icons\/facebook\.|\-icons\/google\.|\-icons\/twitter\.|\-iconTwitter\.|\-instagram\-logo\-|\-instagram_logo\.|\-left\-social\.|\-link\-social\.|\-Linkedin\-logo\-|\-moresocial\-|\-nav\-social\-|\-nav\-social\.|\-pic\/share\-|\-pinterest\-logo\.|\-plus_social\.|\-redes\-facebook\.|\-redes\-twitter\.|\-redes\-youtube\.|\-share\-16\.|\-share\-bar\/|\-share\-buttons2\.|\-share\-buttons3\/|\-share\-email\.|\-share\-email2\.|\-share\-facebook\.|\-share\-icon\.|\-share\-icons\-|\-share\-icons\.|\-share\-master\/|\-share\-save\/|\-share\-sprite\-|\-share\-sprite\.|\-share\-tools\-|\-share\-twiiter\.|\-share\-whatsapp\.|\-share2\-master\/|\-sharebar\-|\-sharebar\.|\-ShareButton2\.|\-ShareButton_|\-sharebuttons_|\-shareit\.|\-sharetools\-|\-shareWidget\.|\-sharing\-popin\.|\-slide\-social\-|\-social\-32\.|\-social\-bar\.|\-social\-bar\/|\-social\-btn\.|\-social\-buttons\-|\-social\-buttons\.|\-social\-email\-|\-social\-facebook\-|\-social\-facebook\.|\-social\-facebookhover\-|\-social\-flat\.|\-social\-flickr\.|\-social\-google\-|\-social\-icon\-|\-social\-icon\.|\-social\-icons\-|\-social\-icons\.|\-social\-icons\?|\-social\-instagram\-|\-social\-instagram\.|\-social\-linked\-|\-social\-linkedin\.|\-social\-panel\.|\-social\-panel\/|\-social\-pinterest\-|\-social\-popup\-|\-social\-profiles\-|\-social\-share\/|\-social\-share_|\-social\-sidebar\.|\-Social\-Sidebar\/|\-social\-slider\/|\-social\-sprite\-|\-social\-sprite\.|\-social\-sprites\.|\-social\-tumblr\-|\-social\-twitter\-|\-social\-twitter\.|\-social\-twitterhover\-|\-social\-widget1\.|\-social\-you\-tube\.|\-social\-youtube\-|\-social\/facebook\.|\-social\/istagram\.|\-social\/linkedin\.|\-social\/twitter\.|\-social\/youtube\.|\-social_|\-socialbar\.|\-socialbuttons\.|\-socialbuttons\/|\-socialicons\.|\-socialmedia\-buttons\/|\-socialmedia\-sprite\.|\-socialmediashare\.|\-sprite\-social\-|\-sticky\-social\/|\-subscribe\-social\.|\-toolbar\-social\.|\-twitter\-128\-|\-twitter\-128x128\.|\-twitter\-15x15\.|\-twitter\-16x16\.|\-twitter\-64\-|\-twitter\-64\.|\-twitter\-btn\.|\-twitter\-icon\-|\-twitter\-icon\.|\-twitter\-rnd\.|\-twitter\-social\.|\-twitter\-white\-|\-twitter\.js|\-twitter\.svg|\-twitter1\.|\-twitter14\.|\-twitter2\.|\-twitterbirdsprite\.|\-webicon\-facebook\-|\-webicon\-twitter\-|\-webicon\-youtube\-|\-youtube\-128x128\.|\-youtube\-24x24\.|\-youtube\-32\.|\-youtube\-btn\.|\-YouTube\-Button1\.|\-youtube\-flat\-|\-youtube\-icon\-24\.|\-youtube\-icon\.|\-youtube\-s\.|\.bzshare\.|\.bztotalshare\.|\.dkshare\.|\.dktotalshare\.|\.easyshare\:|\.facebookLikePopUp\.|\.fbshare\.js|\.mobile\-share\.|\.pluckCount\.|\.share\.dossierheader\.|\.share\.lead\.|\.share\.utils\.|\.share\/share\.|\.shareaholic\-|\.sharebar\.js|\.sharecount\.|\.shareCounts\.|\.sharetool\.|\.sharing\.js|\.simpleshare\.|\.social\.png|\.social\/share\/|\.sociallocker\.|\/01social\.|\/02social\.|\/03social\.|\/16x16\/facebook_|\/16x16\/google_plus\.|\/16x16\/twitter\.|\/32_facebook\.|\/32x32\-facebook\.|\/32x32\-twitter\.|\/32x32\-youtube\.|\/32x32\/facebook_|\/32x32\/twitter_|\/45x45xfacebook\-ico\.|\/45x45xtwitter\-ico\.|\/a2a_share_|\/accesspress\-social\-|\/actionsnshare\/|\/add\-mymsn2\.|\/addthis\-stumble\.|\/addthis_horizontal\.|\/addthis_widget\.|\/addtoany\-|\/addtoany\.|\/addtogoogle\.|\/addtomyyahoo4\.|\/advinstagram\/|\/amp\-social\-|\/android\-share\.|\/aolshare\/|\/app\/social\.|\/article\-shares\.|\/article\-social\/|\/ArticleSocialShare\.|\/ashare\.js|\/aspexi\-facebook\-|\/assets\/facebook\-|\/assets\/facebook_|\/assets\/fb\.|\/assets\/social\-|\/assets\/social\/|\/assets\/social_|\/assets\/tumblr_|\/assets\/twitter\-|\/assets\/twitter_|\/ayoshare\.js|\/badge_twitter\.|\/banner\-social\.|\/banner\/social\/|\/bg\-share\.|\/bg\-social\.|\/big\-facebook\.|\/big\-twitter\.|\/bigphoto_share\.|\/body\/share\/|\/bookmarksite_google\.|\/bottom\-facebook\.|\/bottom\-twitter\.|\/bouton\-youtubue\.|\/bt_facebook_|\/bt_g_facebook_|\/bt_g_twitter_|\/bt_google_|\/bt_share_|\/bt_you_tube_|\/btn\-blog\-|\/btn\-facebook\-|\/btn\-facebook\.|\/btn\-follow\-|\/btn\-googleplus\-|\/btn\-share\-|\/btn\-share\.|\/btn\-social\-|\/btn\-twitter\-|\/btn\-twitter\.|\/btn\-youtube\-|\/btn\/follow\?|\/btn_facebook\.|\/btn_facebook_|\/btn_google_|\/btn_share_|\/btn_social\.|\/btn_social_|\/btnFacebook\.|\/btns_youtube_|\/btnShareSprite\.|\/btnsSocialMedia\.|\/btnTwitter\.|\/button\-facebook\-|\/button\-facebook\.|\/button\-twitter\-|\/button\-twitter\.|\/Button\-YouTube\.|\/button\/follow\-|\/button\/share\.|\/button1\-share\.|\/button_custom_twitter\.|\/button_facebook\.|\/button_share\.|\/button_social_|\/button_twitter_|\/Buttons\-Facebook\.|\/Buttons\-Twitter\.|\/buttons\/facebook\.|\/buttons\/google\.|\/buttons\/share\/|\/buttons\/share_|\/buttons\/social\-|\/buttons\/social_|\/buttons\/socials\.|\/buttons\/twitter\.|\/buttons\/youtube\.gif|\/bwSocialIcons\.|\/bz\-share\.|\/bz_share\/|\/chs\/share\/|\/cht\/share\/|\/cnw\.share\.|\/color\-facebook\-|\/color\-twitter\-|\/commentshareicons\.|\/commons\/social\/|\/commonSprites\/social\/|\/components\/share\/|\/connect\-facebook\-|\/connect\-facebook\.|\/connect\-google\-|\/connect\-google\.|\/connect\-twitter\-|\/connect\-twitter\.|\/connect\-youtube\-|\/consumer\/social\-|\/context\-social\.|\/controller\/share\-|\/contshare\.|\/cool\-share\/|\/custom\-share\.|\/data\/twitter\/|\/dc\-facebook\-|\/design\/social_)/i;
var bad_url_parts_flag = 499 > 0 ? true : false;  // test for non-zero number of rules
    
// 0 rules as an efficient NFA RegExp:
var good_url_RegExp = /^$/;
var good_url_regex_flag = 0 > 0 ? true : false;  // test for non-zero number of rules
    
// 0 rules as an efficient NFA RegExp:
var bad_url_RegExp = /^$/;
var bad_url_regex_flag = 0 > 0 ? true : false;  // test for non-zero number of rules

// Add any good networks here. Format is network folowed by a comma and
// optional white space, and then the netmask.
// LAN, loopback, Apple (direct and Akamai e.g. e4805.a.akamaiedge.net), Microsoft (updates and services)
var GoodNetworks_Array = [ "10.0.0.0,     255.0.0.0",
"172.16.0.0,        255.240.0.0",
"192.168.0.0,       255.255.0.0",
"127.0.0.0,         255.0.0.0",
"17.0.0.0,          255.0.0.0",
"23.2.8.68,         255.255.255.255",
"23.2.145.78,       255.255.255.255",
"23.39.179.17,      255.255.255.255",
"23.63.98.0,        255.255.254.0",
"104.70.71.223,     255.255.255.255",
"104.73.77.224,     255.255.255.255",
"104.96.184.235,    255.255.255.255",
"104.96.188.194,    255.255.255.255",
"65.52.0.0,         255.255.252.0" ];

// Apple iAd, Microsoft telemetry
var GoodNetworks_Exceptions_Array = [ "17.172.28.11,     255.255.255.255",
"134.170.30.202,    255.255.255.255",
"137.116.81.24,     255.255.255.255",
"157.56.106.189,    255.255.255.255",
"184.86.53.99,      255.255.255.255",
"2.22.61.43,        255.255.255.255",
"2.22.61.66,        255.255.255.255",
"204.79.197.200,    255.255.255.255",
"23.218.212.69,     255.255.255.255",
"65.39.117.230,     255.255.255.255",
"65.52.108.33,      255.255.255.255",
"65.55.108.23,      255.255.255.255",
"64.4.54.254,       255.255.255.255" ];

// Akamai: 23.64.0.0/14, 23.0.0.0/12, 23.32.0.0/11, 104.64.0.0/10

// Add any bad networks here. Format is network folowed by a comma and
// optional white space, and then the netmask.
// From securemecca.com: Adobe marketing cloud, 2o7, omtrdc, Sedo domain parking, flyingcroc, accretive
var BadNetworks_Array = [ "61.139.105.128,    255.255.255.192",
"63.140.35.160,  255.255.255.248",
"63.140.35.168,  255.255.255.252",
"63.140.35.172,  255.255.255.254",
"63.140.35.174,  255.255.255.255",
"66.150.161.32,  255.255.255.224",
"66.235.138.0,   255.255.254.0",
"66.235.141.0,   255.255.255.0",
"66.235.143.48,  255.255.255.254",
"66.235.143.64,  255.255.255.254",
"66.235.153.16,  255.255.255.240",
"66.235.153.32,  255.255.255.248",
"81.31.38.0,     255.255.255.128",
"82.98.86.0,     255.255.255.0",
"89.185.224.0,   255.255.224.0",
"207.66.128.0,   255.255.128.0" ];

// block these schemes; use the command line for ftp, rsync, etc. instead
var bad_schemes_RegExp = RegExp("^(?:ftp|sftp|tftp|ftp-data|rsync|finger|gopher)", "i")

// RegExp for schemes; lengths from
// perl -lane 'BEGIN{$l=0;} {!/^#/ && do{$ll=length($F[0]); if($ll>$l){$l=$ll;}};} END{print $l;}' /etc/services
var schemepart_RegExp = RegExp("^([\\w*+-]{2,15}):\\/{0,2}","i");
var hostpart_RegExp = RegExp("^((?:[\\w-]+\\.)+[a-zA-Z0-9-]{2,24}\\.?)", "i");
var querypart_RegExp = RegExp("^((?:[\\w-]+\\.)+[a-zA-Z0-9-]{2,24}\\.?[\\w~%.\\/^*-]*)(\\??\\S*?)$", "i");
var domainpart_RegExp = RegExp("^(?:[\\w-]+\\.)*((?:[\\w-]+\\.)[a-zA-Z0-9-]{2,24})\\.?", "i");

//////////////////////////////////////////////////
// Define the is_ipv4_address function and vars //
//////////////////////////////////////////////////

var ipv4_RegExp = /^(\d{1,3})\.(\d{1,3})\.(\d{1,3})\.(\d{1,3})$/;

function is_ipv4_address(host)
{
    var ipv4_pentary = host.match(ipv4_RegExp);
    var is_valid_ipv4 = false;

    if (ipv4_pentary) {
        is_valid_ipv4 = true;
        for( i = 1; i <= 4; i++) {
            if (ipv4_pentary[i] >= 256) {
                is_valid_ipv4 = false;
            }
        }
    }
    return is_valid_ipv4;
}

// object hashes
// Note: original stackoverflow-based hasOwnProperty does not woth within iOS kernel 
var hasOwnProperty = function(obj, prop) {
    return obj.hasOwnProperty(prop);
}

/////////////////////
// Done Setting Up //
/////////////////////

// debug with Chrome at chrome://net-export
// alert("Debugging message.")

//////////////////////////////////
// Define the FindProxyFunction //
//////////////////////////////////

var use_pass_rules_parts_flag = true;  // use the pass rules for url parts, then apply the block rules
var alert_flag = false;                // use for short-circuit '&&' to print debugging statements
var debug_flag = false;               // use for short-circuit '&&' to print debugging statements

// EasyList filtering for FindProxyForURL(url, host)
function EasyListFindProxyForURL(url, host)
{
    var host_is_ipv4 = is_ipv4_address(host);
    var host_ipv4_address;

    alert_flag && alert("url is: " + url);
    alert_flag && alert("host is: " + host);

    // Extract scheme and url without scheme
    var scheme = url.match(schemepart_RegExp)
    scheme = scheme.length > 0? scheme[1] : "";

    // Remove the scheme and extract the path for regex efficiency
    var url_noscheme = url.replace(schemepart_RegExp,"");
    var url_pathonly = url_noscheme.replace(hostpart_RegExp,"");
    var url_noquery = url_noscheme.replace(querypart_RegExp,"$1");
    // Remove the server name from the url and host if host is not an IPv4 address
    var url_noserver = !host_is_ipv4 ? url_noscheme.replace(domainpart_RegExp,"$1") : url_noscheme;
    var url_noservernoquery = !host_is_ipv4 ? url_noquery.replace(domainpart_RegExp,"$1") : url_noscheme;
    var host_noserver =  !host_is_ipv4 ? host.replace(domainpart_RegExp,"$1") : host;

    // Debugging results
    if (debug_flag && alert_flag) {
        alert("url_noscheme is: " + url_noscheme);
        alert("url_pathonly is: " + url_pathonly);
        alert("url_noquery is: " + url_noquery);
        alert("url_noserver is: " + url_noserver);
        alert("url_noservernoquery is: " + url_noservernoquery);
        alert("host_noserver is: " + host_noserver);
    }

    // Short circuit to blackhole for good_da_host_exceptions
    if ( hasOwnProperty(good_da_host_exceptions_JSON,host) ) {
        alert_flag && alert("good_da_host_exceptions_JSON blackhole!");
        return blackhole;
    }

    ///////////////////////////////////////////////////////////////////////
    // Check to make sure we can get an IPv4 address from the given host //
    // name.  If we cannot do that then skip the Networks tests.         //
    ///////////////////////////////////////////////////////////////////////

    host_ipv4_address = host_is_ipv4 ? host : (isResolvable(host) ? dnsResolve(host) : false);

    if (host_ipv4_address) {
        alert_flag && alert("host ipv4 address is: " + host_ipv4_address);
        /////////////////////////////////////////////////////////////////////////////
        // If the IP translates to one of the GoodNetworks_Array (with exceptions) //
        // we pass it because it is considered safe.                               //
        /////////////////////////////////////////////////////////////////////////////

        for (i in GoodNetworks_Exceptions_Array) {
            tmpNet = GoodNetworks_Exceptions_Array[i].split(/,\s*/);
            if (isInNet(host_ipv4_address, tmpNet[0], tmpNet[1])) {
                alert_flag && alert("GoodNetworks_Exceptions_Array Blackhole: " + host_ipv4_address);
                return blackhole;
            }
        }
        for (i in GoodNetworks_Array) {
            tmpNet = GoodNetworks_Array[i].split(/,\s*/);
            if (isInNet(host_ipv4_address, tmpNet[0], tmpNet[1])) {
                alert_flag && alert("GoodNetworks_Array PASS: " + host_ipv4_address);
                return proxy;
            }
        }

        ///////////////////////////////////////////////////////////////////////
        // If the IP translates to one of the BadNetworks_Array we fail it   //
        // because it is not considered safe.                                //
        ///////////////////////////////////////////////////////////////////////

        for (i in BadNetworks_Array) {
            tmpNet = BadNetworks_Array[i].split(/,\s*/);
            if (isInNet(host_ipv4_address, tmpNet[0], tmpNet[1])) {
                alert_flag && alert("BadNetworks_Array Blackhole: " + host_ipv4_address);
                return blackhole;
            }
        }
    }

    //////////////////////////////////////////////////////////////////////////////
    // HTTPS: https scheme can only use domain information                      //
    // unless PacHttpsUrlStrippingEnabled == false [Chrome] or                  //
    // network.proxy.autoconfig_url.include_path == true [Firefox, about:config]              //
    // E.g. on macOS:                                                           //
    // defaults write com.google.Chrome PacHttpsUrlStrippingEnabled -bool false //
    // Check setting at page chrome://policy                                    //
    //////////////////////////////////////////////////////////////////////////////

    // Assume browser has disabled path access if scheme is https and path is '/'
    if ( scheme == "https" && url_pathonly == "/" ) {

        ///////////////////////////////////////////////////////////////////////
        // PASS LIST:   domains matched here will always be allowed.         //
        ///////////////////////////////////////////////////////////////////////

        if ( (good_da_host_exact_flag && (hasOwnProperty(good_da_host_JSON,host_noserver)||hasOwnProperty(good_da_host_JSON,host)))
            && !hasOwnProperty(good_da_host_exceptions_JSON,host) ) {
                alert_flag && alert("HTTPS PASS: " + host + ", " + host_noserver);
            return proxy;
        }

        //////////////////////////////////////////////////////////
        // BLOCK LIST:	stuff matched here here will be blocked //
        //////////////////////////////////////////////////////////

        if ( (bad_da_host_exact_flag && (hasOwnProperty(bad_da_host_JSON,host_noserver)||hasOwnProperty(bad_da_host_JSON,host))) ) {
            alert_flag && alert("HTTPS blackhole: " + host + ", " + host_noserver);
            return blackhole;
        }
    }

    ////////////////////////////////////////
    // HTTPS and HTTP: full path analysis //
    ////////////////////////////////////////

    if (scheme == "https" || scheme == "http") {

        ///////////////////////////////////////////////////////////////////////
        // PASS LIST:   domains matched here will always be allowed.         //
        ///////////////////////////////////////////////////////////////////////

        if ( !hasOwnProperty(good_da_host_exceptions_JSON,host)
            && ((good_da_host_exact_flag && (hasOwnProperty(good_da_host_JSON,host_noserver)||hasOwnProperty(good_da_host_JSON,host))) ||  // fastest test first
                (use_pass_rules_parts_flag &&
                    (good_da_hostpath_exact_flag && (hasOwnProperty(good_da_hostpath_JSON,url_noservernoquery)||hasOwnProperty(good_da_hostpath_JSON,url_noquery)) ) ||
                    // test logic: only do the slower test if the host has a (non)suspect fqdn
                    (good_da_host_regex_flag && (good_da_host_RegExp.test(host_noserver)||good_da_host_RegExp.test(host))) ||
                    (good_da_hostpath_regex_flag && (good_da_hostpath_RegExp.test(url_noservernoquery)||good_da_hostpath_RegExp.test(url_noquery))) ||
                    (good_da_regex_flag && (good_da_RegExp.test(url_noserver)||good_da_RegExp.test(url_noscheme))) ||
                    (good_url_parts_flag && good_url_parts_RegExp.test(url)) ||
                    (good_url_regex_flag && good_url_regex_RegExp.test(url)))) ) {
            return proxy;
        }

        //////////////////////////////////////////////////////////
        // BLOCK LIST:	stuff matched here here will be blocked //
        //////////////////////////////////////////////////////////
        // Debugging results
        if (debug_flag && alert_flag) {
            alert("hasOwnProperty(bad_da_host_JSON," + host_noserver + "): " + (bad_da_host_exact_flag && hasOwnProperty(bad_da_host_JSON,host_noserver)));
            alert("hasOwnProperty(bad_da_host_JSON," + host + "): " + (bad_da_host_exact_flag && hasOwnProperty(bad_da_host_JSON,host)));
            alert("hasOwnProperty(bad_da_hostpath_JSON," + url_noservernoquery + "): " + (bad_da_hostpath_exact_flag && hasOwnProperty(bad_da_hostpath_JSON,url_noservernoquery)));
            alert("hasOwnProperty(bad_da_hostpath_JSON," + url_noquery + "): " + (bad_da_hostpath_exact_flag && hasOwnProperty(bad_da_hostpath_JSON,url_noquery)));
            alert("bad_da_host_RegExp.test(" + host_noserver + "): " + (bad_da_host_regex_flag && bad_da_host_RegExp.test(host_noserver)));
            alert("bad_da_host_RegExp.test(" + host + "): " + (bad_da_host_regex_flag && bad_da_host_RegExp.test(host)));
            alert("bad_da_hostpath_RegExp.test(" + url_noservernoquery + "): " + (bad_da_hostpath_regex_flag && bad_da_hostpath_RegExp.test(url_noservernoquery)));
            alert("bad_da_hostpath_RegExp.test(" + url_noquery + "): " + (bad_da_hostpath_regex_flag && bad_da_hostpath_RegExp.test(url_noquery)));
            alert("bad_da_RegExp.test(" + url_noserver + "): " + (bad_da_regex_flag && bad_da_RegExp.test(url_noserver)));
            alert("bad_da_RegExp.test(" + url_noscheme + "): " + (bad_da_regex_flag && bad_da_RegExp.test(url_noscheme)));
            alert("bad_url_parts_RegExp.test(" + url + "): " + (bad_url_parts_flag && bad_url_parts_RegExp.test(url)));
            alert("bad_url_regex_RegExp.test(" + url + "): " + (bad_url_regex_flag && bad_url_regex_RegExp.test(url)));
        }

        if ( (bad_da_host_exact_flag && (hasOwnProperty(bad_da_host_JSON,host_noserver)||hasOwnProperty(bad_da_host_JSON,host))) ||  // fastest test first
            (bad_da_hostpath_exact_flag && (hasOwnProperty(bad_da_hostpath_JSON,url_noservernoquery)||hasOwnProperty(bad_da_hostpath_JSON,url_noquery)) ) ||
            // test logic: only do the slower test if the host has a (non)suspect fqdn
            (bad_da_host_regex_flag && (bad_da_host_RegExp.test(host_noserver)||bad_da_host_RegExp.test(host))) ||
            (bad_da_hostpath_regex_flag && (bad_da_hostpath_RegExp.test(url_noservernoquery)||bad_da_hostpath_RegExp.test(url_noquery))) ||
            (bad_da_regex_flag && (bad_da_RegExp.test(url_noserver)||bad_da_RegExp.test(url_noscheme))) ||
            (bad_url_parts_flag && bad_url_parts_RegExp.test(url)) ||
            (bad_url_regex_flag && bad_url_regex_RegExp.test(url)) ) {
            alert_flag && alert("Blackhole: " + url + ", " + host);
            return blackhole;
        }
    }

    // default pass
    alert_flag && alert("Default PASS: " + url + ", " + host);
    return proxy;
}

// User-supplied FindProxyForURL()
function FindProxyForURL(url, host)
{
if (
   isPlainHostName(host) ||
   shExpMatch(host, "10.*") ||
   shExpMatch(host, "172.16.*") ||
   shExpMatch(host, "192.168.*") ||
   shExpMatch(host, "127.*") ||
   dnsDomainIs(host, ".local") || dnsDomainIs(host, ".LOCAL")
   /*
       Fix iOS 13 PAC file issue with Mail.app
       See: https://forums.developer.apple.com/thread/121928
   */
   ||
   // Apple
   (host == "imap.mail.me.com") || (host == "smtp.mail.me.com") ||
   dnsDomainIs(host, "imap.mail.me.com") || dnsDomainIs(host, "smtp.mail.me.com") ||
   (host == "p03-imap.mail.me.com") || (host == "p03-smtp.mail.me.com") ||
   dnsDomainIs(host, "p03-imap.mail.me.com") || dnsDomainIs(host, "p03-smtp.mail.me.com") ||
   (host == "p66-imap.mail.me.com") || (host == "p66-smtp.mail.me.com") ||
   dnsDomainIs(host, "p66-imap.mail.me.com") || dnsDomainIs(host, "p66-smtp.mail.me.com") ||
   // Google
   (host == "imap.gmail.com") || (host == "smtp.gmail.com") ||
   dnsDomainIs(host, "imap.gmail.com") || dnsDomainIs(host, "smtp.gmail.com") ||
   // Yahoo
   (host == "imap.mail.yahoo.com") || (host == "smtp.mail.yahoo.com") ||
   dnsDomainIs(host, "imap.mail.yahoo.com") || dnsDomainIs(host, "smtp.mail.yahoo.com") ||
   // Comcast
   (host == "imap.comcast.net") || (host == "smtp.comcast.net") ||
   dnsDomainIs(host, "imap.comcast.net") || dnsDomainIs(host, "smtp.comcast.net")
   /*
       Proxy bypass hostnames
   */
   ||
   // Apple Mobile Software Update
   (host == "mesu.apple.com") || dnsDomainIs(host, "mesu.apple.com")
)
        return "DIRECT";
else
        return EasyListFindProxyForURL(url, host);
}   
